*****************************************************************************
*
* Differential costing allow wholesale or selective calculation of differential
*  costs for DMDs.  Differential cost being defined as the cost of the least
*  expensive DMD being subtracted from itself and each other DMD belonging to
*  the DM.
*
* Note that ADRATIOs must be handled by the user via the table DIFFCOST(,(DM))
*  table where a TID entry implies that the minimum cost should be found for
*  the DMDs, otherwise the T entries (after interpolation) will be used.  OUTDM
*  may also require that the DIFFCOST override capability be used.
*
*****************************************************************************
*GG* V1.2b new
*GG* V1.3b calculate the capital recovery factor for each technology
PARAMETERS CRF(TCH) / EMPTY 0 /;
  CRF(TCH)$TCH_LIFE(TCH) =
  (TCH_DISC(TCH)/(1-(1+TCH_DISC(TCH))**(-TCH_LIFE(TCH)*NYRSPER)))$TCH_DISC(TCH)
   + (DISCOUNT/(1-(1+DISCOUNT)**(-TCH_LIFE(TCH)*NYRSPER)))$(NOT TCH_DISC(TCH));

*display dmd_dms, dmd_out, fraclife, crf, tch_invcos;

PUT CLOG;
*SCALARS MINLIFE, MAXLIFE;
PARAMETERS MINVAL(TP,DM), MINMULT(TP,DM);
IF (DIFFDMDS NE 0,

  PUT / ' ***** TRACE LOG - DIFFERENTIAL DEMAND DEVICE COSTING *****' /;
  PUT / @43 LOOP(TP, PUT TP.TL:>10) ;
  MINVAL(TP,DM) = +INF;
  MINMULT(TP,DM) = +INF;
  LOOP(DM,
* either the DIFFCOST TID has an entry for DM or just calculate requested
    IF ((DIFF_DM(DM) OR DIFFDMDS = 1),
* find the minimum for each year for this demand sector
*GG* V1.3b go over all DMDs feeding the current DM, that is the OUT(DM)s too
      LOOP(DMD_DMS(DMD,DM)$TCH_LIFE(DMD),
*GG* V1.3b take into account OUT(DM)s and annualized investment costs, including
*         fractional LIFEfimes and TCH-based DISCRATEs, but only DMDs with LIFEs
        MINMULT(TP,DM)$(ORD(TP) GE TCH_START(DMD)) =
                    MIN(MINMULT(TP,DM), (TCH_INVCOS(DMD,TP)/DMD_OUT(DMD,DM,TP))
                                     * (FRACLIFE(DMD) * CRF(DMD)));
*        MINVAL(TP)$(ORD(TP) GE TCH_START(DMD)) =
*                    MIN(MINVAL(TP,DM), TCH_INVCOS(DMD,TP)/DMD_OUT(DMD,DM,TP));
        MINVAL(TP,DM)$((ORD(TP) GE TCH_START(DMD)) AND (MINMULT(TP,DM) EQ
         (TCH_INVCOS(DMD,TP)/DMD_OUT(DMD,DM,TP))*(FRACLIFE(DMD) * CRF(DMD))))
                                       = TCH_INVCOS(DMD,TP)/DMD_OUT(DMD,DM,TP);
      );
      MINVAL(TP,DM)$(MINVAL(TP,DM) EQ +INF) = 0;
      PUT  / ' CALCULATED MULTIPLIERS FOR DM  : ' DM.TL:<2 ' = ' ;
        LOOP(TP, PUT MINMULT(TP,DM)) ;
      PUT  / '            MINIMUMS                 = ';
        LOOP(TP, PUT MINVAL(TP,DM)) ;
    ELSE
* set min value from user table or to 0 if none
      PUT / ' SET BY USER FOR DM                 : ' DM.TL:<2 ' = ' ;
        LOOP(TP, PUT (DIFFCOST(DM,TP))) ;
      TCH_INVCOS(DMD,TP)$(DMD_DMS(DMD,DM)$(ORD(TP) GE TCH_START(DMD) AND
                       1$TCH_LIFE(DMD))) = TCH_INVCOS(DMD,TP) - DIFFCOST(DM,TP);

    );

*GG* V1.2c add message if DM has DMDs with different LIFEtimes
*GG* V1.3b remove message because handled in algorithm above
*    MINLIFE = +INF;
*    MAXLIFE = -INF;
*    LOOP(DMD_DM(DMD,DM),
*      MINLIFE = MIN(TCH_LIFE(DMD),MINLIFE);
*      MAXLIFE = MAX(TCH_LIFE(DMD),MAXLIFE);
*    );
*    IF (MINLIFE NE MAXLIFE,
*      PUT / ' *** DEMAND SECTOR : ' DM.TL:<2 ' HAS DMDS WITH DIFFERING LIFETIMES'
*    );

  );

  PUT // ' *** REMINDER : POSSIBLE CROSS-DM CONSIDERATIONS ***' /;
  LOOP (DMD_DMS(DMD,DM),
*GG* V1.3b adjust the investment cost adjustments taking into consideration
*          OUT(DM)s and differring LIFEtimes, also go over all DMDs to DM
*          but only look at DMDs with LIFEs.
*          Also, do so after all DMs are processed.
    IF ((DIFF_DM(DM) OR DIFFDMDS = 1),
      TCH_INVCOS(DMD,TP)$(ORD(TP) GE TCH_START(DMD) AND 1$TCH_LIFE(DMD)) =
                                TCH_INVCOS(DMD,TP) - (DMD_OUT(DMD,DM,TP) *
                                (MINMULT(TP,DM)/(FRACLIFE(DMD) * CRF(DMD))));
    );
* put out message to LOG if OUT(DM)s exist
*GG* V1.3b adjust the test/messages
    IF (NOT DMD_DM(DMD,DM),
      PUT / ' * DEMAND SECTOR : ' DM.TL:<2
            ' LINKED TO ANOTHER SECTOR VIA DEVICE = ' DMD.TL:<3;
    );

*GG* V1.3b check for all devices, because not linked via OUT(DM) but possibly
*          ADRATIOs instead
    LOOP (ADR_TCHC(ADRATIO,DMD),
      PUT / ' * DEMAND SECTOR : ' DM.TL:<2
' HAS DEVICES IN RATIO EQUATIONS; ADRATIO/DEVICE = ' ADRATIO.TL:<7 ' / ' DMD.TL:<3;
    );
  );

);

*GG* V1.4b Hook for UKs FIX O&M adjustment
*$BATINCLUDE DIFF_FOM.INC
