*****************************************************************************
*
* The introduction of fractional lifetimes for technologies either suppled
*  by the user or calculated as a result of COLLAPSE requires an adjustment
*  be applied to the original investment costs.
*
* The nature of the fractional life multiplier is outlined in a memo from Tom
*  Kram of December 21, 1993.
*
*****************************************************************************
*GG* V1.2b

PUT CLOG;
CLOG.NW=10;CLOG.ND=5;CLOG.PW=150;
*GG* V1.2c change fractional information to parameter for later use by COST_INV
SCALAR IIFRLIFE, FRADJ;
*GG* V1.2b add fractional lifetime investment cost multiplier
PARAMETERS FRACLIFE(TCH) / EMPTY 0 /,
           FRLIFE(TCH)  / EMPTY 0 /,
           FLLIFE(TCH)  / EMPTY 0 /;

PUT // ' ***** TRACE LOG - FRACTIONAL LIFETIME INVESTMENT COST MULTIPLIERS ***** '/ ;
LOOP(TCH,
  FRACLIFE(TCH) = 1;
  FLLIFE(TCH) = FLOOR(TCH_LIFE(TCH));
  FRLIFE(TCH) = TCH_LIFE(TCH) - FLLIFE(TCH);
  IF (FRLIFE(TCH),
* have a fractional lifetime
    IIFRLIFE = FLOOR(1/FRLIFE(TCH));
    FRACLIFE(TCH) = FRLIFE(TCH) * (FRACLIFE(TCH) +
                             SUM(ALLORD$(ORD(ALLORD) < IIFRLIFE),
                             (1 + DISCOUNT) ** (-ORD(ALLORD)*FRLIFE(TCH)*NYRSPER)));
    IF ((IIFRLIFE < 1/FRLIFE(TCH)),
      FRACLIFE(TCH) = FRACLIFE(TCH) + FRLIFE(TCH) * (1 + DISCOUNT) **
                                                (-IIFRLIFE*FRLIFE(TCH)*NYRSPER) *
        ( (DISCOUNT/(1-(1+DISCOUNT)**(-FRLIFE(TCH)*NYRSPER))) /
          (DISCOUNT/(1-(1+DISCOUNT)**(-NYRSPER*(1-FRLIFE(TCH)*IIFRLIFE)))) );
    );
    IF ((TCH_LIFE(TCH) > 1),
* add the fractional periods adjustment value
      IIFRLIFE = 1 + SUM(ALLORD$(ORD(ALLORD) < FLLIFE(TCH)),
                 (1 + DISCOUNT)**(-ORD(ALLORD)*NYRSPER));
      FRADJ = FRLIFE(TCH) * (1 + DISCOUNT)**(-FLLIFE(TCH)*NYRSPER);
      FRACLIFE(TCH) = (IIFRLIFE + FRADJ * FRACLIFE(TCH)) / (IIFRLIFE + FRADJ);
    );
    PUT / ' LIFETIME MULTIPLIER FOR TECHNOLOGY = ' TCH.TL:<3,
           ' LIFE/FACTOR: ' TCH_LIFE(TCH), ' / ' FRACLIFE(TCH);
  );
);
