******************************************************************************
*                                                                            *
* The MACRO Related Model Components are Initialized                         *
*                                                                            *
******************************************************************************
*GG* V1.0h change the hardwire .001/1000 scaling to us MMSCALE
$ontext
                                   MARKAL              MACRO
Energy                   petaJ (10**15 J)    exaJ (10**18 J)
Energy prices                    $ per GJ           $ per GJ
Total costs,1990 dollars            10**6              10**9

*PARAMETER CRF(YRS) capital recovery factors - annual
* First payment is during same year as initial investment.  Beta =
* 1/(1+rate).  Therefore: crf = (1-beta)/(1-beta^T)).  With annual rate = 5%:
$offtext

*============================================================================*
* Initialize the economic parameters                                         *
*============================================================================*
*GG* V1.0i moved declarations to MMINIT

*  AEEIV(DM, TP) = DDAT(DM, "AEEI") / 100;
*GG* V1.2 change AEEIs -> DDF with time dependancy
  AEEIV(DM, TP) = DDF(DM, TP) / 100;
  ASRV          = 1 - DEPR / 100;
  DFACTCURR(TP) = 1 - (KPVS / KGDP - DEPR / 100 - GROWV(TP) / 100);
  RHO           = 1 - 1 / ESUB;
  TSRV = ASRV ** NYRSPER;

*============================================================================*
*  Calculate the initial values for the economic variables for the first     *
*   time period                                                              *
*   - Capital Stock                                                          *
*   - Investment during time period 0                                        *
*   - Consumption during time period 0                                       *
*   - GDP (Consumption + Investment) + Energy Costs                          *
*============================================================================*
  K0   = KGDP * GDP0;
  IV0  = K0 * (DEPR + SUM(TB, GROWV(TB))) / 100;
  C0   = GDP0 - IV0;
  Y0   = GDP0 + EC0;

DISPLAY ASRV, C0, IV0, K0;

*============================================================================*
* Calculate intermedita values                                               *
*============================================================================*
  AEEIFAC(DM,TB) = 1;
  DFACT(TB)      = 1;
  L(TB)          = 1;

LOOP(TP,
  AEEIFAC(DM, TP + 1) = AEEIFAC(DM, TP) * (1 - AEEIV(DM, TP + 1)) ** NYRSPER;
  DFACT(TP + 1)       = DFACT(TP) * DFACTCURR(TP) ** NYRSPER;
  L(TP + 1)           = L(TP) * (1 + GROWV(TP) / 100) ** NYRSPER
);

  DFACT(TLAST) = DFACT(TLAST) / (1 - DFACTCURR(TLAST) ** NYRSPER);

  DISPLAY DFACT, L;

  D0(DM) = MMSCALE * SUM(TB, DM_DEMAND(DM, TB));

  B(DM)  = D0(DM) / Y0;
  B(DM)  = B(DM) ** (1 - RHO);
*SK* keep factor rather than MMSCALE?
  B(DM)  = 0.001 * DDAT(DM, "PREF") * B(DM);

  AKL    =  Y0 ** RHO - SUM(DM, B(DM) * (D0(DM) ** RHO));
  AKL    =  AKL / (K0 ** (KPVS * RHO));

  YCHECK = AKL * K0 ** (KPVS * RHO)  +  SUM(DM, B(DM) * D0(DM) ** RHO);
  YCHECK = YCHECK ** (1 / RHO);

*============================================================================*
*  Set the Lower Bound and Fix the First Year                                *
*   - Demands                                                                *
*   - Investment                                                             *
*   - Capital                                                                *
*   - Marginal Costs of Demands                                              *
*============================================================================*
*GG* V1.0h user scalar (from CONSTANT table) to control lower bound on demands
  D.LO(DM,TT)   = DMTOL * D0(DM);
  D.FX(DM,TB)  = D0(DM);

  IV.L(TT)      = IV0 * L(TT);
  IV.FX(TB)    = IV0;

  K.L(TT)       = K0 * L(TT);
*GG* V1.0h user scalar (from CONSTANT table) to control investment tolerance
  K.LO(TT)      = K0 * (L(TT) ** IVETOL);
  K.FX(TB)     = K0;

  SP.FX(DM,TP) = 0;

*Initialization of CONS
CONS.L(TP)=C0;
CONS.LO(TP)=C0/2;
DISPLAY CONS.L;
* annual percent expansion factor converted into 1 period factor
  EXPF = (1+EXPF/100)**NYRSPER;

******************************************************************************
*                                                                            *
*  Calculate the Annualized Investment Costs for MARKAL-MACRO                *
*                                                                            *
******************************************************************************
*GG* V1.1c moved back to MMCOEF
