*****************************************************************************
*                                                                           *
*   MMBNDS.INC resets any previous bounds and then applies the current set  *
*    of bounds to the vectors.                                              *
*                                                                           *
*   Note that the $ conditional needs to be specified to the left of the =  *
*    so that 0s are not assigned where no user input is provided!           *
*                                                                           *
*****************************************************************************

*===========================================================================*
*  Supply of Resources                                                      *
*===========================================================================*
*GG* V1.0a reset the bounds
TSEP.LO(TP,SEP) = 0;
TSEP.UP(TP,SEP) = +INF;
TSEP.LO(TPSEP(TP,SEP))$(SEP_BOUND(SEP, 'LO', TP)) = SEP_BOUND(SEP, 'LO', TP);
TSEP.FX(TPSEP(TP,SEP))$(SEP_BOUND(SEP, 'FX', TP)) = SEP_BOUND(SEP, 'FX', TP);
TSEP.UP(TPSEP(TP,SEP))$(SEP_BOUND(SEP, 'UP', TP)) = SEP_BOUND(SEP, 'UP', TP);

*===========================================================================*
*  Capacity of Technologies                                                 *
*===========================================================================*
*GG* V1.0a reset the bounds
CAP.LO(TP,TCH) = 0;
CAP.UP(TP,TCH) = +INF;
CAP.LO(TPTCH(TP,TCH))$(TCH_BOUND(TCH, 'LO', TP)) = TCH_BOUND(TCH, 'LO', TP);
CAP.FX(TPTCH(TP,TCH))$(TCH_BOUND(TCH, 'FX', TP)) = TCH_BOUND(TCH, 'FX', TP);
CAP.UP(TPTCH(TP,TCH))$(TCH_BOUND(TCH, 'UP', TP)) = TCH_BOUND(TCH, 'UP', TP);

*===========================================================================*
*  Investment in Technologies                                               *
*===========================================================================*
*GG* V1.0a reset the bounds
INV.LO(TP,TCH) = 0;
INV.UP(TP,TCH) = +INF;
INV.LO(TPTCH(TP,TCH))$(TCH_IBND(TCH, 'LO', TP)) = TCH_IBND(TCH, 'LO', TP);
INV.FX(TPTCH(TP,TCH))$(TCH_IBND(TCH, 'FX', TP)) = TCH_IBND(TCH, 'FX', TP);
INV.UP(TPTCH(TP,TCH))$(TCH_IBND(TCH, 'UP', TP)) = TCH_IBND(TCH, 'UP', TP);

* activity of processes
*===========================================================================*
*  Activity of Processes                                                    *
*===========================================================================*
*GG* V1.0a reset the bounds
ACT.LO(TP,PRC) = 0;
ACT.UP(TP,PRC) = +INF;
*GG* V1.0h not if no activity vector
LOOP(TPPRC(TP,PRC)$(NOT ZPR(PRC)),
  ACT.LO(TP,PRC)$TCH_BNDO(PRC, 'LO', TP) = TCH_BNDO(PRC, 'LO', TP);
  ACT.FX(TP,PRC)$TCH_BNDO(PRC, 'FX', TP) = TCH_BNDO(PRC, 'FX', TP);
  ACT.UP(TP,PRC)$TCH_BNDO(PRC, 'UP', TP) = TCH_BNDO(PRC, 'UP', TP);
);
*GG* V2.2g handle XPRs too
LOOP(TPPRC(TP,ZPR),
  CAP.LO(TP,ZPR)$TCH_BNDO(ZPR, 'LO', TP) = TCH_BNDO(ZPR, 'LO', TP) *
                                           TCH_CAPUNI(ZPR) * TCH_CF2(ZPR, TP);
  CAP.FX(TP,ZPR)$TCH_BNDO(ZPR, 'FX', TP) = TCH_BNDO(ZPR, 'FX', TP) *
                                           TCH_CAPUNI(ZPR) * TCH_CF2(ZPR, TP);
  CAP.UP(TP,ZPR)$TCH_BNDO(ZPR, 'UP', TP) = TCH_BNDO(ZPR, 'UP', TP) *
                                           TCH_CAPUNI(ZPR) * TCH_CF2(ZPR, TP);
);

*===========================================================================*
*  Activity of Conversion Technologies                                      *
*===========================================================================*
*GG* MUST BE RHS of (T)BND(CON)(B)!
*GG* V1.0a reset the bounds
*TEZY.LO(TP,TCH) = 0;
*TEZY.UP(TP,TCH) = +INF;
*TEZY.LO(TPCON(TP,CON))$(TCH_BNDO(CON, 'LO', TP)) = TCH_BNDO(CON, 'LO', TP);
*TEZY.FX(TPCON(TP,CON))$(TCH_BNDO(CON, 'FX', TP)) = TCH_BNDO(CON, 'FX', TP);
*TEZY.UP(TPCON(TP,CON))$(TCH_BNDO(CON, 'UP', TP)) = TCH_BNDO(CON, 'UP', TP);

*===========================================================================*
*  Annual Emissions                                                         *
*===========================================================================*
*GG* V1.0a reset the bounds
*GG* V1.4b adjust the emission bounds by MMSCALE, V1.4f intro ENV_SCAL
EM.UP(TP, ENV) = +INF;
EM.UP(TP, ENV)$(EM_BOUND(ENV, TP)) = EM_BOUND(ENV, TP) * ENV_SCAL;

*===========================================================================*
*  Cumulative Emissions                                                     *
*===========================================================================*
*GG* V1.0d add the ENV cumulative RHS set to unlimited if not defined by user
ENV_CUM(ENV)$(NOT ENV_CUM(ENV)) = +INF;

*===========================================================================*
*GG* V1.4e Tax/Subsidy                                                      *
*===========================================================================*
TXSUB.LO(TP, TAXSUB) = 0;
TXSUB.UP(TP, TAXSUB) = +INF;
TXSUB.LO(TP, TAXSUB)$(TSUB_BND(TAXSUB, 'LO', TP)) = TSUB_BND(TAXSUB,'LO',TP);
TXSUB.FX(TP, TAXSUB)$(TSUB_BND(TAXSUB, 'FX', TP)) = TSUB_BND(TAXSUB,'FX',TP);
TXSUB.UP(TP, TAXSUB)$(TSUB_BND(TAXSUB, 'UP', TP)) = TSUB_BND(TAXSUB,'UP',TP);

