******************************************************************************
*                                                                            *
*   MMCOEF.INC is a pre-processor which establishes the basic coefficients   *
*    that are to be applied for each intersection in the matrix.  Besides    *
*    containing the appropriate coefficients, the structure of the table     *
*    controls most of the intersections created during matrix generation.    *
*                                                                            *
******************************************************************************
*GG* V1.0h change the hardwire .001/1000 scaling to us MMSCALE

******************************************************************************
*                                                                            *
* The ANNC_* tables contain the annualized cost coefficients for the various *
*  vectors.                                                                  *
*                                                                            *
******************************************************************************

*============================================================================*
*  Resource Supply Annual Costs                                              *
*============================================================================*
PARAMETER ANNC_TSEP(TP, SRC, ENT, P) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  ANNC_TSEP(TPSEP(TP,SEP(SRC,ENT,P)))$(NOT LTH(ENT)) = SIGN(SRC)*
                                                      SEP_COST1(SEP, TP) +
*GG* V1.0i add the delvery costs for any input fuels
*   SUM(ENC$(NOT (1$ENU(ENC) OR 1$ECV(ENC) OR 1$ENT(ENC))),
   SUM(ENC$(NOT (1$ENU(ENC) OR 1$ECV(ENC))),
*GG*?check with AM     SUM(ENC$(NOT (1$ENU(ENC) OR 1$ECV(ENC))),
        SEP_INP(SEP, ENC, TP) * SEP_DELIV(SEP, ENC, TP) ) +
    (SEP_INP(SEP, 'ELC', TP) * SEP_DELIV(SEP, 'ELC', TP))$(NOT ELC(ENT)) ;
*GG* V1.0e add O&M for imports of electricity
  ANNC_TSEP(TPSEP(TP,SEP('IMP','ELC',P))) = SEP_COST1(SEP, TP) +
                                            ETRANOM + EDISTOM;

*============================================================================*
*  Stockpiling Annual Costs                                                  *
*============================================================================*
PARAMETER ANNC_ZSTK(TP, ENC, P) / EMPTY.EMPTY.EMPTY 0 /;
  ANNC_ZSTK(TLAST, ENC, P)$(SEP('STK',ENC,P)) = - SEP_STKCOS('STK', ENC, P)

*============================================================================*
*  Variable Costs for Processes, according to activity, other than for       *
*   externally load managed technologies                                     *
*============================================================================*
PARAMETER ANNC_ACT(TP, PRC) / EMPTY.EMPTY 0 /;
  ANNC_ACT(TPPRC(TP,PRC))$(NOT ZPR(PRC)) = (
    TCH_VAROM(PRC, TP) +
    SUM(ENT$(NOT LTH(ENT)),
      TCH_DELIV(PRC, ENT, TP) * PRC_INP2(PRC, ENT, TP) *
      (1 - PRC_LED(PRC, ENT, TP))));

*============================================================================*
*  Annual Costs for Demand Devices, according to capacity's activity         *
*============================================================================*
PARAMETER ANNC_CAP(TP, TCH) / EMPTY.EMPTY 0 /;
  ANNC_CAP(TPDMD(TP,DMD)) = (
    TCH_FIXOM(DMD, TP) + (
*GG* V1.0c Include the variable OM too!
    SUM(ENT$DD_MA(DMD, ENT),
      TCH_DELIV(DMD, ENT, TP) * DMD_MA(DMD, ENT, TP))
      / DMD_EFF(DMD, TP)
      + TCH_VAROM(DMD, TP) )
      * TCH_CAPUNI(DMD) * TCH_CF2(DMD, TP) );

*============================================================================*
*  Fixed Costs for Conversion Technologies, according to capacity,           *
*   other than externally load managed plants                                *
*============================================================================*
  ANNC_CAP(TPCON(TP,CON))$(NOT XLM(CON)) =
    TCH_FIXOM(CON, TP);

*============================================================================*
*  Fixed Costs for Process Technologies, according to capacity,              *
*   other than for externally load managed technologies                      *
*============================================================================*
  ANNC_CAP(TPPRC(TP,PRC))$(NOT ZPR(PRC)) =
    TCH_FIXOM(PRC, TP);

*============================================================================*
*  Annual Costs for Externally Load Managed Processes,                       *
*   according to capacity's activity                                         *
*============================================================================*
  ANNC_CAP(TPPRC(TP,PRC))$ZPR(PRC) = (
    TCH_FIXOM(PRC, TP) +
    TCH_CAPUNI(PRC) * TCH_CF2(PRC, TP) *
    (
      TCH_VAROM(PRC, TP) +
      SUM(ENT$(NOT LTH(ENT)),
        TCH_DELIV(PRC, ENT, TP) * PRC_INP2(PRC, ENT, TP) *
        (1 - PRC_LED(PRC, ENT, TP)))
      ));

*============================================================================*
*  Annual Costs for Externally Load Managed Conversion Technologies,         *
*   according to capacity's activity                                         *
*============================================================================*
  ANNC_CAP(TPCON(TP,XLM)) = (
    SUM((Z, Y),
      TCH_CF1(XLM, Z, Y, TP) * QHR(Z, Y)
    ) *
    TCH_CAPUNI(XLM) *
    (
      TCH_VAROM(XLM, TP) +
*GG* V1.0i allow electricity for heating plants
      SUM(ENT$(NOT LTH(ENT)),
        TCH_DELIV(XLM, ENT, TP) *
        CON_INP1(XLM, ENT, TP)
      ) +
*GG* V1.0e handle heating too
      (ETRANOM$(CEN(XLM)) + EDISTOM$(NOT STG(XLM)))$(NOT HPL(XLM)) +
       DTRANOM$HPL(XLM)
    ) +
    TCH_FIXOM(XLM, TP));

*============================================================================*
*  Variable Costs for Normal Electric Technologies, according to activity    *
*============================================================================*
PARAMETER ANNC_TEZY(TP, TCH, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  ANNC_TEZY(TPELA(TP, ELA), Z, Y)$(NOT ELAXLM(ELA)) = (
    TCH_VAROM(ELA, TP) +
    SUM(ENC$CON_ENC(ELA, ENC),
      TCH_DELIV(ELA, ENC, TP) * CON_INP1(ELA, ENC, TP)
    ) + (ETRANOM$(CEN(ELA)) + EDISTOM)$(NOT STG(ELA)));
*GG* V1.1a adjust storage test (above) over both trans/dist
*GG* V1.1a add the costs for back-pressure heat distribution
  ANNC_TEZY(TPCPD(TP, CENCPD), Z, Y)$CPD_REH(CENCPD) =
    ANNC_TEZY(TP, CENCPD, Z, Y) + DTRANOM/CPD_REH(CENCPD);
*GG* V1.1a adjust for peaking only devices
  ANNC_TEZY(TPELA(TP, ELA), Z, Y)$PEAK_ACT(ELA, Z, Y) = 0;
  ANNC_TEZY(TPCON(TP, BAS), Z, 'N') = 0;
  ANNC_TEZY(TPELA(TP, STG), Z, 'N') = 0;

*============================================================================*
*  Variable Costs for Heating portion of Pass-out Coupled Prod Plants        *
*============================================================================*
*GG* V1.1a add CPD
PARAMETER ANNC_TCZY(TP, TCH, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  ANNC_TCZY(TPCPD(TP, CPD), Z, Y)$CPD_ELM(CPD) = (
    (CPD_CEH(CPD, Z, Y)/CPD_ELM(CPD)) *
    ( TCH_VAROM(CPD, TP) +
      SUM(ENC, TCH_DELIV(CPD, ENC, TP) * CON_INP1(CPD, ENC, TP)) +
      (1 - CPD_ELM(CPD)) * (ETRANOM$CENCPD(CPD) + EDISTOM) ) +
    DTRANOM$CENCPD(CPD) );
  ANNC_TCZY(TPCPD(TP, CPD), Z, 'N')$BAS(CPD) = 0;

*============================================================================*
*  Variable Costs for Normal Heating Plants, according to activity           *
*============================================================================*
*GG* V1.0e added costs for heating XLM plants
PARAMETER ANNC_THZ(TP, TCH, Z) / EMPTY.EMPTY.EMPTY 0 /;
  ANNC_THZ(TPHPL(TP, HPL), Z)$(NOT HPLXLM(HPL)) = (
    TCH_VAROM(HPL, TP) +
*GG* V1.0e handle heating too
    SUM(ENT, TCH_DELIV(HPL, ENT, TP) * CON_INP1(HPL, ENT, TP)) +
    DTRANOM);
*GG* V1.1a adjust for peaking only devices
  ANNC_THZ(TPHPL(TP, HPL), Z)$PEAK_ACT(HPL, Z, 'D') = 0;

******************************************************************************
*                                                                            *
*    The BAL_* tables contain the fuel balance coefficients for other than   *
*     electrity and heat.                                                    *
*                                                                            *
******************************************************************************

*============================================================================*
*  Supply of a Resource, according to whether it is produced or consumed     *
*============================================================================*
*GG* V1.0i introduce the energy carrier related efficiency, + ignore elec
PARAMETER BAL_TSEP(TP, TC, SRC, ENT, P) / EMPTY.EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  BAL_TSEP(TP, TPSEP(TP, SRC, ENC, P)) = SIGN(SRC) * (1$(SIGN(SRC) = -1) +
                                         TEENC(ENC)$(SIGN(SRC) = 1));
  BAL_TSEP(TP, TPSEP(TC, 'STK', ENC, P))$(SEP('STK', ENC, P)) = (
           1$(ORD(TC) EQ ORD(TP)) +
           (-1$( (ORD(TC) EQ (ORD(TP) + 1)) )) ) * TEENC(ENC);

*============================================================================*
*  Input of an Energy Carrier for the Supply of a Resource                   *
*============================================================================*
*GG* V1.0i
PARAMETER BAL_SEPENT(TP, SRC, ENT, P, ENT) / EMPTY.EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  BAL_SEPENT(TPSEP(TP, SRC, ENT, P), ENC)$ (NOT (1$ENU(ENC) OR 1$ECV(ENC))) =
                                              - SEP_INP(SRC, ENT, P, ENC, TP);
  BAL_SEPENT(TPSEP(TP, SRC, ENC, P), 'ELC') = - SEP_INP(SRC, ENC, P, 'ELC', TP);
* don't let the same energy carrier go to itself
  BAL_SEPENT(TPSEP(TP, SRC, ENT, P), ENT) = 0;

*============================================================================*
*  Stockpiling of a Resource in the Final Period                             *
*============================================================================*
*GG* V1.0i introduce the energy carrier related efficiency
PARAMETER BAL_ZSTK(TP, ENC, P) / EMPTY.EMPTY.EMPTY 0 /;
  BAL_ZSTK(TLAST, ENC, P)$(SEP('STK', ENC, P)) = - TEENC(ENC);

*============================================================================*
*    Production or Use of an Energy Carrier for Processes, according to      *
*     activity, for other than externally load managed processes             *
*============================================================================*
*GG* V1.0i introduce the energy carrier related efficiency
PARAMETER BAL_ACT(TP, TC, PRC, ENC) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
*GG* V1.1a improve xeq time by using preprocessor sets
*GG* V1.1c adjust test so that values set for LIMIT processes
  BAL_ACT(TP, TPPRC(TC, PRC), ENC)$(1$(1$(NOT ZPR(PRC)) OR PRC_LIM(PRC, TC)) AND
                                    1$PRC_ENC(PRC, ENC))= (
* current period
    (
      - PRC_INP2(PRC, ENC, TC) * (1 - PRC_LED(PRC, ENC, TC)$(ORD(TP) GT 1)) +
*GG* V1.1a adjust for limit processes
      (1$(PRC_LIM(PRC, TC) AND PRC_OUT(PRC, ENC, TC)) +
         PRC_OUT(PRC, ENC, TC)$(NOT PRC_LIM(PRC, TC))) *
      (1 - PRC_LAG(PRC, ENC, TC)) * TEENC(ENC)
    )$(ORD(TC) EQ ORD(TP)) +
* previous period
    (
      - PRC_INP2(PRC, ENC, TC) * PRC_LED(PRC, ENC, TC)
    )$(ORD(TC) EQ (ORD(TP) + 1)) +
* next period
*GG* V1.1a adjust for limit processes
    (
     (1$(PRC_LIM(PRC, TC) AND PRC_OUT(PRC, ENC, TC)) +
         PRC_OUT(PRC, ENC, TC)$(NOT PRC_LIM(PRC, TC))) *
      PRC_LAG(PRC, ENC, TC) * TEENC(ENC)
    )$ (ORD(TC) EQ (ORD(TP) - 1)) );

*============================================================================*
*    Production or Use of an Energy Carrier for Externally Load Managed      *     *
*     Processes, according to capacity's activity                            *
*============================================================================*
PARAMETER BAL_CAP(TP, TC, TCH, ENC) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
*GG* V1.1a improve xeq time by using preprocessor sets
  BAL_CAP(TP, TPPRC(TC, ZPR), ENC)$PRC_ENC(ZPR, ENC) = (
* current period
     (
      - TCH_CAPUNI(ZPR) * TCH_CF2(ZPR, TC) * PRC_INP2(ZPR, ENC, TC) *
      (1 - PRC_LED(ZPR, ENC, TC)$(ORD(TC) GT 1)) +
*GG* V1.1a adjust for limit processes
      (TCH_CAPUNI(ZPR) * TCH_CF2(ZPR, TC) * PRC_OUT(ZPR, ENC, TC) *
       (1 - PRC_LAG(ZPR, ENC, TC))$(NOT PRC_LIM(ZPR, TC))
     ) * TEENC(ENC)
    )$(ORD(TC) EQ ORD(TP)) +
* previous period
    (
      - TCH_CAPUNI(ZPR) * TCH_CF2(ZPR, TC) * PRC_INP2(ZPR, ENC, TC) *
      PRC_LED(ZPR, ENC, TC)
    )$ (ORD(TC) EQ (ORD(TP)+1)) +
* next period
   (
*GG* V1.1a adjust for limit processes
      (TCH_CAPUNI(ZPR) * TCH_CF2(ZPR, TC) * PRC_OUT(ZPR, ENC, TC) *
       PRC_LAG(ZPR, ENC, TC))$(NOT PRC_LIM(ZPR, TC)) * TEENC(ENC)
    )$ (ORD(TC) EQ (ORD(TP) - 1)) );

*============================================================================*
*    Consumption of an energy carrier by demand devices                      *
*============================================================================*
*GG* V1.1a improve xeq time by using preprocessor sets
  BAL_CAP(TP, TPDMD(TP, DMD), ENC)$DD_MA(DMD, ENC) = (
    - TCH_CAPUNI(DMD) * (DMD_MA(DMD, ENC, TP) / DMD_EFF(DMD, TP)) *
      TCH_CF2(DMD, TP) );

*============================================================================*
*    Production of an energy carrier by demand devices                       *
*============================================================================*
*GG* V1.0i add energy carrier from demand devices
*GG* V1.1a improve xeq time by using preprocessor sets
  BAL_CAP(TP, TPDMD(TP, DMD), ENC)$(1$(NOT DMD_MA(DMD, ENC, TP)) AND
                                       1$DD_MO(DMD, ENC)) = (
      TCH_CAPUNI(DMD) * DMD_MO(DMD, ENC, TP) * TCH_CF2(DMD, TP) *
      TEENC(ENC) );

*============================================================================*
*     Production and Use of an Energy Carrier by Externally Load Managed     *
*      Conversion Technologies, according to capacity's activity             *
*============================================================================*
*GG* V1.0e handle heating too
*GG* V1.0i introduce the energy carrier related efficiency
*GG* V1.1a improve xeq time by using preprocessor sets
  BAL_CAP(TP, TPCON(TP, XLM), ENC)$CON_ENC(XLM, ENC) = (
    TCH_CAPUNI(XLM) *
    SUM((Z, Y),
      TCH_CF1(XLM, Z, Y, TP) * QHR(Z, Y)
    ) *
    ((CON_OUT(XLM, ENC, TP) * TEENC(ENC)) - CON_INP1(XLM, ENC, TP))
  );

*============================================================================*
*  Use of an Energy Carrier Based Upon Investment in Conversion Technologies *
*============================================================================*
PARAMETER BAL_INV(TP, TC, TCH, ENC) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  BAL_INV(TP, TPCON(TC, CON), ENC)$(CON_INP2(CON, ENC)  AND
                           (TCH_LIFE(CON) AND (ORD(TC) EQ (ORD(TP) + 1)))) =
    - CON_INP2(CON, ENC) / NYRSPER;


*============================================================================*
*     Production and Use of an Energy Carrier by Electric Conversion Plants, *
*      according to activity, other than externally load managed plants      *
*============================================================================*
*GG* V1.0i introduce the energy carrier related efficiency
*GG* V1.1a improve xeq time by using preprocessor sets
PARAMETER BAL_TEZY(TP, TCH, ENC, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  BAL_TEZY(TPELA(TP, ELA), ENC, Z, Y)$(1$(NOT ELAXLM(ELA)) AND
                                       1$CON_ENC(ELA, ENC)) = (
    - CON_INP1(ELA, ENC, TP) + (CON_OUT(ELA, ENC, TP) * TEENC(ENC))
  );
*GG* V1.1a adjust for peaking only devices
  BAL_TEZY(TPELA(TP, ELA), ENC, Z, Y)$PEAK_ACT(ELA, Z, Y) = 0;
  BAL_TEZY(TPELA(TP, ELABAS), ENC, Z, 'N')$CON_ENC(ELABAS, ENC) = 0;
  BAL_TEZY(TPELA(TP, ELASTG), ENC, Z, 'N') = 0;

*============================================================================*
*     Production and Use of an Energy Carrier by Couple Production Pass-out  *
*      turbines                                                              *
*============================================================================*
*GG* V1.1a add CPD, V1.1c change declare for reports
PARAMETER BAL_TCZY(TP, CON, ENC, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  BAL_TCZY(TPCPD(TP, CPD), ENC, Z, Y)$(1$CPD_ELM(CPD) AND
                                       1$CON_ENC(CPD, ENC)) = (
    (- CON_INP1(CPD, ENC, TP) + CON_OUT(CPD, ENC, TP) * TEENC(ENC)) *
    (CPD_CEH(CPD, Z, Y)/CPD_ELM(CPD)) );
  BAL_TCZY(TPCPD(TP, CPD), ENC, Z, 'N')$BAS(CPD) = 0;

*============================================================================*
*     Production and Use of an Energy Carrier by Heating Conversion Plants,  *
*      according to activity, other than externally load managed plants      *
*============================================================================*
*GG* V1.0e add heating plants, V1.1c change declare for reports
PARAMETER BAL_THZ(TP, CON, ENT, Z) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  BAL_THZ(TPHPL(TP, HPL), ENC, Z)$(1$(NOT HPLXLM(HPL)) AND
                                   1$CON_ENC(HPL, ENC)) = (
    - CON_INP1(HPL, ENC, TP) + CON_OUT(HPL, ENC, TP) *TEENC(ENC) );
*GG* V1.1a add transmission eff. of energy carrier to outputs (above)
*GG* V1.1a adjust for peaking only devices
  BAL_THZ(TPHPL(TP, HPL), ENC, Z)$PEAK_ACT(HPL, Z, 'D') = 0;

******************************************************************************
*                                                                            *
*     Production and Use of Heat                                             *
*                                                                            *
******************************************************************************

*============================================================================*
* Production of Heat, according to activity, for other than externally load  *
*  managed plants                                                            *
*============================================================================*
PARAMETER BALH_THZ(TP, HPL, Z) / EMPTY.EMPTY.EMPTY 0 /;
  BALH_THZ(TPHPL(TP, HPL), Z)$(NOT HPLXLM(HPL)) = 1;
*GG* V1.1a adjust for peaking only devices
  BALH_THZ(TPHPL(TP, HPL), Z)$PEAK_ACT(HPL, Z, 'D') = 0;

*============================================================================*
* Production of Heat, from Coupled Production Plants                         *
*  - Pass-out turbine                                                        *
*  - Back-pressure turbine                                                   *
*============================================================================*
*GG* V1.1a add CPD
PARAMETER BALH_TCZY(TP, CPD, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  BALH_TCZY(TPCPD(TP, CPD), Z, Y)$CPD_ELM(CPD) =
    (CPD_TEFF(CPD, Z, Y)$CENCPD(CPD) + 1$DCNCPD(CPD));
  BALH_TCZY(TPCPD(TP, CPD), Z, Y)$CPD_REH(CPD) =
    (CPD_TEFF(CPD, Z, Y)$CENCPD(CPD) + 1$DCNCPD(CPD)) / CPD_REH(CPD);
  BALH_TCZY(TPCPD(TP, CPD), Z, 'N')$BAS(CPD) = 0;

*============================================================================*
* Production of Heat by Externally Load Managed Plants, according to         *
*  capacity's activity                                                       *
*============================================================================*
*GG* V1.0e add heating plants
PARAMETER BALH_CAP(TP, TC, TCH, Z) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  BALH_CAP(TP, TPHPL(TP, HPLXLM), Z) = (
    TCH_CAPUNI(HPLXLM) * SUM(Y, TCH_CF1(HPLXLM, Z, Y, TP) * QHR(Z, Y))
  ) ;

*============================================================================*
* Use of Heat by Demand Devices                                              *
*============================================================================*
  BALH_CAP(TP, TPDMD(TP, DMD), Z)$DD_MA(DMD, 'LTH') = (
      - TCH_CAPUNI(DMD) *
  SUM((DM,Y)$(1$DMD_DM(DMD, DM) AND (DM_FR(DM,Z,Y) NE EPS)), DM_FR(DM, Z, Y)) *
      DMD_MA(DMD, 'LTH', TP)  / (DHDE(Z)* DMD_EFF(DMD, TP)) * TCH_CF2(DMD, TP)
  ) ;

******************************************************************************
*                                                                            *
*     Production and Use of Electricity                                      *
*                                                                            *
******************************************************************************

*============================================================================*
* Use of Electricity by Externally Load Managed Processes, according to      *
*  capacity's activity                                                       *
*============================================================================*
PARAMETER BALE_CAP(TP, TC, TCH, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY.EMPTY 0 /;
*GG* V1.1a improve xeq time by using preprocessor sets
  BALE_CAP(TP, TPZPR(TC, ZPR), Z, Y)$PRC_ELC(ZPR, 'ELC') = (
    (
      - TCH_CAPUNI(ZPR) * TCH_CF2(ZPR, TC) * PRC_INP2(ZPR, 'ELC', TC) *
      QHR(Z, Y) * (1 - PRC_LED(ZPR, 'ELC', TC)$(ORD(TC) GT 1))
    )$(ORD(TC) EQ ORD(TP)) +
    (
      - TCH_CAPUNI(ZPR) * TCH_CF2(ZPR, TC) * PRC_INP2(ZPR, 'ELC', TC) *
      QHR(Z, Y) * PRC_LED(ZPR, 'ELC', TC)
    )$ (ORD(TC) EQ (ORD(TP) + 1)));

*============================================================================*
* Use of Electricity by Externally Load Managed Heating Plants, according    *
*  to capacity's activity                                                    *
*============================================================================*
*GG* V1.0i added
  BALE_CAP(TP, TPHPL(TP, HPLXLM), Z, Y) = (
      - TCH_CAPUNI(HPLXLM) * TCH_CF1(HPLXLM, Z, Y, TP) *
        CON_INP1(HPLXLM, 'ELC', TP) * QHR(Z, Y)
    );

*============================================================================*
* Use of Electricity by Externally Load Managed Night Storage Processes,     *
*  according to capacity's activity                                          *
*============================================================================*
*GG* V1.0e only night requirements for night storage devices
  BALE_CAP(TP, TPZPR(TC, PRCNST), Z, 'N') = BALE_CAP(TP, TC, PRCNST, Z, 'N') +
                                            BALE_CAP(TP, TC, PRCNST, Z, 'D');
  BALE_CAP(TP, TPZPR(TC, PRCNST), Z, 'D') = 0;

*============================================================================*
* Production of Electricity by Externally Load Managed Conversion Plants     *
*  according to capacity's activity                                          *
*   - Centralized plants                                                     *
*   - Decentralized plants                                                   *
*============================================================================*
*GG* V1.1a adjust to use CEN/DCN transmission efficiency
  BALE_CAP(TP, TPELAXLM(TP, ELAXLM), Z, Y) =
    ( TE_CON(ELAXLM) * TCH_CAPUNI(ELAXLM) * TCH_CF1(ELAXLM, Z, Y, TP)
      * QHR(Z, Y) );
*  BALE_CAP(TP, TPELAXLM(TP, ELAXLM), Z, Y)$DCN(ELAXLM) =
*    ( TCH_CAPUNI(ELAXLM) * TCH_CF1(ELAXLM, Z, Y, TP) * QHR(Z, Y)
*    );

*============================================================================*
* Production & Use of Electricity by Externally Load Managed Storage         *
*  Facilities, according to capacity's activity                              *
*============================================================================*
*GG* V0.8 add pumped storage
  BALE_CAP(TP, TPELA(TP, ELAXLMSTG), Z, 'D') = ( TE *
    TCH_CAPUNI(ELAXLMSTG) * TCH_CF1(ELAXLMSTG, Z, 'D', TP) * QHR(Z, 'D')
    ) * CON_INP1(ELAXLMSTG, 'ELC', TP);
  BALE_CAP(TP, TPELA(TP, ELAXLMSTG), Z, 'N') = ( -TE *
    TCH_CAPUNI(ELAXLMSTG) * TCH_CF1(ELAXLMSTG, Z, 'D', TP) * QHR(Z, 'D')
    ) * CON_INP1(ELAXLMSTG, 'ELC', TP);

*============================================================================*
* Use of Electricity by Demand Technologies, according to capacity's activity*
*============================================================================*
*GG* V1.0e only if no EPS
  BALE_CAP(TP, TPDMD(TP, DMD), Z, Y)$DD_MA(DMD, 'ELC') = (
    - TCH_CAPUNI(DMD) * SUM(DM$(1$DMD_DM(DMD, DM) AND (DM_FR(DM,Z,Y) NE EPS)),
                            DM_FR(DM, Z, Y) *
    (DMD_MA(DMD, 'ELC', TP) / DMD_EFF(DMD, TP)) * TCH_CF2(DMD, TP)) );

*============================================================================*
* Use of Electricity by Night Storage Demand Technologies                    *
*============================================================================*
*GG* V1.0e only night requirements for night storage devices
  BALE_CAP(TP, TPDMD(TP, DMDNST), Z, 'N') = BALE_CAP(TP, TP, DMDNST, Z, 'N') +
                                            BALE_CAP(TP, TP, DMDNST, Z, 'D');
  BALE_CAP(TP, TPDMD(TP, DMDNST), Z, 'D') = 0;

*============================================================================*
* Use of Electricity by Process, according to activity, for other than       *
*  externally load managed processes                                         *
*============================================================================*
*GG* add electric balance for processes NOT in XPR and STG
PARAMETER BALE_ACT(TP, TC, PRC, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY.EMPTY 0 /;
*GG* V1.1a improve xeq time by using preprocessor sets
  BALE_ACT(TP, TPPRC(TC, PRC), Z, Y)$(1$(NOT ZPR(PRC)) AND
                                      1$PRC_ELC(PRC, 'ELC')) = (
* current period
    (
      - PRC_INP2(PRC, 'ELC', TC) * QHR(Z, Y) *
      (1 - PRC_LED(PRC, 'ELC', TC)$(ORD(TC) GT 1))
    )$(ORD(TC) EQ ORD(TP)) +
* previous period
    (
      - PRC_INP2(PRC, 'ELC', TC) * QHR(Z, Y) *
      PRC_LED(PRC, 'ELC', TC)
    )$ (ORD(TC) EQ (ORD(TP) + 1)));

*============================================================================*
* Use of Electricity by Night Storage Processes, according to activity       *
*============================================================================*
*GG* V1.0e adjust the night storage processes
  BALE_ACT(TP, TPPRC(TC, PRCNST), Z, 'N')$(NOT ZPR(PRCNST)) =
                                            BALE_ACT(TP, TC, PRCNST, Z, 'N') +
                                            BALE_ACT(TP, TC, PRCNST, Z, 'D');
  BALE_ACT(TP, TPPRC(TC, PRCNST), Z, 'D') = 0;

*============================================================================*
* Use of Electricity by Heating Plants, according to activity                *
*============================================================================*
PARAMETER BALE_HPL(TP, TCH, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  BALE_HPL(TPHPL(TP, HPL), Z, Y)$(1$(NOT HPLXLM(HPL)) AND
                                  1$CON_ELC(HPL, 'ELC'))  = (
           - CON_INP1(HPL, 'ELC', TP) * QHR(Z, Y) / QHRZ(Z)
      );
*GG* V1.1a adjust for peaking only devices
  BALE_HPL(TPHPL(TP, HPL), Z, Y)$PEAK_ACT(HPL, Z, Y) = 0;

*============================================================================*
* Procuction of Electricity, according to activity                           *
*  - Centralized Plants                                                      *
*  - Decentralized Plants                                                    *
*  - Baselaod Plants                                                         *
*============================================================================*
PARAMETER BALE_TEZY(TP, TCH, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
*GG* V1.1a adjust to use CEN/DCN transmission efficiency
  BALE_TEZY(TPELA(TP, ELA), Z, Y)$(NOT ELABAS(ELA)) = TE_CON(ELA);
*  BALE_TEZY(TPELA(TP, ELADCN), Z, Y) = 1.0;
*  BALE_TEZY(TPELA(TP, ELABAS), Z, Y) = 0;
*GG* V1.1c do the decentralized too and use the appropriate trans. eff.
  BALE_TEZY(TPELA(TP, ELABAS), Z, Y) = ( TE_CON(ELABAS) * QHR(Z, Y) / QHRZ(Z) );
*GG* V1.0i use the seasonal total parameter (above)

*============================================================================*
* Procuction & Use of Electricity by Storage Facilities, according to        *
*  activity                                                                  *
*============================================================================*
*GG* V0.8 handle pumped storage
*GG* V1.1a remove the elaxlmstg test as xlm nulled below
  BALE_TEZY(TPELA(TP, STG), Z, 'D') = TE;
  BALE_TEZY(TPELA(TP, STG), Z, 'N') = (-TE * CON_INP1(STG, 'ELC', TP) );

* null out any externally load managed plants
  BALE_TEZY(TPELA(TP, ELAXLM), Z, Y) = 0;

*GG* V1.1a adjust for peaking only devices
  BALE_TEZY(TPELA(TP, ELA), Z, Y)$PEAK_ACT(ELA, Z, Y)=0;

*============================================================================*
* Procuction of Electricity from Coupled Production pass-out turbines        *
*============================================================================*
*GG* V1.1a add CPD
*GG* V1.1a adjust to use CEN/DCN transmission efficiency
PARAMETER BALE_TCZY(TP, TCH, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  BALE_TCZY(TPCPD(TP, CPD), Z, Y)$CPD_ELM(CPD) = (
    TE_CON(CPD) * CPD_CEH(CPD, Z, Y) * (1 - CPD_ELM(CPD)) / CPD_ELM(CPD) ) *
    (1$(NOT BAS(CPD)) + (QHR(Z, Y)/QHRZ(Z))$BAS(CPD)) ;

*============================================================================*
* Import and Export of Electricity                                           *
*============================================================================*
*GG* V1.0e add import/export of electricity
PARAMETER BALE_SEP(TP, SRC, ENT, P, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY.EMPTY.EMPTY 0 /;
*GG* V1.0i use the seasonal total parameter
  BALE_SEP(TPSEP(TP, 'EXP', 'ELC', P), Z, Y)$(1$IMPEXPELC('EXP',P) AND
                                              1$QHRZ(Z)) =
   - (QHR(Z, Y)$(NOT SEP_FR('EXP', P, Z, Y)) +
   SEP_FR('EXP', P, Z, Y)$(SEP_FR('EXP', P, Z, Y) NE EPS));
  BALE_SEP(TPSEP(TP, 'IMP', 'ELC', P), Z, Y)$(1$IMPEXPELC('IMP',P) AND
                                              1$QHRZ(Z)) =
     (QHR(Z, Y)$(NOT SEP_FR('IMP', P, Z, Y)) +
     SEP_FR('IMP', P, Z, Y)$(SEP_FR('IMP', P, Z, Y) NE EPS)) * TE;

******************************************************************************
*                                                                            *
* Electricity Base-load Day/Night Relationship                               *
*                                                                            *
******************************************************************************

*============================================================================*
* Non-Base-load Electricity at Night by Externally Load Managed Plants,      *
*  according to capacity's activity                                          *
*  - Decentralized                                                           *
*  - Centralized                                                             *
*============================================================================*
PARAMETER BAS_CAP(TP, TCH, Z) / EMPTY.EMPTY.EMPTY 0 /;
*GG* V1.1a use the CEN/DCN transmission efficiency
  BAS_CAP(TPELAXLM(TP, ELAXLM), Z) = (
    - TCH_CAPUNI(ELAXLM) * TCH_CF1(ELAXLM, Z, 'N', TP) * QHR(Z, 'N') *
      BASELOAD * TE_CON(ELAXLM) );
*  BAS_CAP(TPELAXLM(TP, ELAXLM), Z)$(CEN(ELAXLM)) = BAS_CAP(TP, ELAXLM, Z) * TE;

*============================================================================*
* Base-load Electricity at Night by Externally Load Managed Plants,          *
*  according to capacity's activity                                          *
*============================================================================*
  BAS_CAP(TPELAXLM(TP, ELAXLM), Z)$(BAS(ELAXLM)) = (
    TCH_CAPUNI(ELAXLM) * TCH_CF1(ELAXLM, Z, 'N', TP) * QHR(Z, 'N') *
    (1 - BASELOAD) * TE_CON(ELAXLM));

*============================================================================*
* Base-load Electricity at Night by Conversion Technologies, according to    *
*  activity                                                                  *
*  - Centralized                                                             *
*  - Decentralized                                                           *
*============================================================================*
PARAMETER BAS_TEZY(TP, TCH, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
*GG* V1.0i use the seasonal total parameter
*GG* V1.1a use the CEN/DCN transmission efficiency
*GG* V1.1a make adjustment for no XLM
  BAS_TEZY(TPELA(TP, ELABAS), Z, 'D')$(NOT ELAXLM(ELABAS)) = (
    (1 - BASELOAD) * QHR(Z, 'N') * TE_CON(ELABAS) / QHRZ(Z) );
*  BAS_TEZY(TPELA(TP, ELABASDCN), Z, 'D') = (
*    (1 - BASELOAD) * QHR(Z, 'N') / QHRZ(Z) );

*============================================================================*
* Non-Base-load Electricity at Night by Conversion Technologies, according   *
*  to activity                                                               *
*  - Centralized                                                             *
*  - Decentralized                                                           *
*  - Except for Externally Load Managed, Storage or Base Plants              *
*GG*@ move TE into one statement according to DCN/CEN                        *
*============================================================================*
*GG* V1.0 add adjustment for NLMs, eg co-gen
*GG* V1.1a use the CEN/DCN transmission efficiency
  BAS_TEZY(TPELA(TP, ELA), Z, 'N')$(NOT ELAXLM(ELA)) =
     (1$(NLM(ELA)) - BASELOAD) * TE_CON(ELA);
*  BAS_TEZY(TPELA(TP, ELADCN), Z, 'N') = (1$(NLM(ELADCN)) - BASELOAD);
*  BAS_TEZY(TPELA(TP, ELAXLM), Z, 'N') = 0;
  BAS_TEZY(TPELA(TP, ELASTG), Z, 'N') = 0;
  BAS_TEZY(TPELA(TP, ELABAS), Z, 'N') = 0;
  BAS_TEZY(TPELA(TP, ELA), Z, 'N')$PEAK_TID(ELA) = 0;

*============================================================================*
* Base-load Electricity from Coupled Production Pass-out Turbines            *
*   - Pass-out turbines, base-load                                           *
*   - Pass-out turbines, non base-load                                       *
*   - Pass-out turbines that can not follow the load (are non-load managed)  *
*============================================================================*
*GG* V1.1a add CPD
*GG* V1.1a use the CEN/DCN transmission efficiency
PARAMETER BAS_TCZY(TP, TCH, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  BAS_TCZY(TPCPD(TP, CPDBAS), Z, 'D')$CPD_ELM(CPDBAS) = (
    CPD_CEH(CPDBAS, Z, 'D') * ((1-CPD_ELM(CPDBAS))/CPD_ELM(CPDBAS)) *
    (1 - BASELOAD) * QHR(Z, 'N') * TE_CON(CPDBAS) /
     QHRZ(Z) );
  BAS_TCZY(TPCPD(TP, CPD), Z, 'N')$(1$(NOT CPDBAS(CPD)) AND CPD_ELM(CPD))  = (
    - BASELOAD * CPD_CEH(CPD, Z, 'N') * TE_CON(CPD) *
    (1-CPD_ELM(CPD))/CPD_ELM(CPD) );
  BAS_TCZY(TPCPD(TP, CPD), Z, 'N')$(1$NLM(CPD) AND CPD_ELM(CPD)) = (
    (1 - BASELOAD) * CPD_CEH(CPD, Z, 'N') *
    TE_CON(CPD) * (1-CPD_ELM(CPD)) / CPD_ELM(CPD) );

*============================================================================*
*  Night Fraction of Electricity Imports/Exports                             *
*============================================================================*
*GG* V1.0e add import/export of electricity
PARAMETER BAS_SEP(TP, SRC, ENT, P, Z) / EMPTY.EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  BAS_SEP(TPSEP(TP, 'IMP', 'ELC', P), Z)$(1$IMPEXPELC('IMP', P) AND
                                          1$QHRZ(Z)) =
      (1 - BASELOAD) * (QHR(Z, 'N') $ (NOT SEP_FR('IMP', P, Z, 'N')) +
       SEP_FR('IMP', P, Z, 'N')$(SEP_FR('IMP', P, Z, 'N') NE EPS)) * TE;

  BAS_SEP(TPSEP(TP, 'EXP', 'ELC', P), Z)$(1$IMPEXPELC('EXP', P) AND
                                          1$QHRZ(Z)) =
      (BASELOAD - 1) * (QHR(Z, 'N') $ (NOT SEP_FR('EXP', P, Z, 'N')) +
               SEP_FR('EXP', P, Z, 'N')$(SEP_FR('EXP', P, Z, 'N') NE EPS));

*============================================================================*
*  Add bounds on the combined output of Electric Generation Plants           *
*============================================================================*
*GG* V1.1a add for PEAKing only devices
PARAMETER BND_TEZY(TP, CON, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  BND_TEZY(TPELA(TP, ELA), Z, Y)$(NOT ELAXLM(ELA)) = 1;
  BND_TEZY(TPELA(TP, ELABAS), Z, 'N') = 0;
  BND_TEZY(TPELA(TP, STG), Z, 'N') = 0;
  BND_TEZY(TPELA(TP, ELA), Z, Y)$PEAK_ACT(ELA, Z, Y) = 0;

*============================================================================*
*  Add bounds on the combined output of Couple Production Pass-out Turbines  *
*============================================================================*
*GG* V1.1a add CPD
PARAMETER BND_TCZY(TP, CON, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  BND_TCZY(TPCPD(TP, CPD), Z, Y)$CPD_ELM(CPD) = (
      CPD_CEH(CPD, Z, Y) / CPD_ELM(CPD) );
  BND_TCZY(TPCPD(TP, CPDBAS), Z, 'N') = 0;

*============================================================================*
*  Add bounds on the combined output of Heating Generation Plants            *
*============================================================================*
*GG* V1.1a add for PEAKing only devices
PARAMETER BND_THZ(TP, CON, Z) / EMPTY.EMPTY.EMPTY 0 /;
  BND_THZ(TPHPL(TP, HPL), Z)$(NOT HPLXLM(HPL)) = 1;
  BND_THZ(TPHPL(TP, HPL), Z)$PEAK_ACT(HPL, Z, 'D') = 0;

******************************************************************************
*                                                                            *
* Capacity Transfer Relationship                                             *
*                                                                            *
******************************************************************************

*============================================================================*
*  Capacity In the Current Period                                            *
*============================================================================*
PARAMETER CPT_CAP(TP, TCH) / EMPTY.EMPTY 0 /;
  CPT_CAP(TPTCH(TP, TCH))$TCH_LIFE(TCH) = 1.0;

*============================================================================*
*  Investments Still Available in the Current Time Period, LIFE not done     *
*============================================================================*
PARAMETER CPT_INV(TP, TC, TCH) / EMPTY.EMPTY.EMPTY 0 /;
  CPT_INV(TP, TPTCH(TC, TCH))$( TCH_LIFE(TCH) AND (
    (ORD(TC) GE (ORD(TP) - TCH_LIFE(TCH) + 1)) AND
    (ORD(TC) LE ORD(TP)) AND
    (ORD(TC) GE 1))) = -1.0;

*============================================================================*
*GG* V1.1c handle fractional lifes
*============================================================================*
  CPT_INV(TP, TPTCH(TC, TCH))$(TCH_LIFE(TCH) AND (
    (FLOOR(TCH_LIFE(TCH)) NE TCH_LIFE(TCH)) AND
    (ORD(TC) + FLOOR(TCH_LIFE(TCH)) EQ ORD(TP)) AND
    (ORD(TC) GE 1))) = -(TCH_LIFE(TCH)-FLOOR(TCH_LIFE(TCH)));

******************************************************************************
*                                                                            *
* Cumulative Resource Availability Constraint                                *
*                                                                            *
******************************************************************************

*============================================================================*
*  Total Quantity of a Resource Produced in a Time Period                    *
*============================================================================*
PARAMETER CUM_TSEP(TP, SRC, ENT, P) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  CUM_TSEP(TPSEP(TP, SEP))$(SEP_CUM(SEP)) = NYRSPER;
  CUM_TSEP(TP, 'STK', ENC, P) = 0;

******************************************************************************
*                                                                            *
* Output Energy from a Demand Device to a Demand Sector                      *
*                                                                            *
******************************************************************************

PARAMETER DEM_CAP(TP, DMD, DM) / EMPTY.EMPTY.EMPTY 0 /;
*GG* v1.0i allow for output to other DMs
*GG* V1.1a use the preprocess set to speed xeq
  DEM_CAP(TPDMD(TP, DMD), DM)$DMD_DMS(DMD, DM) =
    TCH_CAPUNI(DMD) * TCH_CF2(DMD, TP) * DMD_OUT(DMD, DM, TP) ;

******************************************************************************
*                                                                            *
* Electricity Activity/Available Capacity Constraint                         *
*                                                                            *
******************************************************************************

*============================================================================*
* Electricity Generation by Conversion Plants, other than for externally     *
*  load managed facilities                                                   *
*  - Null Out Base and Storage Night-time                                    *
*============================================================================*
PARAMETER TEZY_TEZY(TP, TCH, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  TEZY_TEZY(TPELA(TP, ELA), Z, Y)$(NOT ELAXLM(ELA)) = 1.0;
  TEZY_TEZY(TPELA(TP, ELABAS), Z, 'N') = 0;
  TEZY_TEZY(TPELA(TP, ELASTG), Z, 'N') = 0;
*  TEZY_TEZY(TPELA(TP, ELA), Z, Y)$PEAK_ACT(ELA, Z, Y) =  0;

*============================================================================*
* Coupled Production Pass-out Turbines electricity generation                *
*============================================================================*
*GG* V1.1a add CPDs
PARAMETER TEZY_TCZY(TP, TCH, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  TEZY_TCZY(TPCPD(TP, CPD), Z, Y)$CPD_ELM(CPD) = (
      CPD_CEH(CPD, Z, Y) / CPD_ELM(CPD) );
*GG* V1.4a null out base-loads
  TEZY_TCZY(TPCPD(TP, CPDBAS), Z, 'N') = 0;

*============================================================================*
* Electric Conversion Plants Available Capacity                              *
*  - Non-base-load Plants                                                    *
*  - Base-load Plants                                                        *
*  - Null Out Externally Load Managed Plants and Storage Night-time          *
*============================================================================*
PARAMETER TEZY_CAP(TP, TCH, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  TEZY_CAP(TPELA(TP, ELA), Z, Y)$(NOT ELABAS(ELA)) = (
    (
      - TCH_CAPUNI(ELA) * QHR(Z, Y) * TCH_AF3(ELA, Z, Y, TP)
    )$(NOT TCH_AF1(ELA, TP)) +
    (
      - TCH_CAPUNI(ELA) * QHR(Z, Y) *
      (
        1 - (1 - TCH_AF1(ELA, TP)) *
        (
          TCH_AF2(ELA)$TCH_AF2(ELA) +
          1$(NOT TCH_AF2(ELA))
        )
      )
    )$TCH_AF1(ELA, TP) );

*GG* V1.0i use the seasonal total parameter
  TEZY_CAP(TPELA(TP, ELABAS), Z, 'D') = (
    (
      - TCH_CAPUNI(ELABAS) * QHRZ(Z) *
      TCH_AF3(ELABAS, Z, 'D', TP)
    )$(NOT TCH_AF1(ELABAS, TP)) +
    (
      - TCH_CAPUNI(ELABAS) * QHRZ(Z) *
      (
        1 - (1 - TCH_AF1(ELABAS, TP)) *
        (
          TCH_AF2(ELABAS)$TCH_AF2(ELABAS) +
          1$(NOT TCH_AF2(ELABAS))
        )
      )
    )$TCH_AF1(ELABAS, TP));
*GG* V1.1a handle the PEAKing only devices
  TEZY_CAP(TPELA(TP, ELA), Z ,Y)$PEAK_TID(ELA) = - TCH_CAPUNI(ELA) * QHR(Z, Y) *
    TCH_PD(ELA, Z, TP);
  TEZY_CAP(TPELA(TP, ELAXLM), Z, Y) = 0;
  TEZY_CAP(TPELA(TP, ELASTG), Z, 'N') = 0;
*GG* V1.0i null out any values where a limited set of AFs are provided
*  TEZY_CAP(TPELA(TP, ELA), Z, Y)$((NOT TCH_AF1(ELA, TP)) AND
*          (NOT TCH_AF3(ELA, Z, Y, TP)) AND SUM(TD, TCH_AF3(ELA, TD, TP))) = 0;

******************************************************************************
*                                                                            *
* Scheduled Maintenance for Electric Conversion Plants                       *
*                                                                            *
******************************************************************************

*============================================================================*
* Scheduled Maintenance by Conversion Plants for Utilization Equaiton        *
*   - Most Plants                                                            *
*   - Not Externally Load-managed Plants                                     *
*============================================================================*
*GG* V1.1a added maintenance
PARAMETER TUTL_CON(TP, TCH) / EMPTY.EMPTY 0 /;
  TUTL_CON(TPCON(TP, CON))$
    (TCH_AF1(CON, TP) AND TCH_AF2(CON) AND (TCH_AF2(CON) NE 1)) =
    - ( (1-TCH_AF1(CON, TP)) * (1-TCH_AF2(CON)) ) * TCH_CAPUNI(CON) ;
  TUTL_CON(TPCON(TP, XLM)) = 0;

*============================================================================*
* Scheduled Maintenance by Electric Plants for Capacity/Production Equation  *
*   - Most Plants                                                            *
*   - Base-load Plants                                                       *
*   - Storage Plants not at night                                            *
*============================================================================*
*GG* V1.1a added maintenance
PARAMETER TEZY_TEZYM(TP, TCH, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  TEZY_TEZYM(TPELA(TP, ELA), Z, Y)$TUTL_CON(TP, ELA) = QHR(Z,Y) / QHRZ(Z);
  TEZY_TEZYM(TPELA(TP, ELABAS), Z, 'D')$TUTL_CON(TP, ELABAS) = 1.0;
  TEZY_TEZYM(TPELA(TP, ELABAS), Z, 'N') = 0;
  TEZY_TEZYM(TPELA(TP, STG), Z, 'N') = 0;

******************************************************************************
*                                                                            *
* Heat Activity/Available Capacity Constraint                                *
*                                                                            *
******************************************************************************

*============================================================================*
* Heat Generation by Conversion Plants, other than for externally load       *
*  managed facilities                                                        *
*============================================================================*
*GG* V1.0e add heating
PARAMETER THZ_THZ(TP, TCH, Z) / EMPTY.EMPTY.EMPTY 0 /;
  THZ_THZ(TPHPL(TP, HPL), Z)$(NOT HPLXLM(HPL)) = 1.0;

*============================================================================*
* Heating Conversion Plants Available Capacity, other than for externally    *
*  load managed facilities                                                   *
*============================================================================*
*GG* V1.0e heating plants
PARAMETER THZ_CAP(TP, TCH, Z) / EMPTY.EMPTY.EMPTY 0 /;
*GG* V1.0i not needed for XLMs
  THZ_CAP(TPHPL(TP, HPL), Z)$(NOT HPLXLM(HPL)) = (
    (
      - TCH_CAPUNI(HPL) * SUM(Y, QHR(Z, Y)) * TCH_AF3(HPL, Z, 'D', TP)
    )$(NOT TCH_AF1(HPL, TP)) +
    (
      - TCH_CAPUNI(HPL) * SUM(Y, QHR(Z, Y)) *
      (
        1 - (1 - TCH_AF1(HPL, TP)) *
        (
          TCH_AF2(HPL)$(TCH_AF2(HPL)) +
          1$(NOT TCH_AF2(HPL))
        )
      )
    )$(TCH_AF1(HPL, TP))
  );
*GG* V1.1a adjust for PEAKing only devices
  THZ_CAP(TPHPL(TP, HPL), Z)$PEAK_TID(HPL) = (
    - TCH_CAPUNI(HPL) * QHRZ(Z) * TCH_PD(HPL, 'W', TP) );

******************************************************************************
*                                                                            *
* Environmental Constraints                                                  *
*                                                                            *
******************************************************************************

*============================================================================*
* Emissions Coefficient Associated with Resource Activity                    *
*============================================================================*
PARAMETER TENV_TSEP(TP, SRC, ENT, P, ENV) / EMPTY.EMPTY.EMPTY.EMPTY.EMPTY 0 /;
*GG* V1.1a use the preprocessor sets to speed xeq
  TENV_TSEP(TPSEP(TP, SEP), ENV)$ENV_S(ENV, SEP) = ENV_TSEP(ENV, SEP, TP);

*============================================================================*
* Emissions Coefficient Associated with Supply Side Technologies Activity,   *
*  other than for externally load managed facilities                         *
*  - Processes                                                               *
*============================================================================*
PARAMETER TENV_TACT(TP, TCH, ENV) / EMPTY.EMPTY.EMPTY 0 /;
*GG* V1.0g adjust for XPR and XLM
  TENV_TACT(TPPRC(TP,PRC),ENV)$(NOT ZPR(PRC)) = ENV_TACT(ENV,PRC,TP);

*============================================================================*
* Emissions Coefficient Associated with Supply Side Technologies Activity,   *
*  other than for externally load managed facilities                         *
*  - Electricity Plants                                                      *
*============================================================================*
PARAMETER TENV_TEZY(TP, TCH, Z, Y, ENV) / EMPTY.EMPTY.EMPTY.EMPTY.EMPTY 0 /;
*GG* V1.1a adjust for PEAKing only devices
  TENV_TEZY(TPELA(TP,ELA), Z, Y, ENV)$(NOT ELAXLM(ELA)) = ENV_TACT(ENV,ELA,TP);
  TENV_TEZY(TPELA(TP,ELA), Z, Y, ENV)$PEAK_ACT(ELA, Z, Y) = 0;
  TENV_TEZY(TPELA(TP, ELABAS), Z, 'N', ENV) = 0;
  TENV_TEZY(TPELA(TP, STG), Z, 'N', ENV) = 0;

*============================================================================*
* Emissions Coefficient Associated with Supply Side Technologies Activity,   *
*  other than for externally load managed facilities                         *
*  - Heating Plants                                                          *
*============================================================================*
PARAMETER TENV_THZ(TP, TCH, Z, ENV) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
*GG* V1.1a adjust for PEAKing only devices
  TENV_THZ(TPHPL(TP,HPL),Z,ENV)$(NOT HPLXLM(HPL)) = ENV_TACT(ENV,HPL,TP);
  TENV_THZ(TPHPL(TP,HPL), Z, ENV)$PEAK_ACT(HPL, Z, 'D') = 0;

*============================================================================*
* Emissions Coefficient Associated with Coupled Production Pass-out Turbines *
*============================================================================*
*GG* V1.1a add CPDs, V1.1c change declaration for reports to CON
PARAMETER TENV_TCZY(TP, CON, Z, Y, ENV) / EMPTY.EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  TENV_TCZY(TPCPD(TP,CPD), Z, Y, ENV)$CPD_ELM(CPD) = (
      ENV_TACT(ENV, CPD, TP) * CPD_CEH(CPD, Z, Y) / CPD_ELM(CPD) );
  TENV_TCZY(TPCPD(TP, CPDBAS), Z, 'N', ENV) = 0;

*============================================================================*
* Emissions Coefficient Associated with the Capacity of a Technology         *
*  other than for externally load managed facilities                         *
*  - Processes, other than externally load managed technologies              *
*  - Externally Load Managed Processes, check both activity and capacity     *
*     environmental coefficients                                             *
*  - Conversion Technologies, other than those externally load managed       *
*  - Externally Load Managed Electric Plants, check both activity and        *
*     capacity environmental coefficients                                    *
*  - Externally Load Managed Heating Plants, check both activity and         *
*     capacity environmental coefficients                                    *
*  - Demand Devices                                                          *
*============================================================================*
*GG* V1.0g add the rest of the emission tracking tables
PARAMETER TENV_CAP(TP, TCH, ENV) / EMPTY.EMPTY.EMPTY 0 /;
  TENV_CAP(TPPRC(TP, PRC), ENV)$(NOT ZPR(PRC)) = ENV_CAP(ENV, PRC, TP);
  TENV_CAP(TPZPR(TP, ZPR), ENV) = ENV_CAP(ENV, ZPR, TP) +
     (TCH_CAPUNI(ZPR) * TCH_CF2(ZPR, TP) * ENV_TACT(ENV, ZPR, TP));
  TENV_CAP(TPCON(TP, CON), ENV)$(NOT XLM(CON)) = ENV_CAP(ENV, CON, TP);
*GG* V1.1a use the preprocessor sets to speed xeq
  TENV_CAP(TPELAXLM(TP, ELAXLM), ENV)$ENV_C(ENV, ELAXLM) =
                                 ENV_CAP(ENV, ELAXLM, TP) +
     (TCH_CAPUNI(ELAXLM) * SUM((Z,Y), TCH_CF1(ELAXLM, Z, Y, TP) * QHR(Z, Y)) *
      ENV_TACT(ENV, ELAXLM, TP));
  TENV_CAP(TPHPL(TP, HPLXLM), ENV) = ENV_CAP(ENV, HPLXLM, TP) +
       SUM(Z, BALH_CAP(TP, TP, HPLXLM, Z)) * ENV_TACT(ENV, HPLXLM, TP);
*GG* V1.1a use the preprocessor sets to speed xeq
  TENV_CAP(TPDMD(TP, DMD), ENV)$ENV_C(ENV, DMD) =
*GG* V2.2g add the CAPUNIT multiplier
       TCH_CAPUNI(DMD) * ENV_CAP(ENV, DMD, TP) * TCH_CF2(DMD, TP);

*============================================================================*
* Emissions Coefficient Associated with Investment in a Technology           *
*============================================================================*
PARAMETER TENV_INV(TP, TCH, ENV) / EMPTY.EMPTY.EMPTY 0 /;
  TENV_INV(TPTCH(TP, TCH), ENV) = ENV_INV(ENV, TCH, TP);

*============================================================================*
* Emissions Coefficient Associated Total Emissions                           *
*  - Resource Supply
*  - Technology Activity
*============================================================================*
*GG* V1.0g remove and use source table in equations code directly
*PARAMETER ENV__TSEP(TP, SRC, ENT, P, ENV);
*  ENV__TSEP(TPSEP(TP,SEP), ENV)$(TENV_TSEP(TPSEP, ENV)) = (
*    NYRSPER * TENV_TSEP(TPSEP, ENV));
*PARAMETER ENV__TACT(TP, TCH, ENV);
*  ENV__TACT(TPTCH(TP,TCH), ENV)$(TENV_TACT(TPTCH, ENV)) = (
*    NYRSPER * TENV_TACT(TPTCH, ENV));

******************************************************************************
*                                                                            *
* Electricity Peaking Coefficients                                           *
*                                                                            *
******************************************************************************

*============================================================================*
* Electricity Required by Demand Devices, other than night storage devices,  *
*  according to capacity's activity                                          *
*============================================================================*
PARAMETER EPK_CAP(TP, TC, TCH, Z) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
*GG* V1.1a use the preprocessor set to speed xeq
  EPK_CAP(TP, TPDMD(TP, DMD), Z)$(1$DD_MA(DMD, 'ELC') AND
                                  1$(NOT DMDNST(DMD))) = (
    - TCH_CAPUNI(DMD) * DMD_MA(DMD, 'ELC', TP) *
   SUM(DM$(1$DMD_DM(DMD, DM) AND (DM_FR(DM,Z,'D') NE EPS)), DM_FR(DM, Z, 'D')) *
    TCH_CF2(DMD, TP) *
    SUM(DM$(1$DMD_DM(DMD, DM) AND (DM_ELF(DM, TP) NE EPS)), DM_ELF(DM, TP)) /
    (QHR(Z, 'D') * DMD_EFF(DMD, TP)) );

*============================================================================*
* Use of Electricity by Externally Load Managed Heating Plants, according    *
*  to capacity's activity                                                    *
*============================================================================*
*GG* V1.0i added
  EPK_CAP(TP, TPHPL(TP, HPLXLM), Z) = (
      - TCH_CAPUNI(HPLXLM) * TCH_CF1(HPLXLM, Z, 'D', TP) *
                             CON_INP1(HPLXLM, 'ELC', TP)
    );
*============================================================================*
* Electricity Required by Externally Load Managed Processes, according to    *
*  capacity's activity                                                       *
*  - Previous Period for Process Activity in Current Period                  *
*  - Current Period                                                          *
*  - Null out Night Storage Processes                                        *
*============================================================================*
*GG* V1.1a add the PEAKDA peaking requirement factor
  EPK_CAP(TP, TPZPR(TC, PRC), Z)$(ORD(TC) EQ (ORD(TP) + 1)) = (
    - TCH_CAPUNI(PRC) * TCH_CF2(PRC, TC) * PRC_INP2(PRC, 'ELC', TC) *
    PRC_LED(PRC, 'ELC', TC) * PEAKDA_PRC(PRC, TP)
  ) ;
  EPK_CAP(TP, TPZPR(TP, PRC), Z) = (
    - TCH_CAPUNI(PRC) * TCH_CF2(PRC, TP) * PRC_INP2(PRC, 'ELC', TP) *
      PEAKDA_PRC(PRC, TP) * (1 - PRC_LED(PRC, 'ELC', TP)$(ORD(TP) GT 1)) );
*GG* V1.0e no contribution to peak by night storage devices
  EPK_CAP(TP, TPZPR(TP, PRCNST), Z) = 0;

*============================================================================*
* Electric Generating Capacity Available for Peaking                         *
*  - Centralized                                                             *
*  - Decentralized                                                           *
*  - Storage                                                                 *
*  - Null Out 'I'ntermediate Season, *GG* V1.0i remove                       *
*============================================================================*
*GG* V1.1a use the CEN/DCN transmission efficiency
  EPK_CAP(TP, TPELA(TP, ELA), Z) = (
    TE_CON(ELA) * TCH_CAPUNI(ELA) * PEAK1(ELA, TP) / (1 + ERESERV)
  ) ;
*  EPK_CAP(TP, TPELA(TP, ELADCN), Z) = (
*    TCH_CAPUNI(ELADCN) * PEAK1(ELADCN, TP) / (1 + ERESERV)
*  ) ;
*GG* V0.8 add stg to electric peak
  EPK_CAP(TP, TPELA(TP, STG), Z) = (
    TE * TCH_CAPUNI(STG) * PEAK1(STG, TP) / (1 + ERESERV)
  ) ;
*GG* V1.1a ajdust for PEAKing only devices
  EPK_CAP(TP, TPELA(TP, ELA), Z)$PEAK_TID(ELA) = 0;
*  EPK_CAP(TP, TPTCH(TC, TCH), 'I') = 0;
*GG* V1.0d add nulling for no season
*  EPK_CAP(TP, TPTCH(TC, TCH), Z) = 0$(QHR(Z,'D') + QHR(Z,'N') EQ 0);

*============================================================================*
* Electricity Required by Processes, other than externally load managed,     *
*  according to activity                                                     *
*  - Previous Period for Process Activity in Current Period                  *
*  - Current Period                                                          *
*  - Null out 'I'ntermediate Season, *GG* V1.0i remove                       *
*  - Null out Night Storage Technologies                                     *
*============================================================================*
*GG* V1.1a add the PEAKDA peaking requirement factor
PARAMETER EPK_ACT(TP, TC, PRC, Z) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  EPK_ACT(TP, TPPRC(TC, PRC), Z)$(NOT (1$ZPR(PRC))AND(ORD(TC) EQ (ORD(TP) + 1))) = (
    - PRC_INP2(PRC, 'ELC', TC) * PRC_LED(PRC, 'ELC', TC) * PEAKDA_PRC(PRC, TP)
  );
  EPK_ACT(TP, TPPRC(TP, PRC), Z)$(NOT ZPR(PRC)) = (
    - PRC_INP2(PRC, 'ELC', TP)  * PEAKDA_PRC(PRC, TP) *
      (1 - PRC_LED(PRC, 'ELC', TP)$(ORD(TP) GT 1)) );
*GG* V1.0 clear 'I's
*  EPK_ACT(TP, TPPRC(TC, PRC), 'I') = 0;
*GG* V1.0d add nulling for no season
*  EPK_ACT(TP, TPPRC(TC, PRC), Z) = 0$(QHR(Z,'D') + QHR(Z,'N') EQ 0);
  EPK_ACT(TP, TPPRC(TP, PRCNST), Z) = 0;

*============================================================================*
* Electricity generated by PEAKing only devices                              *
*============================================================================*
*GG* V1.1a added peaking only devices
PARAMETERS EPK_TEZY(TP, TC, CON, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  EPK_TEZY(TP, TPELA(TP, ELA), Z, 'D')$(PEAK_TID(ELA) AND TCH_PD(ELA, Z, TP)
                                   AND (NOT (1$ELABAS(ELA) OR 1$CPD(ELA)))) = (
   TE_CON(ELA) * PEAK1(ELA, TP)/(QHR(Z,'D') * (1+ERESERV) * TCH_PD(ELA, Z, TP))
  );

*============================================================================*
* Electricity Required by Heating Plants, other than externally load managed,*
*  according to activity                                                     *
*============================================================================*
*GG* V1.0i added
PARAMETER EPK_HPL(TP, HPL, Z) / EMPTY.EMPTY.EMPTY 0 /;
  EPK_HPL(TPHPL(TP, HPL), Z)$(NOT HPLXLM(HPL)) = (
                                     - CON_INP1(HPL, 'ELC', TP) / QHRZ(Z) ) ;

*============================================================================*
* Electricity Imported/Exproted                                              *
*  - Import                                                                  *
*  - Export                                                                  *
*  - Null out 'I'ntermediate Season, *GG* V1.0i remove                       *
*============================================================================*
*GG* V1.0e add import/export of electricity
PARAMETER EPK_SEP(TP, SRC, ENT, P, Z) / EMPTY.EMPTY.EMPTY.EMPTY.EMPTY 0 /;
*GG* V1.2d add Imports contribute to peak multiplier
  EPK_SEP(TPSEP(TP, 'IMP', 'ELC', P), Z)$IMPEXPELC('IMP', P) =
   PEAKDA_SEP('IMP', 'ELC', P, TP) * ( 1$(NOT SEP_FR('IMP', P, Z, 'D')) +
 (SEP_FR('IMP', P, Z, 'D')/QHR(Z, 'D'))$(SEP_FR('IMP', P, Z, 'D') NE EPS) ) *
                                TE / (1 + ERESERV);
*GG* V1.1a add the PEAKDA indicator of exporting at peak
  EPK_SEP(TPSEP(TP, 'EXP', 'ELC', P), Z)$IMPEXPELC('EXP', P) =
   - PEAKDA_SEP('EXP', 'ELC', P, TP) * ( 1$(NOT SEP_FR('EXP', P, Z, 'D')) +
  (SEP_FR('EXP', P, Z, 'D')/QHR(Z, 'D'))$(SEP_FR('EXP', P, Z, 'D') NE EPS) );
*GG* V1.1a add the PEAKDA indicator for peaking contribution when using elec.
*  EPK_SEP(TP, SRC, 'ELC', P, 'I') = 0;

******************************************************************************
*                                                                            *
* Heat Peaking Coefficients                                                  *
*                                                                            *
******************************************************************************

*============================================================================*
* Heat Generating Capacity Available for Peaking                             *
*============================================================================*
*GG* V1.0e add heating peaking equations
PARAMETER HPKW_CAP(TP, TCH) / EMPTY.EMPTY 0 /;
*GG* V1.1a ajdust for PEAKing only devices
  HPKW_CAP(TPHPL(TP, HPL))$(NOT PEAK_TID(HPL)) = (
    TCH_CAPUNI(HPL) * PEAK1(HPL, TP) / (1 + HRESERV)
  );

*============================================================================*
* Heat Required by Demand Devices                                            *
*============================================================================*
*GG* V1.1a use the preprocessor set to speed xeq
  HPKW_CAP(TPTCH(TP, DMD))$DD_MA(DMD, 'LTH') = (
    - TCH_CAPUNI(DMD) * DMD_MA(DMD, 'LTH', TP) *
 SUM((DM,Y)$(1$DMD_DM(DMD, DM) AND (DM_FR(DM,'W',Y) NE EPS)), DM_FR(DM,'W',Y)) *
    TCH_CF2(DMD, TP) / (SUM(Y, QHR('W', Y)) * DMD_EFF(DMD, TP) * DHDE('W'))
  );

*============================================================================*
* Heat generated by PEAKing only devices                                     *
*============================================================================*
*GG* V1.1a added peaking only devices
PARAMETERS HPKW_ACT(TP, HPL) / EMPTY.EMPTY 0 /;
  HPKW_ACT(TP, HPL)$(PEAK_TID(HPL) AND TCH_PD(HPL, 'W', TP))= (
    PEAK1(HPL, TP) / (QHRZ('W') * (1+HRESERV) * TCH_PD(HPL, 'W', TP))
  );

*============================================================================*
* Heat Generating Capacity Available for Peaking from Coupled Production     *
*   - Pass-out Turbines                                                      *
*   - Back-pressure Turbines                                                 *
*============================================================================*
*GG* V1.1a add CPDs
PARAMETER HPKW_TCPD(TP, CPD) / EMPTY.EMPTY 0 /;
  HPKW_TCPD(TPCPD(TP, CPD))$CPD_ELM(CPD) = (
    TCH_CAPUNI(CPD) * CPD_TEFF(CPD, 'W', 'D') * CPD_ELM(CPD) *
    PEAK1(CPD, TP) / ((1 + HRESERV) * CPD_CEH(CPD,'W','D')) );
  HPKW_TCPD(TPCPD(TP, CPD))$CPD_REH(CPD) = (
    TCH_CAPUNI(CPD) * CPD_TEFF(CPD, 'W', 'D') *
    PEAK1(CPD, TP) / ((1 + HRESERV) * CPD_REH(CPD)) );

******************************************************************************
*                                                                            *
* Investment Cost                                                            *
*                                                                            *
******************************************************************************

*============================================================================*
* Investment Cost                                                            *
* - All Technologies                                                         *
* - Electric Technologies                                                    *
* - Coupled Production                                                       *
*============================================================================*
PARAMETER INVEST_INV(TP, TCH) / EMPTY.EMPTY 0 /;
*SK
  INVEST_INV(TPTCH(TP, TCH)) = TCH_INVCOS(TCH, TP);
  INVEST_INV(TPTCH(TP, BEW)) =(1.-FRSB)* TCH_INVCOS(BEW, TP);
*   display invest_inv;
*SK
*GG* V1.1c use TCH_LIFE to control generation so that D&T costs captured
  INVEST_INV(TPELA(TP, ELA))$TCH_LIFE(ELA) = (
    TCH_INVCOS(ELA, TP) + EDISTINV$(NOT STG(ELA)) + ETRANINV$(ELACEN(ELA)) );
*GG* V1.1a add heating plant distribution costs for centralized plants
  INVEST_INV(TPHPL(TP, HPL))$(1$CEN(HPL) AND 1$TCH_LIFE(HPL)) = (
     TCH_INVCOS(HPL, TP) + DTRANINV );
*GG* V1.1a add distribution cost for centralized plants
  INVEST_INV(TPCPD(TP, CENCPD))$TCH_LIFE(CENCPD) = (
    INVEST_INV(TP, CENCPD) +
    (DTRANINV * CPD_ELM(CENCPD) / CPD_CEH(CENCPD, 'W', 'D'))$
        (CPD_ELM(CENCPD) AND CPD_CEH(CENCPD,'W','D')) +
    (DTRANINV / CPD_REH(CENCPD))$CPD_REH(CENCPD) ) ;


******************************************************************************
*                                                                            *
* Fossil Fuel Accounting Rows                                                *
*                                                                            *
*GG* V1.1a added in full                                                     *
******************************************************************************

*============================================================================*
* Period Fossil Fuel                                                         *
*  - Null Out Stockpiling and Renewables                                     *
*============================================================================*
PARAMETER TFOSS_TSEP(TP, SRC, EFS, P) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  TFOSS_TSEP(TPSEP(TP, SRC, EFS, P)) = SIGN(SRC);
  TFOSS_TSEP(TPSEP(TP, 'STK', EFS, P)) = 0;
  TFOSS_TSEP(TPSEP(TP, 'RNW', EFS, P)) = 0;

*============================================================================*
* Total Fossil Fuel                                                          *
*============================================================================*
*PARAMETER FOSS_TSEP(TP, SRC, EFS, P) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
*  FOSS_TSEP(TPSEP(TP, SEP(SRC,EFS,P))) = TFOSS_TSEP(TPSEP) * NYRSPER;

******************************************************************************
*                                                                            *
* Non-Renewables Accounting Rows                                             *
*                                                                            *
*GG* V1.1a added in full                                                     *
******************************************************************************

*============================================================================*
* Non-Renewables by Period                                                   *
*============================================================================*
PARAMETER TNONR_TSEP(TP, SRC, EFS, P) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  TNONR_TSEP(TPSEP(TP, SRC, EFS, P)) = TFOSS_TSEP(TP, SRC, EFS, P);

PARAMETER TNONR_ACT(TP, PRC) / EMPTY.EMPTY 0 /;
  TNONR_ACT(TPPRC(TP, PRC))$(NOT ZPR(PRC)) = PRC_INP2(PRC, 'FEQ', TP);

PARAMETER TNONR_CAP(TP, TCH) / EMPTY.EMPTY 0 /;
  TNONR_CAP(TPPRC(TP, ZPR)) = PRC_INP2(ZPR, 'FEQ', TP) *
                              TCH_CAPUNI(ZPR) * TCH_CF2(ZPR, TP);

PARAMETER TNONR_EZY(TP, CON, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  TNONR_EZY(TPELA(TP, ELA), Z, Y)$(NOT ELAXLM(ELA)) =
                                     CON_INP1(ELA, 'FEQ', TP);
  TNONR_EZY(TPELA(TP, ELA), Z, Y)$PEAK_ACT(ELA, Z, Y) = 0;
  TNONR_EZY(TPELA(TP, ELABAS), Z, 'N') = 0;

  TNONR_CAP(TPCON(TP, XLM)) = CON_INP1(XLM, 'FEQ', TP) *
        TCH_CAPUNI(XLM) * SUM(TD, TCH_CF1(XLM, TD, TP) * QHR(TD));

PARAMETER TNONR_HZ(TP, HPL, Z) / EMPTY.EMPTY.EMPTY 0 /;
  TNONR_HZ(TPHPL(TP, HPL), Z)$(NOT HPLXLM(HPL)) = CON_INP1(HPL, 'FEQ', TP);
  TNONR_HZ(TPHPL(TP, HPL), Z)$PEAK_ACT(HPL, Z, 'D') = 0;

PARAMETER TNONR_CZY(TP, CON, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  TNONR_CZY(TPCPD(TP, CPD), Z, Y)$CPD_ELM(CPD) =
                                   CON_INP1(CPD, 'FEQ', TP) *
                                   CPD_CEH(CPD, Z, Y) / CPD_ELM(CPD);
  TNONR_CZY(TPCON(TP, BAS), Z, 'N') = 0;

*  TNONR_TSEP(TPSEP(TP, 'STK', EFS, P)) = 0;
*  TNONR_TSEP(TPSEP(TP, 'RNW', EFS, P)) = 0;

*============================================================================*
* Total Non-Renewables                                                       *
*============================================================================*
*PARAMETER NONRE_TSEP(TP, SRC, EFS, P) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
*  NONRE_TSEP(TPSEP(TP, SRC, EFS, P)) = NYRSPER * TNONR_TSEP(TPSEP);

******************************************************************************
*                                                                            *
* Nuclear Fuel Accounting Rows                                               *
* - Process by activity                                                      *
* - Process by capacity for externally load managed processes                *
* - Conversion plant by activity                                             *
* - Conversion plant by capacity for externally load managed plants          *
* - Heat conversion plant by activity                                        *
* - Coupled production conversion plant by activity                          *
*GG* V1.1a added in full                                                     *
******************************************************************************

PARAMETER TNUCL_ACT(TP, PRC) / EMPTY.EMPTY 0 /;
  TNUCL_ACT(TPPRC(TP, PRC))$(NOT ZPR(PRC)) = PRC_INP2(PRC, 'FEQ', TP);

PARAMETER TNUCL_CAP(TP, TCH) / EMPTY.EMPTY 0 /;
  TNUCL_CAP(TPPRC(TP, ZPR)) = PRC_INP2(ZPR, 'FEQ', TP) *
                              TCH_CAPUNI(ZPR) * TCH_CF2(ZPR, TP);

PARAMETER TNUCL_EZY(TP, CON, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  TNUCL_EZY(TPELA(TP, ELANUC), Z, Y)$(NOT NUCXLM(ELANUC)) =
                                     CON_INP1(ELANUC, 'FEQ', TP);
  TNUCL_EZY(TPELA(TP, ELANUC), Z, Y)$PEAK_ACT(ELANUC, Z, Y) = 0;
  TNUCL_EZY(TPCON(TP, BASNUC), Z, 'N') = 0;

  TNUCL_CAP(TPCON(TP, NUCXLM)) = CON_INP1(NUCXLM, 'FEQ', TP) *
        TCH_CAPUNI(NUCXLM) * SUM(TD, TCH_CF1(NUCXLM, TD, TP) * QHR(TD));

PARAMETER TNUCL_HZ(TP, CON, Z) / EMPTY.EMPTY.EMPTY 0 /;
  TNUCL_HZ(TPHPL(TP, HPL), Z)$(NOT HPLXLM(HPL)) = CON_INP1(HPL, 'FEQ', TP);
  TNUCL_HZ(TPHPL(TP, HPL), Z)$PEAK_ACT(HPL, Z, 'D') = 0;

PARAMETER TNUCL_CZY(TP, CON, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  TNUCL_CZY(TPCPD(TP, CPD), Z, Y)$(1$NUC(CPD) AND CPD_ELM(CPD)) =
                                   CON_INP1(CPD, 'FEQ', TP) *
                                   CPD_CEH(CPD, Z, Y) / CPD_ELM(CPD);
  TNUCL_CZY(TPCON(TP, BASNUC), Z, 'N') = 0;

*PARAMETER NUCLE_TEZY(TP, CON, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
*  NUCLE_TEZY(TPELA(TP, NUC), Z, Y) = NYRSPER * TNUCL_TEZY(TP, NUC, Z, Y);

*****************************************************************************
*                                                                           *
* Salvage on Investments (for accounting and to adjust investment)          *
*                                                                           *
*****************************************************************************
PARAMETER SALVAG_INV(TP, TCH) / EMPTY.EMPTY 0 /;
  SALVAG_INV(TPTCH(TP, TCH))$((ORD(TP) + TCH_LIFE(TCH) - CARD(TP) - 1) GT 0) = (
*GG* V1.0i use the investment adjusted for OM
    INVEST_INV(TP, TCH) *
    (
      1 -
*GG* V1.2c correct salvage credit for technology-based discount rates
      (1 + DISCOUNT$(NOT TCH_DISC(TCH)) + TCH_DISC(TCH)) ** (
                          - NYRSPER *
                          (ORD(TP) + TCH_LIFE(TCH) - CARD(TP) - 1)
                        )
    ) /
      ((1 + DISCOUNT$(NOT TCH_DISC(TCH)) + TCH_DISC(TCH)) **
       (NYRSPER * (CARD(TP) + 1 - ORD(TP)))) /
    (1 - (1 + DISCOUNT$(NOT TCH_DISC(TCH)) + TCH_DISC(TCH)) **
         (- NYRSPER * TCH_LIFE(TCH)))
  );

******************************************************************************
*                                                                            *
* Coefficients for Total Discounted System Costs                             *
*                                                                            *
****************************************************************************

*============================================================================*
* Annual Discount Factor                                                     *
*============================================================================*
*GG* V1.0f  add/adjust for the option of differential discount rates
*GG* V1.0i back to only by TP as CRF_RAT will handle final adjustment
*GG* V1.2b forget about YRS by using NYRSPER to limit summing via 1*20 set
PARAMETER PRICE_DF(TP) / EMPTY 0 /;
  PRICE_DF(TP) =
    SUM(ALLORD$(ORD(ALLORD) LE NYRSPER), (1 + DISCOUNT) ** (1 - ORD(ALLORD))) /
    ((1 + DISCOUNT) ** (- STARTYRS + NYRSPER * (ORD(TP) - 1)));

*GG* V1.0i out, only need 1
*PARAMETER PRICE_DF2(TP, SRC, ENT, P);
*  PRICE_DF2(TPSEP(TP, SEP)) =
*    SUM(YRS, (1 + DISCRATE2(SEP)) ** (1 - ORD(YRS))) /
*    ((1 + DISCRATE2(SEP)) ** (- STARTYRS + NYRSPER * (ORD(TP) - 1)));

*============================================================================*
* Discounted Supply Costs                                                    *
*============================================================================*
PARAMETER PRICE_TSEP(TP, SRC, ENT, P) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  PRICE_TSEP(TPSEP(TP, SEP)) = PRICE_DF(TP) * ANNC_TSEP(TP, SEP);

*============================================================================*
* Discounted Stockpile Costs                                                 *
*============================================================================*
PARAMETER PRICE_ZSTK(TP, ENC, P) / EMPTY.EMPTY.EMPTY 0 /;
  PRICE_ZSTK(TLAST, ENC, P)$(SEP('STK',ENC,P)) =
             PRICE_DF(TLAST) * ANNC_ZSTK(TLAST, ENC, P);

*============================================================================*
* Discounted Process Costs, associated with activity                         *
*============================================================================*
PARAMETER PRICE_ACT(TP, PRC) / EMPTY.EMPTY 0 /;
  PRICE_ACT(TPPRC(TP, PRC)) = PRICE_DF(TP) * ANNC_ACT(TP, PRC);

*============================================================================*
* Discounted Process Costs, associated with capacity                         *
*============================================================================*
PARAMETER PRICE_CAP(TP, TCH) / EMPTY.EMPTY 0 /;
  PRICE_CAP(TPTCH(TP, TCH)) = PRICE_DF(TP) * ANNC_CAP(TP, TCH);

*============================================================================*
* Discounted Electric Generating Costs, associated with activity             *
*============================================================================*
PARAMETER PRICE_TEZY(TP, TCH, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  PRICE_TEZY(TPELA(TP, ELA), Z, Y) = PRICE_DF(TP) * ANNC_TEZY(TP, ELA, Z, Y);

*============================================================================*
* Discounted Electric Generating Costs for Coupled Production Plants         *
*============================================================================*
*GG* V1.1a add CPDs
PARAMETER PRICE_TCZY(TP, CPD, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  PRICE_TCZY(TPCPD(TP, CPD), Z, Y) = PRICE_DF(TP) * ANNC_TCZY(TP, CPD, Z, Y);

*============================================================================*
* Discounted Heat Generating Costs, associated with activity                 *
*============================================================================*
*GG* V1.0e add heating plants
PARAMETER PRICE_THZ(TP, TCH, Z) / EMPTY.EMPTY.EMPTY 0 /;
  PRICE_THZ(TPHPL(TP, HPL), Z) = PRICE_DF(TP) * ANNC_THZ(TP, HPL, Z);

*============================================================================*
* Investment Capital Recovery Factor                                         *
*============================================================================*
*GG* V1.0i just adjust by crf ratio if tch-based discount, 1 if normal discount
*GG* V1.2b don't need TP index
PARAMETER CRF_RAT(TCH) / EMPTY 0 /;
  CRF_RAT(TCH) = 1$(NOT TCH_DISC(TCH)) +
*GG* V1.3b use the CRF calculated in DIFFCOST.INC
*    ((TCH_DISC(TCH)/(1-(1+TCH_DISC(TCH))**(-TCH_LIFE(TCH)*NYRSPER))) /
        (CRF(TCH) /
         (DISCOUNT/(1-(1+DISCOUNT)**(-TCH_LIFE(TCH)*NYRSPER))))$TCH_DISC(TCH);

*============================================================================*
* Discounted Total Investment Costs, according to amount of investment       *
*============================================================================*
* take the salvage on investment right out from the coefficient
*GG* V1.0i adjust by different discount rates, if any
PARAMETER PRICE_INV(TP, TCH) / EMPTY.EMPTY 0 /;
  PRICE_INV(TPTCH(TP, TCH)) = (
    (1 / ((1 + DISCOUNT) ** (- STARTYRS + NYRSPER * (ORD(TP) - 1)))) *
*GG* V1.2b don't need TP index
*GG* V1.2b add fractional lifetime correction multiplier
     CRF_RAT(TCH) * FRACLIFE(TCH) *
    (INVEST_INV(TP, TCH) - SALVAG_INV(TP, TCH))
  );

******************************************************************************
*                                                                            *
*GG* V1.0i just use PRICE in MMEQUA except for RNT
*                                                                            *
******************************************************************************
*PARAMETER PRICR_TSEP(TP, SRC, ENT, P);
*  PRICR_TSEP(TPSEP(TP, sep)) = PRICE_TSEP(TP, sep);

*PARAMETER PRICR_ZSTK(TP, ENC, P);
*  PRICR_ZSTK(TLAST, ENC, P)$(sep('STK',ENC,P)) =
*             PRICE_ZSTK(TLAST, ENC, P);

*PARAMETER PRICR_ACT(TP, PRC);
*  PRICR_ACT(TPPRC(TP, PRC)) = PRICE_ACT(TP, PRC);

*PARAMETER PRICR_CAP(TP, TCH);
*  PRICR_CAP(TPTCH(TP, TCH)) = PRICE_CAP(TP, TCH);

*PARAMETER PRICR_TEZY(TP, TCH, Z, Y);
*  PRICR_TEZY(TPTCH(TP, TCH), Z, Y) = PRICE_TEZY(TP, TCH, Z, Y);

*GG* V1.0e add heating plants
*PARAMETER PRICR_THZ(TP, TCH, Z);
*  PRICR_THZ(TPHPL(TP, HPL), Z) = PRICE_THZ(TP, HPL, Z);

*PARAMETER PRICR_INV(TP, TCH);
*  PRICR_INV(TPTCH(TP, TCH)) = PRICE_INV(TP, TCH);
*  PRICR_INV(TPTCH(TP, RNT)) = 0.00001;

******************************************************************************
*                                                                            *
* Security Coefficents                                                       *
*                                                                            *
******************************************************************************

PARAMETER TSECU_TSEP(TP, SRC, ENT, P) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  TSECU_TSEP(TPSEP(TP, SEP(SRC,ENT,P))) = ( SIGN(SRC)*
    SEP_SECURI(SEP, TP) / 1000) ;
  TSECU_TSEP(TPSEP(TP, 'STK', ENC, P)) = 0;

PARAMETER SECUR_TSEP(TP, SRC, ENT, P) / EMPTY.EMPTY.EMPTY.EMPTY 0 /;
  SECUR_TSEP(TPSEP(TP,SEP)) = NYRSPER * TSECU_TSEP(TPSEP);

******************************************************************************
*                                                                            *
* Capacity Utilization                                                       *
*                                                                            *
******************************************************************************

*============================================================================*
* Utilization coefficient for activity, except for externally load managed   *
*  facilities and when a availability factor is provided                     *
*============================================================================*
PARAMETER UTLPRC_ACT(TP, PRC) / EMPTY.EMPTY 0 /;
  UTLPRC_ACT(TPPRC(TP, PRC))$(NOT(1$ZPR(PRC)) AND TCH_AF1(PRC,TP)) = 1.0;

*============================================================================*
* Utilization coefficient for capacity, except for externally load managed   *
*  facilities                                                                *
*============================================================================*
PARAMETER UTLPRC_CAP(TP, PRC) / EMPTY.EMPTY 0 /;
  UTLPRC_CAP(TPPRC(TP, PRC))$(NOT ZPR(PRC)) =
             - TCH_CAPUNI(PRC) * TCH_AF1(PRC, TP);

******************************************************************************
*                                                                            *
*  Calculate the Annualized Investment Costs for MARKAL-MACRO                *
*                                                                            *
******************************************************************************
*GG* V1.1c moved back from MMEQUA
*PARAMETER ICOST(TP, TCH) / EMPTY.EMPTY 0 /;
* first calculate the initial investment costs, then calculate their
* annualized equivalent.
*GG* V1.3b adjust to use the CRF(TCH) values calculated in DIFFCOST.INC
  ICOST(TP, TCH)$TCH_LIFE(TCH) =
     INVEST_INV(TP, TCH) * FRACLIFE(TCH) * CRF(TCH);
*GG* V1.0h add test that life exists
*  ICOST(TP, TCH)$(TCH_LIFE(TCH) AND (1$(NOT TCH_DISC(TCH)))) =
*GG* V1.2b add fractional lifetime correction multiplier
*     INVEST_INV(TP, TCH) * FRACLIFE(TCH) *
*GG* V1.0f introduce calculation of CRF internally and TCH based discounts
*     (DISCOUNT/(1-(1+DISCOUNT)**(-TCH_LIFE(TCH)*NYRSPER)));

*GG* V1.0i use technology based discount rate if provided
*  ICOST(TP, TCH)$(TCH_LIFE(TCH) AND (1$TCH_DISC(TCH))) =
*GG* V1.2b add fractional lifetime correction multiplier
*     INVEST_INV(TP, TCH) * FRACLIFE(TCH) *
*     (TCH_DISC(TCH)/(1-(1+TCH_DISC(TCH))**((-TCH_LIFE(TCH))*NYRSPER)));

*PARAMETER COST_INV(TP, TC, TCH) / EMPTY.EMPTY.EMPTY 0 /;
* calculate the year-by-year annualized investment and operating costs.
  COST_INV(TP, TC, TCH)$((ORD(TP) GE ORD(TC)) AND
                   (ORD(TP) LE (ORD(TC) + TCH_LIFE(TCH) - 1))) = ICOST(TC, TCH);
*TK* V1.2c adjust for fractional period if fraction lifetime
  COST_INV(TP, TC, TCH)$((ORD(TP) EQ (ORD(TC) + FLLIFE(TCH))) AND
                     (FRLIFE(TCH) GT 0)) = FRLIFE(TCH) * ICOST(TC, TCH);

