******************************************************************************
*                                                                            *
*   MMEQUA.INC has the actual equation declarations and specifications.  All *
*    the details regarding the actual value of the coefficients are handled  *
*    in MMCOEF.INC.                                                          *
*                                                                            *
******************************************************************************
*GG* V1.0h change the hardwire .001/1000 scaling to us MMSCALE

*============================================================================*
*  Declare the individual equations and provided informative text to be      *
*   printed in the *.LST files for the user                                  *
*============================================================================*
EQUATIONS
  EQ_PRICE               objective function total discounted system cost (=N=)
  EQ_ADRAT1(TP, ADRATIO) ratio relation among vectors (=G=)
  EQ_ADRAT2(TP, ADRATIO) ratio relation among vectors (=E=)
  EQ_ADRAT3(TP, ADRATIO) ratio relation among vectors (=L=)
  EQ_ADRAT4(TP, ADRATIO) ratio relation among vectors (=N=)
  EQ_ANNCOST(TP)         annual system cost (=N=)
  EQ_BAL1(TP, ENC)       ENERGY-CARRIER balance for EFS (=G=)
  EQ_BAL2(TP, ENC)       energy-carrier balance for ENU (=G=)
  EQ_BAL3(TP, ENC)       energy-carrier balance for ESY (=G=)
  EQ_BAL4(TP, ENC)       energy-carrier balance for EHC (=G=)
  EQ_BAL5(TP, ENC)       energy-carrier balance for ECV (=N=)
  EQ_BAL6(TP, ENC)       energy-carrier balance for ERNXMAC (=N=)
  EQ_BAL7(TP, ENC)       energy-carrier balance for 'BIT' (=G=)
  EQ_BALE1(TP, Z, Y)     bal. of electricity by season for day (=G=)
  EQ_BALE2(TP, Z, Y)     bal. of electricity by season for night (=G=)
*GG* V1.0e add heating balance equation
  EQ_BALDH(TP, Z)        bal. of electricity by season (=G=)
  EQ_BAS(TP, Z)          electricity prod. base-load constraints (=L=)
*GG* V1.0i bound for conversion technology non-seasonal activity
  EQ_BNDCON1(TP, CON)    conversion technology annual lower bounds (=G=)
  EQ_BNDCON2(TP, CON)    conversion technology annual fixed bounds (=E=)
  EQ_BNDCON3(TP, CON)    conversion technology annual upper bounds (=L=)
  EQ_CPT1(TP, DMD)       tech-capacity interperiod transfer for DMD (=L=)
  EQ_CPT2(TP, CON)       tech-capacity interperiod transfer for CON (=E=)
  EQ_CPT3(TP, PRC)       tech-capacity interperiod transfer for PRC (=E=)
  EQ_CUM(SRC, ENT, P)    energy-carrier cumulative constraint (=L=)
  EQ_DEM(TP, DM)         demand relation (=G=)
*GG* V1.1a adjust the indexing order
  EQ_TEZY(TP, TCH, Z, Y) electricity-prod. capacity constraint (ELA) (=L=)
*GG* V1.0e add heating
  EQ_THZ(TP, HPL, Z)     heating-prod. capacity constraint (ELA) (=L=)
*GG* V1.0e change cum env to L so RHS can be set
  EQ_ENV(ENV)            environmental-ind. function - all periods (=N=)
  EQ_TENV(TP, ENV)       environmental-ind. accounting - each period (=L=)
  EQ_EPK(TP, Z)          electricity-peaking constraint (=G=)
*GG* V1.1a add resource and technology incremental growth constraint
  EQ_GRSEP(TP, SRC, ENT, P) incremenatl growth constraint (=L=)
  EQ_GRTCH(TP, TCH)      incremental growth constraint (=L=)
*GG* V1.0e add heating
  EQ_HPKW(TP)             heating-peaking constraint (=G=)
  EQ_FOSSIL              total fossil-energy usage function (=N=)
  EQ_TFOSSIL(TP)         fossil-energy usage function per period (=N=)
*GG* V1.1a add the accounting equations
  EQ_INVEST(TP)          inv. costs of the energy system for each period (=N=)
  EQ_NONRNW              total nonrenewable function (=N=)
  EQ_TNONRNW(TP)         total nonrenewable accounting for each period (=N=)
  EQ_NUCLEAR             fossil equivalent of total nuclear production (=N=)
  EQ_TNUCLAR(TP)         fossil equiv. of nuclear production per period (=N=)
  EQ_PRICER              price with special treatment for renewable tch (=N=)
  EQ_SALVAGE(TP)         correction to the end-effect problem (=N=)
  EQ_SECURIT             total weighted security value in all periods (=N=)
  EQ_TSECURI(TP)         annual security value in each period (=N=)
*GG* V1.1a add scheduled maintenance for conversion technologies
  EQ_UTLCON(TP, CON)     conversion plant utilization relation (=G=)
  EQ_UTLPRC(TP, PRC)     process utilization relation (=L=)
*GG* V1.1a add limit processes
  EQ_LIM(TP, PRC, ENC)  limit process individual output ratios
  EQ_PBL(TP, PRC)       limit processes
*GG* V1.4e handle tax/subsidy
  EQ_TXSUB(TP, TAXSUB)  'energy carrier tax/subsidy balance equation (=E=)'

*  Macro submodel:
  DD(DM,TP)             markal-macro demand coupling equations
  UTIL                  utility equation - objective function for MKMC
  MCAP(TP)              capital - trillion dollars
  TMC(TP)               terminal condition  - trillion dollars
  COSTNRG(TP)           cost of energy - billion dollars
  EQ_IVECBND(TP)        bound on sum of investment and energy costs
  EQ_MPEN(TCH, TP)      market penetration
*GG* V1.0f add substitution equation & variables
  EQ_XCAPDB(TP,TCH)     substitution equation for XCAP
*DVR/GG* V1.4e, introduce MARKAL-MICRO support
* Micro Submodel :
  EQ_DD(TP,DM)          markal-micro demand equations
  EQ_CSPRICE            objective function for MKMICRO
  PRODUC(TP)
;


*============================================================================*
*  Total Discounted System Cost                                              *
*============================================================================*
EQ_PRICE .. 
MMSCALE * (

* Resource Supply Options
  SUM(TPSEP(TP, SEP),
    PRICE_TSEP(TP, SEP) * TSEP(TP, SEP)
  ) +

* Stockpiling
  SUM((TLAST, ENC, P),
    PRICE_ZSTK(TLAST, ENC, P) * ZSTK(ENC, P)
  ) +

* Process Activity
  SUM(TPPRC(TP, PRC),
    PRICE_ACT(TP, PRC) * ACT(TP, PRC)
  ) +

* Technology Capacity & Investment
  SUM(TPTCH(TP, TCH),
    PRICE_CAP(TP, TCH) * CAP(TP, TCH) +
    PRICE_INV(TP, TCH) * INV(TP, TCH)
  ) +

* Electric Generation
  SUM((TPELA(TP, ELA), Z, Y),
    PRICE_TEZY(TP, ELA, Z, Y) * TEZY(TP, ELA, Z, Y)
  ) +

*GG* V1.1a Electric Generation from Couple Production
  SUM((TPCPD(TP, CPD), Z, Y),
    PRICE_TCZY(TP, CPD, Z, Y) * TCZYH(TP, CPD, Z, Y)
  ) +

* Heat Generation
*GG* V1.0e add heating plants
  SUM((TPHPL(TP, HPL), Z),
    PRICE_THZ(TP, HPL, Z) * THZ(TP, HPL, Z)
  ) +

* Environmental Costs
*GG* V1.0g add the emission tax if appropriate, using the discount factor
*GG* V1.4b adjust EM scaling by MMSCALE
  SUM((TP, ENV)$ENV_COST(ENV, TP),
*GG* V1.4e use seperate scaler for emissions
*                PRICE_DF(TP) * ENV_COST(ENV, TP) * EM(TP, ENV) / MMSCALE
                PRICE_DF(TP) * ENV_COST(ENV, TP) * EM(TP, ENV) / ENV_SCAL
  ) +

*GG* V1.4e energy carrier tax/subsidy
  SUM((TP, TAXSUB)$TSUB_COST(TAXSUB, TP),
                PRICE_DF(TP) * TSUB_COST(TAXSUB, TP) * TXSUB(TP, TAXSUB)
  )

$ONTEXT
* coefficient on invest was adjusted directly in MMCOEF.INC
  - SUM(TPTCH(TP,TCH),
    SALVAG_INV(TP, TCH) * INV(TP, TCH) )
$OFFTEXT
)
  =E=
  MMSCALE * objZ;

*============================================================================*
*  Useful Energy Demands                                                     *
*   A demand relation is generated for each demand sector DM and ensures     *
*   that the end-use energy output from the demand devices which have output *
*   to DM is greater than or equal to the end-use demand specified by the    *
*   user.                                                                    *
*============================================================================*
*GG* V1.1c only generate if demand provided
EQ_DEM(TP, DM)$(DM_DEMAND(DM, TP) GT 0) ..
 MMSCALE * (
  SUM(DMD$DMD_DMS(DMD, DM),
    DEM_CAP(TP, DMD, DM) * CAP(TP, DMD)
  )
)
  =G=
  MMSCALE * DM_DEMAND(DM, TP);


*============================================================================*
*  User Defined Equations Which are >= RHS                                   *
*============================================================================*
EQ_ADRAT1(TP, ADRATIO)$(RAT_RTY1(ADRATIO, 'MIN')) .. 
MMSCALE * (

* Capacity of Technologies
  SUM(TPTCH(TP, TCH),
    RAT_CAP(ADRATIO, TCH, TP) * CAP(TP, TCH)) +

*GG* V1.1a Investment in Technologies
  SUM(TPTCH(TP, TCH),
    RAT_INV(ADRATIO, TCH, TP) * INV(TP, TCH)) +

* Activity of Processes
  SUM(TPPRC(TP,PRC)$(NOT ZPR(PRC)),
    RAT_ACT(ADRATIO, PRC, TP) * ACT(TP, PRC)) +

* Resource Supply Activity
  SUM(TPSEP(TP,SEP),
    RAT_TSEP(ADRATIO, SEP, TP) * TSEP(TP, SEP)) +

* Activity of Conversion Technologies
  SUM((TPELA(TP,ELA), Z)$(NOT ELAXLM(ELA)),
*GG* V1.0i not if base or storage technology at night
*  SUM(TD,
*    RAT_TEZY(ADRATIO, CON, TD, TP) * TEZY(TP, CON, TD))) +
*GG* V1.1a just 1 loop  SUM(Z,
    (RAT_TEZY(ADRATIO, ELA, Z, 'D', TP) * TEZY(TP, ELA, Z, 'D'))$
      (NOT PEAK_ACT(ELA, Z, 'D')) +
    (RAT_TEZY(ADRATIO, ELA, Z, 'N', TP) * TEZY(TP, ELA, Z, 'N'))$
      (NOT (1$BAS(ELA) OR 1$STG(ELA) OR PEAK_TID(ELA))) ) +

* Activity of Coupled Production Plants
*GG* V1.1a add CPDs
  SUM((TPCPD(TP,CPD),Z,Y),
    RAT_TCZY(ADRATIO, CPD, Z, Y, TP) * TCZYH(TP, CPD, Z, Y)) +

* Activity of Heating Technologies
*GG* V1.0h add ADRATIO heating plants
  SUM((TPHPL(TP,HPL),Z)$(NOT (1$HPLXLM(HPL) OR 1$PEAK_ACT(HPL, Z, 'D'))),
*GG* V1.1a just 1 loop  SUM(Z,
    RAT_HPL(ADRATIO, HPL, Z, TP) * THZ(TP, HPL, Z))
  )
  =G=
  MMSCALE * RAT_RTY2(ADRATIO, 'MIN', TP);

*============================================================================*
*  User Defined Equations Which are = RHS                                    *
*============================================================================*
EQ_ADRAT2(TP, ADRATIO)$(RAT_RTY1(ADRATIO, 'FIX')) .. MMSCALE * (

* Capacity of Technologies
  SUM(TPTCH(TP,TCH),
    RAT_CAP(ADRATIO, TCH, TP) * CAP(TP, TCH)) +

*GG* V1.1a Investment in Technologies
  SUM(TPTCH(TP, TCH),
    RAT_INV(ADRATIO, TCH, TP) * INV(TP, TCH)) +

* Activity of Processes
  SUM(TPPRC(TP,PRC)$(NOT ZPR(PRC)),
    RAT_ACT(ADRATIO, PRC, TP) * ACT(TP, PRC)) +

* Resource Supply Activity
  SUM(TPSEP(TP,SEP),
    RAT_TSEP(ADRATIO, SEP, TP) * TSEP(TP, SEP)) +

* Activity of Conversion Technologies
  SUM((TPELA(TP,ELA),Z)$(NOT ELAXLM(ELA)),
*GG* V1.0i not if base or storage technology at night
*  SUM(TD,
*    RAT_TEZY(ADRATIO, CON, TD, TP) * TEZY(TP, CON, TD))) +
*  SUM(Z,
    RAT_TEZY(ADRATIO, ELA, Z, 'D', TP) * TEZY(TP, ELA, Z, 'D')$
      (NOT PEAK_ACT(ELA, Z, 'D')) +
    (RAT_TEZY(ADRATIO, ELA, Z, 'N', TP) * TEZY(TP, ELA, Z, 'N'))$
      (NOT (1$BAS(ELA) OR 1$STG(ELA) OR PEAK_TID(ELA))) ) +

* Activity of Coupled Production Plants
*GG* V1.1a add CPDs
  SUM((TPCPD(TP,CPD),Z,Y),
    RAT_TCZY(ADRATIO, CPD, Z, Y, TP) * TCZYH(TP, CPD, Z, Y)) +

* Activity of Heating Technologies
*GG* V1.0h add ADRATIO heating plants
  SUM((TPHPL(TP,HPL),Z)$(NOT (1$HPLXLM(HPL) OR 1$PEAK_ACT(HPL, Z, 'D'))),
*  SUM(Z,
    RAT_HPL(ADRATIO, HPL, Z, TP) * THZ(TP, HPL, Z))
  )
  =E=
  MMSCALE * RAT_RTY2(ADRATIO, 'FIX', TP);

*============================================================================*
*  User Defined Equations Which are <= RHS                                   *
*============================================================================*
EQ_ADRAT3(TP, ADRATIO)$(RAT_RTY1(ADRATIO, 'MAX'))  .. MMSCALE * (

* Capacity of Technologies
  SUM(TPTCH(TP,TCH),
    RAT_CAP(ADRATIO, TCH, TP) * CAP(TP, TCH)) +

*GG* V1.1a Investment in Technologies
  SUM(TPTCH(TP, TCH),
    RAT_INV(ADRATIO, TCH, TP) * INV(TP, TCH)) +

* Activity of Processes
  SUM(TPPRC(TP,PRC)$(NOT ZPR(PRC)),
    RAT_ACT(ADRATIO, PRC, TP) * ACT(TP, PRC)) +

* Resource Supply Activity
  SUM(TPSEP(TP,SEP),
    RAT_TSEP(ADRATIO, SEP, TP) * TSEP(TP, SEP)) +

* Activity of Conversion Technologies
  SUM((TPELA(TP,ELA),Z)$(NOT ELAXLM(ELA)),
*GG* V1.0i not if base or storage technology at night
*  SUM(TD,
*    RAT_TEZY(ADRATIO, CON, TD, TP) * TEZY(TP, CON, TD))) +
*  SUM(Z,
    RAT_TEZY(ADRATIO, ELA, Z, 'D', TP) * TEZY(TP, ELA, Z, 'D')$
      (NOT PEAK_ACT(ELA, Z, 'D')) +
    (RAT_TEZY(ADRATIO, ELA, Z, 'N', TP) * TEZY(TP, ELA, Z, 'N'))$
      (NOT (1$BAS(ELA) OR 1$STG(ELA) OR PEAK_TID(ELA))) ) +

* Activity of Coupled Production Plants
*GG* V1.1a add CPDs
  SUM((TPCPD(TP,CPD),Z,Y),
    RAT_TCZY(ADRATIO, CPD, Z, Y, TP) * TCZYH(TP, CPD, Z, Y)) +

* Activity of Heating Technologies
*GG* V1.0h add ADRATIO heating plants
  SUM((TPHPL(TP,HPL),Z)$(NOT (1$HPLXLM(HPL) OR 1$PEAK_ACT(HPL, Z, 'D'))),
*  SUM(Z,
    RAT_HPL(ADRATIO, HPL, Z, TP) * THZ(TP, HPL, Z))
  )
  =L=
  MMSCALE * RAT_RTY2(ADRATIO, 'MAX', TP);

*============================================================================*
*  User Defined Equations Which are OBJ                                      *
*============================================================================*
*GG* V1.1a added OBJ
EQ_ADRAT4(TP, ADRATIO)$(RAT_RTY1(ADRATIO, 'OBJ')) .. MMSCALE * (

* Capacity of Technologies
  SUM(TPTCH(TP,TCH),
    RAT_CAP(ADRATIO, TCH, TP) * CAP(TP, TCH)) +

*GG* V1.1a Investment in Technologies
  SUM(TPTCH(TP, TCH),
    RAT_INV(ADRATIO, TCH, TP) * INV(TP, TCH)) +

* Activity of Processes
  SUM(TPPRC(TP,PRC)$(NOT ZPR(PRC)),
    RAT_ACT(ADRATIO, PRC, TP) * ACT(TP, PRC)) +

* Resource Supply Activity
  SUM(TPSEP(TP,SEP),
    RAT_TSEP(ADRATIO, SEP, TP) * TSEP(TP, SEP)) +

* Activity of Conversion Technologies
  SUM((TPELA(TP,ELA),Z)$(NOT ELAXLM(ELA)),
*GG* V1.0i not if base or storage technology at night
*  SUM(TD,
*    RAT_TEZY(ADRATIO, CON, TD, TP) * TEZY(TP, CON, TD))) +
*GG* V1.1a just 1 loop  SUM(Z,
    RAT_TEZY(ADRATIO, ELA, Z, 'D', TP) * TEZY(TP, ELA, Z, 'D')$
      (NOT PEAK_ACT(ELA, Z, 'D')) +
    (RAT_TEZY(ADRATIO, ELA, Z, 'N', TP) * TEZY(TP, ELA, Z, 'N'))$
      (NOT (1$BAS(ELA) OR 1$STG(ELA) OR PEAK_TID(ELA))) ) +

* Activity of Coupled Production Plants
*GG* V1.1a add CPDs
  SUM((TPCPD(TP,CPD),Z,Y),
    RAT_TCZY(ADRATIO, CPD, Z, Y, TP) * TCZYH(TP, CPD, Z, Y)) +

* Activity of Heating Technologies
*GG* V1.0h add ADRATIO heating plants
  SUM((TPHPL(TP,HPL),Z)$(NOT (1$HPLXLM(HPL) OR 1$PEAK_ACT(HPL, Z, 'D'))),
*GG* V1.1a just 1 loop  SUM(Z,
    RAT_HPL(ADRATIO, HPL, Z, TP) * THZ(TP, HPL, Z))
  )
  =N=
  MMSCALE * RAT_RTY2(ADRATIO, 'OBJ', TP);

*============================================================================*
*  Annualized Costs                                                          *
*============================================================================*
EQ_ANNCOST(TP) .. MMSCALE * (

* Resource Supply Activity
  SUM(SEP,
    ANNC_TSEP(TP, SEP) * TSEP(TP, SEP)
  ) +

* Stockpiling of Energy Carriers
  SUM((ENC, P),
    ANNC_ZSTK(TP, ENC, P) * ZSTK(ENC, P)
  ) +

* Activity of Processes
  SUM(PRC,
    ANNC_ACT(TP, PRC) * ACT(TP, PRC)
  ) +

* Capacity of Technologies
  SUM(TCH,
    ANNC_CAP(TP, TCH) * CAP(TP, TCH)
  ) +

* Activity of Electric Plants
  SUM((ELA, Z, Y),
    ANNC_TEZY(TP, ELA, Z, Y) * TEZY(TP, ELA, Z, Y)
  ) +

*GG* V1.1a Activity of Couple Production Plants
  SUM((CPD, Z, Y),
    ANNC_TCZY(TP, CPD, Z, Y) * TCZYH(TP, CPD, Z, Y)
  ) +

* Activity of Heating Plants
*GG* V1.0e add heating plants
  SUM((HPL, Z),
    ANNC_THZ(TP, HPL, Z) * THZ(TP, HPL, Z)
  ) +

* Emissions Costs
*GG* V1.0g add the emission tax if appropriate
*GG* V1.4b adjust EM scaling by MMSCALE
  SUM(ENV,
*GG* V1.4e use seperate scaler for emissions
*    ENV_COST(ENV, TP) * EM(TP, ENV) / MMSCALE )
    ENV_COST(ENV, TP) * EM(TP, ENV) / ENV_SCAL )
)
  =N=
  0;

*============================================================================*
*  Balance Equation for Fossil Energy Carriers                               *
*============================================================================*
EQ_BAL1(TP, EFS) .. MMSCALE * (

* Resource Supply Options
  SUM((TC, SRC, P),
    BAL_TSEP(TP, TC, SRC, EFS, P) * TSEP(TC, SRC, EFS, P)
  ) +

*GG* V1.0i Use of an Energy Carrier for a Resource Supply Options
  SUM(SEP,
    BAL_SEPENT(TP, SEP, EFS) * TSEP(TP, SEP)
  ) +

* Stockpiling
  SUM(P,
    BAL_ZSTK(TP, EFS, P) * ZSTK(EFS, P)
  ) +

* Process Activity, not LIMIT
*GG* V1.1a adjust for limit processes
*GG* V1.2d remove duplicate accounting of inputs if XPR
  SUM(TPPRC(TC, PRC),
    BAL_ACT(TP, TC, PRC, EFS) *
    (ACT(TC, PRC)$(NOT PRC_LIM(PRC, TP) OR
                  (PRC_INP2(PRC, EFS, TP) AND 1$(NOT ZPR(PRC)))) +
     LOUT(TC, PRC, EFS)$(PRC_LIM(PRC, TP) AND (NOT PRC_INP2(PRC, EFS, TP))))
  ) +

* Technology Capacity & Investment
  SUM(TPTCH(TC, TCH),
    BAL_CAP(TP, TC, TCH, EFS) * CAP(TC, TCH) +
    BAL_INV(TP, TC, TCH, EFS) * INV(TC, TCH)
  ) +

* Electricity Generation
  SUM((ELA, Z, Y),
    BAL_TEZY(TP, ELA, EFS, Z, Y) * TEZY(TP, ELA, Z, Y)
  ) +

*GG* V1.1a Coupled Production Plants
  SUM((CPD, Z, Y),
    BAL_TCZY(TP, CPD, EFS, Z, Y) * TCZYH(TP, CPD, Z, Y)
  ) +

* Heat Generation
*GG* V1.0e add HPL
  SUM((HPL, Z),
    BAL_THZ(TP, HPL, EFS, Z) * THZ(TP, HPL, Z)
  )
)
  =G=
  0;

*============================================================================*
*  Balance Equation for Nuclear Energy Carriers                              *
*============================================================================*
EQ_BAL2(TP, ENU) .. MMSCALE * (

* Resource Supply Options
  SUM((TC, SRC, P),
    BAL_TSEP(TP, TC, SRC, ENU, P) * TSEP(TC, SRC, ENU, P)
  ) +

* Stockpiling
  SUM(P,
    BAL_ZSTK(TP, ENU, P) * ZSTK(ENU, P)
  ) +

* Process Activity
*GG* V1.1a adjust for limit processes
*GG* V1.2d remove duplicate accounting of inputs if XPR
  SUM(TPPRC(TC, PRC),
    BAL_ACT(TP, TC, PRC, ENU) *
    (ACT(TC, PRC)$(NOT PRC_LIM(PRC, TP) OR
                  (PRC_INP2(PRC, ENU, TP) AND 1$(NOT ZPR(PRC)))) +
     LOUT(TC, PRC, ENU)$(PRC_LIM(PRC, TP) AND (NOT PRC_INP2(PRC, ENU, TP))))
  ) +

* Technology Capacity & Investment
  SUM(TPTCH(TC, TCH),
    BAL_CAP(TP, TC, TCH, ENU) * CAP(TC, TCH) +
    BAL_INV(TP, TC, TCH, ENU) * INV(TC, TCH)
  ) +

* Electricity Generation
  SUM((ELA, Z, Y),
    BAL_TEZY(TP, ELA, ENU, Z, Y) * TEZY(TP, ELA, Z, Y)
  ) +

*GG* V1.1a Coupled Production Plants
  SUM((CPD, Z, Y),
    BAL_TCZY(TP, CPD, ENU, Z, Y) * TCZYH(TP, CPD, Z, Y)
  ) +

* Heat Generation
*GG* V1.0e add HPL
  SUM((HPL, Z),
    BAL_THZ(TP, HPL, ENU, Z) * THZ(TP, HPL, Z)
  )
)
  =G=
  0;

*============================================================================*
*  Balance Equation for Synthetic Energy Carriers                            *
*============================================================================*
EQ_BAL3(TP, ESY) .. MMSCALE * (

* Resource Supply Options
  SUM((TC, SRC, P),
    BAL_TSEP(TP, TC, SRC, ESY, P) * TSEP(TC, SRC, ESY, P)
  ) +

*GG* V1.0i Use of an Energy Carrier for a Resource Supply Options
  SUM(SEP,
    BAL_SEPENT(TP, SEP, ESY) * TSEP(TP, SEP)
  ) +

* Stockpiling
  SUM(P,
    BAL_ZSTK(TP, ESY, P) * ZSTK(ESY, P)
  ) +

* Process Activity,
*GG* V1.1a adjust for limit processes
*GG* V1.2d remove duplicate accounting of inputs if XPR
  SUM(TPPRC(TC, PRC),
    BAL_ACT(TP, TC, PRC, ESY) *
    (ACT(TC, PRC)$(NOT PRC_LIM(PRC, TP) OR
                  (PRC_INP2(PRC, ESY, TP) AND 1$(NOT ZPR(PRC)))) +
     LOUT(TC, PRC, ESY)$(PRC_LIM(PRC, TP) AND (NOT PRC_INP2(PRC, ESY, TP))))
  ) +

* Technology Capacity & Investment
  SUM(TPTCH(TC, TCH),
    BAL_CAP(TP, TC, TCH, ESY) * CAP(TC, TCH) +
    BAL_INV(TP, TC, TCH, ESY) * INV(TC, TCH)
  ) +

* Electricity Generation
  SUM((ELA, Z, Y),
    BAL_TEZY(TP, ELA, ESY, Z, Y) * TEZY(TP, ELA, Z, Y)
  ) +

*GG* V1.1a Coupled Production Plants
  SUM((CPD, Z, Y),
    BAL_TCZY(TP, CPD, ESY, Z, Y) * TCZYH(TP, CPD, Z, Y)
  ) +

* Heat Generation
*GG* V1.0e add HPL
  SUM((HPL, Z),
    BAL_THZ(TP, HPL, ESY, Z) * THZ(TP, HPL, Z)
  )
)
  =G=
  0;

*============================================================================*
*  Balance Equation for Heat Energy Carriers                                 *
*============================================================================*
EQ_BAL4(TP, EHC) .. MMSCALE * (

* Resource Supply Options
  SUM((TC, SRC, P),
    BAL_TSEP(TP, TC, SRC, EHC, P) * TSEP(TC, SRC, EHC, P)
  ) +

*GG* V1.0i Use of an Energy Carrier for a Resource Supply Options
  SUM(SEP,
    BAL_SEPENT(TP, SEP, EHC) * TSEP(TP, SEP)
  ) +

* Stockpiling
  SUM(P,
    BAL_ZSTK(TP, EHC, P) * ZSTK(EHC, P)
  ) +

* Process Activity
*GG* V1.1a adjust for limit processes
*GG* V1.2d remove duplicate accounting of inputs if XPR
  SUM(TPPRC(TC, PRC),
    BAL_ACT(TP, TC, PRC, EHC) *
    (ACT(TC, PRC)$(NOT PRC_LIM(PRC, TP) OR
                  (PRC_INP2(PRC, EHC, TP) AND 1$(NOT ZPR(PRC)))) +
     LOUT(TC, PRC, EHC)$(PRC_LIM(PRC, TP) AND (NOT PRC_INP2(PRC, EHC, TP))))
  ) +

* Technology Capacity & Investment
  SUM(TPTCH(TC, TCH),
    BAL_CAP(TP, TC, TCH, EHC) * CAP(TC, TCH) +
    BAL_INV(TP, TC, TCH, EHC) * INV(TC, TCH)
  ) +

* Electricity Generation
  SUM((ELA, Z, Y),
    BAL_TEZY(TP, ELA, EHC, Z, Y) * TEZY(TP, ELA, Z, Y)
  ) +

*GG* V1.1a Coupled Production Plants
  SUM((CPD, Z, Y),
    BAL_TCZY(TP, CPD, EHC, Z, Y) * TCZYH(TP, CPD, Z, Y)
  ) +

* Heat Generation
*GG* V1.0e add HPL
  SUM((HPL, Z),
    BAL_THZ(TP, HPL, EHC, Z) * THZ(TP, HPL, Z)
  )
)
  =G=
  0;

*============================================================================*
*  Balance Equation for Conservation Energy Carriers                         *
*============================================================================*
EQ_BAL5(TP, ECV) .. MMSCALE * (

* Resource Supply Options
  SUM((TC, SRC, P),
    BAL_TSEP(TP, TC, SRC, ECV, P) * TSEP(TC, SRC, ECV, P)
  ) +

* Stockpiling
  SUM(P,
    BAL_ZSTK(TP, ECV, P) * ZSTK(ECV, P)
  ) +

* Process Activity
*GG* V1.1a adjust for limit processes
*GG* V1.2d remove duplicate accounting of inputs if XPR
  SUM(TPPRC(TC, PRC),
    BAL_ACT(TP, TC, PRC, ECV) *
    (ACT(TC, PRC)$(NOT PRC_LIM(PRC, TP) OR
                  (PRC_INP2(PRC, ECV, TP) AND 1$(NOT ZPR(PRC)))) +
     LOUT(TC, PRC, ECV)$(PRC_LIM(PRC, TP) AND (NOT PRC_INP2(PRC, ECV, TP))))
  ) +

* Technology Capacity & Investment
  SUM(tptch(TC, TCH),
    BAL_CAP(TP, TC, TCH, ECV) * CAP(TC, TCH) +
    BAL_INV(TP, TC, TCH, ECV) * INV(TC, TCH)
  ) +

* Electricity Generation
  SUM((ELA, Z, Y),
    BAL_TEZY(TP, ELA, ECV, Z, Y) * TEZY(TP, ELA, Z, Y)
  ) +

*GG* V1.1a Coupled Production Plants
  SUM((CPD, Z, Y),
    BAL_TCZY(TP, CPD, ECV, Z, Y) * TCZYH(TP, CPD, Z, Y)
  ) +

* Heat Generation
*GG* V1.0e add HPL
  SUM((HPL, Z),
    BAL_THZ(TP, HPL, ECV, Z) * THZ(TP, HPL, Z)
  )
)
  =N=
  0;

*============================================================================*
*  Balance Equation for Renewable Energy Carriers, Physical                  *
*============================================================================*
EQ_BAL6(TP, ERNXMAC) .. MMSCALE * (

* Resource Supply Options
  SUM((TC, SRC, P),
    BAL_TSEP(TP, TC, SRC, ERNXMAC, P) * TSEP(TC, SRC, ERNXMAC, P)
  ) +

*GG* V1.0i Use of an Energy Carrier for a Resource Supply Options
  SUM(SEP,
    BAL_SEPENT(TP, SEP, ERNXMAC) * TSEP(TP, SEP)
  ) +

* Stockpiling
  SUM(P,
    BAL_ZSTK(TP, ERNXMAC, P) * ZSTK(ERNXMAC, P)
  ) +

* Process Activity
*GG* V1.1a adjust for limit processes
*GG* V1.2d remove duplicate accounting of inputs if XPR
  SUM(TPPRC(TC, PRC),
    BAL_ACT(TP, TC, PRC, ERNXMAC) *
    (ACT(TC, PRC)$(NOT PRC_LIM(PRC, TP) OR
                  (PRC_INP2(PRC, ERNXMAC, TP) AND 1$(NOT ZPR(PRC)))) +
LOUT(TC, PRC, ERNXMAC)$(PRC_LIM(PRC, TP) AND (NOT PRC_INP2(PRC, ERNXMAC, TP))))
  ) +

* Technology Capacity & Investment
  SUM(TPTCH(TC, TCH),
    BAL_CAP(TP, TC, TCH, ERNXMAC) * CAP(TC, TCH) +
    BAL_INV(TP, TC, TCH, ERNXMAC) * INV(TC, TCH)
  ) +

* Electricity Generation
  SUM((ELA, Z, Y),
    BAL_TEZY(TP, ELA, ERNXMAC, Z, Y) * TEZY(TP, ELA, Z, Y)
  ) +

*GG* V1.1a Coupled Production Plants
  SUM((CPD, Z, Y),
    BAL_TCZY(TP, CPD, ERNXMAC, Z, Y) * TCZYH(TP, CPD, Z, Y)
  ) +

* Heat Generation
*GG* V1.0e add HPL
  SUM((HPL, Z),
    BAL_THZ(TP, HPL, ERNXMAC, Z) * THZ(TP, HPL, Z)
  )
)
  =N=
  0;

*============================================================================*
*  Balance Equation for Renewable Energy Carriers, Accounting                *
*============================================================================*
EQ_BAL7(TP, ERN)$(NOT ERNXMAC(ERN)) .. MMSCALE * (

* Resource Supply Options
  SUM((TC, SRC, P),
    BAL_TSEP(TP, TC, SRC, ERN, P) * TSEP(TC, SRC, ERN, P)
  ) +

*GG* V1.0i Use of an Energy Carrier for a Resource Supply Options
  SUM(SEP,
    BAL_SEPENT(TP, SEP, ERN) * TSEP(TP, SEP)
  ) +

* Stockpiling
  SUM(P,
    BAL_ZSTK(TP, ERN, P) * ZSTK(ERN, P)
  ) +

* Process Activity
*GG* V1.1a adjust for limit processes
*GG* V1.2d remove duplicate accounting of inputs if XPR
  SUM(TPPRC(TC, PRC),
    BAL_ACT(TP, TC, PRC, ERN) *
    (ACT(TC, PRC)$(NOT PRC_LIM(PRC, TP) OR
                  (PRC_INP2(PRC, ERN, TP) AND 1$(NOT ZPR(PRC)))) +
     LOUT(TC, PRC, ERN)$(PRC_LIM(PRC, TP) AND (NOT PRC_INP2(PRC, ERN, TP))))
  ) +

* Technology Capacity & Investment
  SUM(TPTCH(TC, TCH),
    BAL_CAP(TP, TC, TCH, ERN) * CAP(TC, TCH) +
    BAL_INV(TP, TC, TCH, ERN) * INV(TC, TCH)
  ) +

* Electricity Generation
  SUM((ELA, Z, Y),
    BAL_TEZY(TP, ELA, ERN, Z, Y) * TEZY(TP, ELA, Z, Y)
  ) +

*GG* V1.1a Coupled Production Plants
  SUM((CPD, Z, Y),
    BAL_TCZY(TP, CPD, ERN, Z, Y) * TCZYH(TP, CPD, Z, Y)
  ) +

* Heat Generation
*GG* V1.0e add HPL
  SUM((HPL, Z),
    BAL_THZ(TP, HPL, ERN, Z) * THZ(TP, HPL, Z)
  )
)
  =G=
  0;

*============================================================================*
*  Low-temperature Heat Balance Equation                                     *
*============================================================================*
*GG* V1.0e balance for heating
EQ_BALDH(TP, Z)  .. MMSCALE * (

* Demand for and Contribution from capacity for externally load managed plants
*GG* V1.1a adjust loop so no TCH
  SUM(TCH,
    BALH_CAP(TP, TP, TCH, Z) * CAP(TP, TCH)
  ) +

*GG* V1.1a Heat from Coupled Production Plants
  SUM((CPD,Y),
    BALH_TCZY(TP, CPD, Z, Y) *
    (TCZYH(TP, CPD, Z, Y)$CPD_ELM(CPD) + TEZY(TP, CPD, Z, Y)$CPD_REH(CPD))
  ) +

* Contribution from activity
  SUM(HPL$(NOT HPLXLM(HPL)),
    BALH_THZ(TP, HPL, Z) * THZ(TP, HPL, Z)
  )
)
  =G=
  0;

*============================================================================*
*  Electricity Balance Equation, Day                                         *
*============================================================================*
*GG* V0.8 add storage
EQ_BALE1(TP, Z, 'D') .. MMSCALE * (

*GG* V1.0e add import/export of electricity
  SUM((SRC, P),
    BALE_SEP(TP, SRC, 'ELC', P, Z, 'D') * TSEP(TP, SRC, 'ELC', P)
  ) +

*GG* V1.0i Use of an Energy Carrier for a Resource Supply Options
  SUM(SEP,
    (QHR(Z, 'D') * BAL_SEPENT(TP, SEP, 'ELC')) * TSEP(TP, SEP)
  ) +

* Production/Consumption according to capacity
  SUM(TPTCH(TC, TCH),
    BALE_CAP(TP, TC, TCH, Z, 'D') * CAP(TC, TCH)
  ) +

* Demand for Electricity by Processes
  SUM(TPPRC(TC,PRC),
    BALE_ACT(TP, TC, PRC, Z, 'D') * ACT(TC, PRC)
  ) +

*GG* V1.0i Demand for Electricity by Heating Plants
  SUM(HPL,
    BALE_HPL(TP, HPL, Z, 'D') * THZ(TP, HPL, Z)
  ) +

* Generation of Electricity
  SUM(ELA,
    BALE_TEZY(TP, ELA, Z, 'D') * TEZY(TP, ELA, Z, 'D')
  ) +

*GG* V1.1a Coupled Production Generation of Electricity
  SUM(CPD,
    BALE_TCZY(TP, CPD, Z, 'D') * TCZYH(TP, CPD, Z, 'D')
  )
)
  =G=
  0;

*============================================================================*
*  Electricity Balance Equation, Night                                       *
*============================================================================*
*GG* V0.8 add storage
EQ_BALE2(TP, Z, 'N') .. MMSCALE * (

*GG* V1.0e add import/export of electricity
  SUM((SRC, P),
    BALE_SEP(TP, SRC, 'ELC', P, Z, 'N') * TSEP(TP, SRC, 'ELC', P)
  ) +

*GG* V1.0i Use of an Energy Carrier for a Resource Supply Options
  SUM(SEP,
    (QHR(Z, 'N') * BAL_SEPENT(TP, SEP, 'ELC')) * TSEP(TP, SEP)
  ) +

* Electric Generation/consumption according to capacity, for externally load managed plants
  SUM(TPTCH(TC, TCH),
    BALE_CAP(TP, TC, TCH, Z, 'N') * CAP(TC, TCH)
  ) +

* Electric Generation for non-base-load and non-storage plants
  SUM(ELAXBAS$(NOT STG(ELAXBAS)),
    BALE_TEZY(TP, ELAXBAS, Z, 'N') * TEZY(TP, ELAXBAS, Z, 'N')
  ) +

* Electric Generation for base-load plants, other than storage
  SUM(ELABAS$(NOT STG(ELABAS)),
*GG* V1.0d use the 'N' coef to correspond to MARKAL manual
*    BALE_TEZY(TP, ELABAS, Z, 'D') * TEZY(TP, ELABAS, Z, 'D')
    BALE_TEZY(TP, ELABAS, Z, 'N') * TEZY(TP, ELABAS, Z, 'D')
  ) +

* Electric Demand by Processes
  SUM(TPPRC(TC, PRC),
    BALE_ACT(TP, TC, PRC, Z, 'N') * ACT(TC, PRC)
  ) +

*GG* V1.0i Demand for Electricity by Heating Plants
  SUM(HPL,
    BALE_HPL(TP, HPL, Z, 'N') * THZ(TP, HPL, Z)
  ) +

* Electric Demand for Storage
  SUM(STG,
    BALE_TEZY(TP, STG, Z, 'N') * TEZY(TP, STG, Z, 'D')
  ) +

*GG* V1.1a Coupled Production Generation of Electricity
*GG* V1.4a correct to handle BAS
  SUM(CPD$(NOT CPDBAS(CPD)),
    BALE_TCZY(TP, CPD, Z, 'N') * TCZYH(TP, CPD, Z, 'N')
  ) +
  SUM(CPDBAS,
    BALE_TCZY(TP, CPDBAS, Z, 'N') * TCZYH(TP, CPDBAS, Z, 'D')
  )
)
  =G=
  0;

*============================================================================*
*  Base-load Electric Equation                                               *
*============================================================================*
*GG* V1.1a only if base-load or non-load-management specified by the user
EQ_BAS(TP, Z)$(SUM(CON, 1$BAS(CON) OR 1$NLM(CON))) .. MMSCALE * (

*GG* V1.0e add import/export of electricity
  SUM((SRC, P),
    BAS_SEP(TP, SRC, 'ELC', P, Z) * TSEP(TP, SRC, 'ELC', P)
  ) +

* Base-load contribution from activity
  SUM((ELA, Y),
    BAS_TEZY(TP, ELA, Z, Y) * TEZY(TP, ELA, Z, Y)
  ) +

*GG* V1.1a Coupled Prodcution Base-load contribution
  SUM((CPD, Y),
    BAS_TCZY(TP, CPD, Z, Y) * TCZYH(TP, CPD, Z, Y)
  ) +

* Base-load contribution from capacity for externally load managed plants
  SUM(ELA,
    BAS_CAP(TP, ELA, Z) * CAP(TP, ELA)
  )
)
  =L=
  0;

*============================================================================*
*  Conversion Technology Annual Bounds, Lower                                *
*GG* V1.0i
*============================================================================*
*GG* V1.1a adjust for PEAKing only devices
EQ_BNDCON1(TPCON(TP, CON))$TCH_BNDO(CON, 'LO', TP) .. MMSCALE * (
  SUM((Z,Y),
    BND_TEZY(TP, CON, Z, Y) * TEZY(TP, CON, Z, Y))$ELA(CON) +
  SUM(Z,
    BND_THZ(TP, CON, Z) *THZ(TP, CON, Z))$HPL(CON) +
*GG* V1.1a add coupled production
  SUM((Z,Y), BND_TCZY(TP, CON, Z, Y) * TCZYH(TP, CON, Z, Y))$CPD(CON)
  )
  =G=
  MMSCALE * TCH_BNDO(CON, 'LO', TP);

*============================================================================*
*  Conversion Technology Annual Bounds, Fixed                                *
*GG* V1.0i
*============================================================================*
*GG* V1.1a adjust for PEAKing only devices
EQ_BNDCON2(TPCON(TP, CON))$TCH_BNDO(CON, 'FX', TP) .. MMSCALE * (
  SUM((Z,Y),
    BND_TEZY(TP, CON, Z, Y) * TEZY(TP, CON, Z, Y))$ELA(CON) +
  SUM(Z,
    BND_THZ(TP, CON, Z) *THZ(TP, CON, Z))$HPL(CON) +
*GG* V1.1a add coupled production
  SUM((Z,Y), BND_TCZY(TP, CON, Z, Y) * TCZYH(TP, CON, Z, Y))$CPD(CON)
  )
  =E=
  MMSCALE * TCH_BNDO(CON, 'FX', TP);

*============================================================================*
*  Conversion Technology Annual Bounds, Upper                                *
*GG* V1.0i
*============================================================================*
*GG* V1.1a adjust for PEAKing only devices
EQ_BNDCON3(TPCON(TP, CON))$TCH_BNDO(CON, 'UP', TP) .. MMSCALE * (
  SUM((Z,Y),
    BND_TEZY(TP, CON, Z, Y) * TEZY(TP, CON, Z, Y))$ELA(CON) +
  SUM(Z,
    BND_THZ(TP, CON, Z) *THZ(TP, CON, Z))$HPL(CON) +
*GG* V1.1a add coupled production
  SUM((Z,Y), BND_TCZY(TP, CON, Z, Y) * TCZYH(TP, CON, Z, Y))$CPD(CON)
  )
  =L=
  MMSCALE * TCH_BNDO(CON, 'UP', TP);

*============================================================================*
*  Capacity Transfer Equation for Demand Devices                             *
*============================================================================*
EQ_CPT1(TPDMD(TP, DMD)) .. MMSCALE * (
  CPT_CAP(TP, DMD) * CAP(TP, DMD) +
  SUM(TC,
    CPT_INV(TP, TC, DMD) * INV(TC, DMD)
  )
)
  =L=
  MMSCALE * TCH_RESID(DMD, TP);

*============================================================================*
*  Capacity Transfer Equation for Conversion Technologies                    *
*============================================================================*
EQ_CPT2(TPCON(TP, CON)) .. MMSCALE * (
  CPT_CAP(TP, CON) * CAP(TP, CON) +
  SUM(TC,
    CPT_INV(TP, TC, CON) * INV(TC, CON)
  )
)
  =E=
  MMSCALE * TCH_RESID(CON, TP);

*============================================================================*
*  Capacity Transfer Equation for Process Technologies                       *
*============================================================================*
EQ_CPT3(TPPRC(TP, PRC)) .. MMSCALE * (
  CPT_CAP(TP, PRC) * CAP(TP, PRC) +
  SUM(TC,
    CPT_INV(TP, TC, PRC) * INV(TC, PRC)
  )
)
  =E=
  MMSCALE * TCH_RESID(PRC, TP);

*============================================================================*
*  Cumulative Resource Availability                                          *
*============================================================================*
*GG* V1.1c scale down as in OMNI
EQ_CUM(SEP)$SEP_CUM(SEP) .. MMSCALE * (
  SUM(TP,
    CUM_TSEP(TP, SEP) * TSEP(TP, SEP)
  )
) / 1000
  =L=
  MMSCALE * SEP_CUM(SEP) / 1000;

*============================================================================*
*  Electric Plant Capacity/Activity                                          *
*============================================================================*
*GG* V1.1a adjust to handle PEAKing only devices
EQ_TEZY(TPELA(TP, ELA), Z, Y)$(NOT PEAK_ACT(ELA, Z, Y)) .. MMSCALE * (
  TEZY_TEZY(TP, ELA, Z, Y) * TEZY(TP, ELA, Z, Y) +
  TEZY_CAP(TP, ELA, Z, Y) * CAP(TP, ELA) +
*GG* V1.1a add coupled production
  (TEZY_TCZY(TP, ELA, Z, Y) * TCZYH(TP, ELA, Z, Y))$CPD(ELA) +
*GG* V1.1a add maintenance vector
  TEZY_TEZYM(TP, ELA, Z, Y) * M(TP, ELA, Z)
)
  =L=
  0;

*============================================================================*
*  Cumulative Emissions                                                      *
*============================================================================*
*GG* V1.0g introduce the rest of the env accounting components
*GG* V1.0g do the number of year multiply here so 1 less set of tables needed
*GG* V1.4b remove MMSCALE from emissions equations, rather leave it
EQ_ENV(ENV) .. MMSCALE * (
*EQ_ENV(ENV) .. (
*GG* V1.2c add the conditional checks

* Supply Options
  SUM(TPSEP(TP, SEP)$ENV_S(ENV, SEP),
    (NYRSPER * TENV_TSEP(TP, SEP, ENV)) * TSEP(TP, SEP))

* Process Activity, other than for externally load managed process
*GG* V1.0a adjust environmental accounting if zpr
  + SUM(TPPRC(TP, PRC)$(1$ENV_A(ENV, PRC) AND 1$(NOT ZPR(PRC))),
      (NYRSPER * TENV_TACT(TP, PRC, ENV)) * ACT(TP, PRC))

* Process Capacity
*GG* V1.3c add the activity class as XLM's may have ENVs by activity
*  + SUM(TPPRC(TP, PRC)$ENV_C(ENV, PRC),
  + SUM(TPPRC(TP, PRC)$(ENV_C(ENV, PRC) + ENV_A(ENV, PRC)),
      (NYRSPER * TENV_CAP(TP, PRC, ENV)) * CAP(TP, PRC))

* Electric Generation, except for externally load managed/base-load/storage
*  plants
*GG* V1.1a use the proper control table which takes things into account
*   + SUM(TPELA(TP, ELA)$(NOT (1$ELAXLM(ELA) OR 1$BAS(ELA) OR 1$STG(ELA))),
   + SUM((TPELA(TP, ELA), Z, Y)$(1$ENV_A(ENV, ELA) AND 1$(NOT ELAXLM(ELA))),
       (NYRSPER * TENV_TEZY(TPELA, Z, Y, ENV) *  TEZY(TPELA,Z,Y)) )

* Electric Generation from base-load/storage plants, except for externally
* load managed facilities
*  + SUM(TPELA(TP, ELA)$(NOT (1$ELAXLM(ELA)) AND (1$BAS(ELA) OR 1$STG(ELA))),
*      (NYRSPER * TENV_TACT(TPELA, ENV)) * SUM(Z, TEZY(TPELA,Z,'D')))

*GG* V1.1a Electric Generation from coupled production plants
  + SUM((TPCPD(TP, CPD),Z,Y)$(ENV_A(ENV, CPD)),
      (NYRSPER * TENV_TCZY(TPCPD, Z, Y, ENV) * TCZYH(TPCPD,Z,Y)))

* Heat Generation, except for externally load managed plants
*GG* V1.1a use the proper control table which takes things into account
  + SUM((TPHPL(TP, HPL), Z)$(1$ENV_A(ENV, HPL) AND 1$(NOT HPLXLM(HPL))),
      (NYRSPER * TENV_THZ(TPHPL, Z, ENV) * THZ(TPHPL,Z)) )

* Conversion Technology Capacity
*GG* V1.3c add the activity class as XLM's may have ENVs by activity
*  + SUM(TPCON(TP, CON)$ENV_C(ENV, CON),
  + SUM(TPCON(TP, CON)$(ENV_C(ENV, CON) + ENV_A(ENV, CON)),
      (NYRSPER * TENV_CAP(TP, CON, ENV)) * CAP(TP, CON))

* Activity of Demand Devices
  + SUM(TPDMD(TP, DMD)$ENV_C(ENV, DMD),
      (NYRSPER * TENV_CAP(TP, DMD, ENV)) * CAP(TP, DMD))

* Investment in Technologies
  + SUM(TPTCH(TP, TCH)$(ENV_I(ENV, TCH)),
       TENV_INV(TP, TCH, ENV) * INV(TP, TCH))

*GG* V1.1a add multiple emissions
*GG* V1.4b adjust EM scaling by MMSCALE
  + SUM((TP, GWP),
*GG* V1.4e use seperate scaler for emissions
*       ENV_GWP(ENV, GWP, TP) * EM(TP, GWP) / MMSCALE)
       ENV_GWP(ENV, GWP, TP) * EM(TP, GWP) / ENV_SCAL)
  )
*GG* V1.0d change cum env to L so RHS can be set from parameter
*  =N=
*  0;
*GG* V1.0g only MAX and name adjusted a little
  =L=
* Cumulative RHS
*GG* V1.2a apply the scale factor
*GG* V1.4b remove MMSCALE from emissions equations
   MMSCALE * ENV_CUM(ENV);
*   ENV_CUM(ENV);

*============================================================================*
*  Annual Emissions                                                          *
*============================================================================*
*GG* V1.0g introduce the rest of the env accounting components
*GG* V1.4b remove MMSCALE from emissions equations, rather leave it
EQ_TENV(TP, ENV) .. MMSCALE * (
*EQ_TENV(TP, ENV) .. (
* Supply Options
  SUM(TPSEP(TP, SEP)$ENV_S(ENV, SEP),
    TENV_TSEP(TP, SEP, ENV) * TSEP(TP, SEP))

* Process Activity, other than for externally load managed process
*GG* V1.0a adjust environmental accounting if zpr
  + SUM(TPPRC(TP, PRC)$(1$ENV_A(ENV, PRC) AND 1$(NOT ZPR(PRC))),
      TENV_TACT(TPPRC, ENV) * ACT(TPPRC))

* Process Capacity
*GG* V1.2c add the conditional checks
*GG* V1.3c add the activity class as XLM's may have ENVs by activity
*  + SUM(TPPRC(TP, PRC)$ENV_C(ENV, PRC),
  + SUM(TPPRC(TP, PRC)$(ENV_C(ENV, PRC) + ENV_A(ENV, PRC)),
      TENV_CAP(TP, PRC, ENV) * CAP(TP, PRC))

* Electric Generation, except for externally load managed/base-load/storage
*  plants
*GG* V1.1a use the proper control table which takes things into account
*   + SUM(TPELA(TP, ELA)$(NOT (1$ELAXLM(ELA) OR 1$BAS(ELA) OR 1$STG(ELA))),
   + SUM((TPELA(TP, ELA), Z, Y)$(1$ENV_A(ENV, ELA) AND 1$(NOT ELAXLM(ELA))),
       TENV_TEZY(TPELA, Z, Y, ENV) *  TEZY(TPELA,Z,Y) )

* Electric Generation from base-load/storage plants, except for externally
* load managed facilities
*  + SUM(TPELA(TP, ELA)$(NOT (1$ELAXLM(ELA)) AND (1$BAS(ELA) OR 1$STG(ELA))),
*      TENV_TACT(TPELA, ENV) * SUM(Z, TEZY(TPELA,Z,'D')))

*GG* V1.1a Electric Generation from coupled production plants
  + SUM((TPCPD(TP, CPD),Z,Y)$(ENV_A(ENV, CPD)),
      TENV_TCZY(TPCPD, Z, Y, ENV) * TCZYH(TPCPD,Z,Y))

* Heat Generation, except for externally load managed plants
*GG* V1.1a use the proper control table which takes things into account
  + SUM((TPHPL(TP, HPL),Z)$(1$ENV_A(ENV, HPL) AND 1$(NOT HPLXLM(HPL))),
      TENV_THZ(TPHPL, Z, ENV) * THZ(TPHPL,Z) )
*  + SUM(TPHPL(TP, HPL)$(NOT HPLXLM(HPL)),
*      TENV_TACT(TPHPL, ENV) * SUM(Z, THZ(TPHPL,Z)))

* Conversion Technology Capacity
*GG* V1.3c add the activity class as XLM's may have ENVs by activity
*  + SUM(TPCON(TP, CON)$ENV_C(ENV, CON),
  + SUM(TPCON(TP, CON)$(ENV_C(ENV, CON) + ENV_A(ENV, CON)),
      TENV_CAP(TP, CON, ENV) * CAP(TP, CON))

* Activity of Demand Devices
  + SUM(TPDMD(TP, DMD)$ENV_C(ENV, DMD),
      TENV_CAP(TP, DMD, ENV) * CAP(TP, DMD))

* Investment in Technologies
  + SUM(TPTCH(TP, TCH)$(ENV_I(ENV, TCH)),
      (TENV_INV(TP, TCH, ENV) / NYRSPER) * INV(TP, TCH))

*GG* V1.1a add multiple emissions
*GG* V1.4b adjust EM scaling by MMSCALE
  + SUM(GWP,
*GG* V1.4e use seperate scaler for emissions
*       ENV_GWP(ENV, GWP, TP) * EM(TP, GWP) / MMSCALE)
       ENV_GWP(ENV, GWP, TP) * EM(TP, GWP) / ENV_SCAL)

* Total Emissions
*GG* V1.4b adjust EM scaling by MMSCALE
*GG* V1.4e use seperate scaler for emissions
*  - EM(TP, ENV) / MMSCALE
  - EM(TP, ENV) / ENV_SCAL
  )
  =L=
  0;

*============================================================================*
*  Electric Peaking                                                          *
*  - Not 'I'ntermediate Season, *GG* V1.0i                                   *
*  - Note that the capacity coefficient table has values for generating      *
*   capacity and demand.                                                     *
*============================================================================*
EQ_EPK(TP, Z)$ZNOTI(Z) .. MMSCALE * (
*GG* V1.0e add import/export of electricity
  SUM((SRC, P),
    EPK_SEP(TP, SRC, 'ELC', P, Z) * TSEP(TP, SRC, 'ELC', P) )+

*GG* V1.0i electricity used by resource supply options
*GG* V1.1a add the PEAKDA indicator for peak requirement
  SUM(SEP,
    BAL_SEPENT(TP, SEP, 'ELC') * PEAKDA_SEP(SEP, TP) * TSEP(TP, SEP) ) +

* electric generation capacity & externally load managed processes and demands
  SUM(TPTCH(TC, TCH),
    EPK_CAP(TP, TC, TCH, Z) * CAP(TC, TCH) ) +

*GG* V1.1a PEAKing only devices
  SUM(TPELA(TC, ELA),
    EPK_TEZY(TP, TC, ELA, Z, 'D') * TEZY(TC, ELA, Z, 'D') ) +

* process demands
  SUM(TPPRC(TC, PRC),
    EPK_ACT(TP, TC, PRC, Z) * ACT(TC, PRC) ) +

*GG* V1.0i Heating demands
  SUM(HPL,
    EPK_HPL(TP, HPL, Z) * THZ(TP, HPL, Z) )
  )
  =G=
  0;

*============================================================================*
*  Cumulative Fossil Accounting                                              *
*GG* V1.1a added in full                                                     *
*============================================================================*
EQ_FOSSIL .. MMSCALE * (
  SUM(TPSEP(TP, SRC, EFS, P),
    NYRSPER * TFOSS_TSEP(TP, SRC, EFS, P) * TSEP(TP, SRC, EFS, P)
  )
)
  =N=
  0;

*============================================================================*
*  Annual Fossil Accounting                                                  *
*GG* V1.1a added in full                                                     *
*============================================================================*
EQ_TFOSSIL(TP) .. MMSCALE * (
  SUM(SEP(SRC, EFS, P),
    TFOSS_TSEP(TP, SRC, EFS, P) * TSEP(TP, SRC, EFS, P)
  )
)
  =N=
  0;

*============================================================================*
*  Heating Plant Capacity/Activity                                           *
*============================================================================*
*GG* V1.0e heating plants
*GG* V1.1a dont need XLM test EQ_THZ(TP, Z, HPL)$(NOT XLM(HPL)) .. MMSCALE * (
EQ_THZ(TPHPL(TP, HPL), Z)$(NOT PEAK_ACT(HPL, Z, 'D')) .. MMSCALE * (
  THZ_THZ(TP, HPL, Z) * THZ(TP, HPL, Z) +
  THZ_CAP(TP, HPL, Z) * CAP(TP, HPL) +
*GG* V1.1a add maintenance vector
  (1.0 * M(TP, HPL, Z))$TUTL_CON(TP, HPL)
)
  =L=
  0;

*============================================================================*
*  Resource Activity Interperiod Growth Constraint                           *
*============================================================================*
*GG* V1.1a add resource annual growth constraint
EQ_GRSEP(TPSEP(TP, SEP))$(ORD(TP) GT SEP_START(SEP)) .. MMSCALE * (
  SUM(TC$(ORD(TC) EQ ORD(TP) - 1), (
    - (SEP_TGR(SEP, TC) ** NYRSPER) * TSEP(TC, SEP) +
      TSEP(TP, SEP) )$SEP_TGR(SEP, TC))
)
  =L=
*GG* V1.2a apply scaling factor
  MMSCALE * SEP_GRTID(SEP);

*============================================================================*
*  Resource Technology Interperiod Growth Constraint                         *
*============================================================================*
*GG* V1.1a add resource annual growth constraint
EQ_GRTCH(TPTCH(TP, TCH))$(ORD(TP) GT TCH_START(TCH)) .. MMSCALE * (
  SUM(TC$(ORD(TC) EQ ORD(TP) - 1), (
    - (TCH_TGR(TCH, TC) ** NYRSPER) * CAP(TC, TCH) +
      CAP(TP, TCH) )$TCH_TGR(TCH, TC))
)
  =L=
*GG* V1.2a apply scaling factor
  MMSCALE * TCH_GRTID(TCH);

*============================================================================*
*  Heat Peaking                                                              *
*   Note that the coefficient table has values for generating capacity and   *
*   demand.                                                                  *
*============================================================================*
*GG* V1.0e add heat peaking, both consumption by DMD and generation capacity
*GG* V1.3b only generate heat peaking equation when heating required
EQ_HPKW(TP)$SUM(DD_MA(DMD,'LTH'),1) .. MMSCALE * (
  SUM(TCH,
    HPKW_CAP(TP, TCH) * CAP(TP, TCH) ) +
*GG* V1.1a add PEAKing only devices
  SUM(HPL,
    HPKW_ACT(TP, HPL) * THZ(TP, HPL, 'W') ) +
*GG* V1.1a add coupled production plants
  SUM(CPD,
    HPKW_TCPD(TP, CPD) * CAP(TP, CPD) )
  )
  =G=
  0;

*============================================================================*
*  Investment in Technologies                                                *
*============================================================================*
EQ_INVEST(TP) .. MMSCALE * (
  SUM(TCH,
    INVEST_INV(TP, TCH) * INV(TP, TCH)
  )
)
  =N=
  0;

*============================================================================*
*  Cumulative Non-Renewable Accounting                                       *
*GG* V1.1a added in full                                                     *
*============================================================================*
EQ_NONRNW .. MMSCALE * (
  SUM(TPSEP(TP, SRC, EFS, P),
    NYRSPER * TNONR_TSEP(TP, SRC, EFS, P) * TSEP(TP, SRC, EFS, P)) +
  SUM(TPPRC(TP, PRC),
    NYRSPER * TNONR_ACT(TP, PRC) * ACT(TP, PRC)) +
  SUM((TPELA(TP, ELA), Z, Y),
    NYRSPER * TNONR_EZY(TP, ELA, Z, Y) * TEZY(TP, ELA, Z, Y)) +
  SUM(TPTCH(TP, TCH)$(NOT DMD(TCH)),
    NYRSPER * TNONR_CAP(TP, TCH) * CAP(TP, TCH)) +
  SUM((TPHPL(TP, HPL), Z),
    NYRSPER * TNONR_HZ(TP, HPL, Z) * THZ(TP, HPL, Z)) +
  SUM((TPCPD(TP, CPD), Z, Y),
    NYRSPER * TNONR_CZY(TP, CPD, Z, Y) * TCZYH(TP, CPD, Z, Y))
)
  =N=
  0;

*============================================================================*
*  Annual Non-Renewable Accounting                                           *
*GG* V1.1a added in full                                                     *
*============================================================================*
EQ_TNONRNW(TP) .. MMSCALE * (
  SUM(SEP(SRC, EFS, P),
    TNONR_TSEP(TP, SRC, EFS, P) * TSEP(TP, SRC, EFS, P)) +
  SUM(TPPRC(TP, PRC),
    TNONR_ACT(TP, PRC) * ACT(TP, PRC)) +
  SUM((TPELA(TP, ELA), Z, Y),
    TNONR_EZY(TP, ELA, Z, Y) * TEZY(TP, ELA, Z, Y)) +
  SUM(TPTCH(TP, TCH)$(NOT DMD(TCH)),
    TNONR_CAP(TP, TCH) * CAP(TP, TCH)) +
  SUM((TPHPL(TP, HPL), Z),
    TNONR_HZ(TP, HPL, Z) * THZ(TP, HPL, Z)) +
  SUM((TPCPD(TP, CPD), Z, Y),
    TNONR_CZY(TP, CPD, Z, Y) * TCZYH(TP, CPD, Z, Y))
)
  =N=
  0;

*============================================================================*
*  Cumulative Nuclear Accounting                                             *
*GG* V1.1a added in full                                                     *
*============================================================================*
EQ_NUCLEAR .. MMSCALE * (
  SUM(TPPRC(TP, PRC),
    NYRSPER * TNUCL_ACT(TP, PRC) * ACT(TP, PRC)) +
  SUM((TPELA(TP, ELANUC), Z, Y),
    NYRSPER * TNUCL_EZY(TP, ELANUC, Z, Y) * TEZY(TP, ELANUC, Z, Y)) +
  SUM(TPTCH(TP, TCH)$(NOT DMD(TCH)),
    NYRSPER * TNUCL_CAP(TP, TCH) * CAP(TP, TCH)) +
  SUM((TPHPL(TP, HPL), Z),
    NYRSPER * TNUCL_HZ(TP, HPL, Z) * THZ(TP, HPL, Z)) +
  SUM((TPCPD(TP, CPD), Z, Y),
    NYRSPER * TNUCL_CZY(TP, CPD, Z, Y) * TCZYH(TP, CPD, Z, Y))
)
  =N=
  0;

*============================================================================*
*  Annual Nuclear Accounting                                                 *
*GG* V1.1a added in full                                                     *
*============================================================================*
EQ_TNUCLAR(TP) .. MMSCALE * (
  SUM(PRC,
    TNUCL_ACT(TP, PRC) * ACT(TP, PRC)) +
  SUM((ELANUC, Z, Y),
    TNUCL_EZY(TP, ELANUC, Z, Y) * TEZY(TP, ELANUC, Z, Y)) +
  SUM(TCH$(NOT DMD(TCH)),
    TNUCL_CAP(TP, TCH) * CAP(TP, TCH)) +
  SUM((HPL,Z),
    TNUCL_HZ(TP, HPL, Z) * THZ(TP, HPL, Z)) +
  SUM((CPD, Z, Y),
    TNUCL_CZY(TP, CPD, Z, Y) * TCZYH(TP, CPD, Z, Y))
)
  =N=
  0;

*============================================================================*
*  Limit Process Total Output                                                *
*============================================================================*
EQ_PBL(TP, PRC)$(1$TPPRC(TP, PRC) AND PRC_LIM(PRC, TP)) .. MMSCALE * (
  (PRC_LIM(PRC, TP) * ACT(TP, PRC))$(NOT ZPR(PRC)) +
  (SUM(ENC$PRC_OUT(PRC, ENC, TP), -1.0 * LOUT(TP, PRC, ENC))) +
 (TCH_CAPUNI(PRC) * TCH_CF2(PRC, TP) * PRC_LIM(PRC, TP) * CAP(TP, PRC))$ZPR(PRC)
)
  =E=
  0;

*============================================================================*
*  Limit Process Individual Outputs                                          *
*============================================================================*
EQ_LIM(TP, PRC, ENC)$(1$TPPRC(TP, PRC) AND PRC_LIM(PRC, TP) AND
                      PRC_OUT(PRC, ENC, TP)) .. MMSCALE * (
  (- PRC_OUT(PRC, ENC, TP) * ACT(TP, PRC))$(NOT ZPR(PRC)) +
  (- TCH_CAPUNI(PRC) * TCH_CF2(PRC, TP) * PRC_OUT(PRC, ENC, TP) * CAP(TP, PRC))
     $ZPR(PRC) +
  (LOUT(TP, PRC, ENC))
)
  =L=
  0;

*============================================================================*
*  Total Discounted System Cost without Renewable Technologies               *
*============================================================================*
EQ_PRICER .. MMSCALE * (

* Resource Supply Options
*GG* V1.0i just use price coefficents except for renewables
  SUM(tpsep(TP, SEP),
    PRICE_TSEP(TP, SEP) * TSEP(TP, SEP)
  ) +

* Stockpiling
  SUM((TP, ENC, P),
    PRICE_ZSTK(TP, ENC, P) * ZSTK(ENC, P)
  ) +

* Process Activity
  SUM(TPPRC(TP, PRC),
    PRICE_ACT(TP, PRC) * ACT(TP, PRC)
  ) +

* Technology Capacity
  SUM(TPTCH(TP, TCH),
    PRICE_CAP(TP, TCH) * CAP(TP, TCH)
  ) +

* Electricity Generation
  SUM((TPELA(TP, ELA), Z, Y),
    PRICE_TEZY(TP, ELA, Z, Y) * TEZY(TP, ELA, Z, Y)
  ) +

*GG* V1.1a Electric Generation from Couple Production
  SUM((TPCPD(TP, CPD), Z, Y),
    PRICE_TCZY(TP, CPD, Z, Y) * TCZYH(TP, CPD, Z, Y)
  ) +

* Heat Generation
*GG* V1.0e add heating plants
  SUM((TPHPL(TP, HPL), Z),
    PRICE_THZ(TP, HPL, Z) * THZ(TP, HPL, Z)
  ) +

* Investment in Technologies, other than Renewables
*GG* V1.0i just use PRICE coefficients except for newables
  SUM(TPTCH(TP, TCH)$(NOT RNT(TCH)),
    PRICE_INV(TP, TCH) * INV(TP, TCH)
  ) +

* Investment in Renewables Technologies
*GG* V1.4f only if has life/investment
  SUM(TPTCH(TP, RNT)$INVEST_INV(TP,RNT),
    0.00001 * INV(TP, RNT)
  ) +

* Emissions Costs
*GG* V1.0g add the emission tax if appropriate
*GG* V1.4b adjust EM scaling by MMSCALE
  SUM((TP,ENV)$ENV_COST(ENV, TP),
*GG* V1.4e use seperate scaler for emissions
*       PRICE_DF(TP) * ENV_COST(ENV, TP) * EM(TP, ENV) / MMSCALE
       PRICE_DF(TP) * ENV_COST(ENV, TP) * EM(TP, ENV) / ENV_SCAL
  )
)
  =N=
  0;

*============================================================================*
*  Salavage Correction Accounting                                            *
*============================================================================*
EQ_SALVAGE(TP) .. MMSCALE * (
  SUM(TCH,
    SALVAG_INV(TP, TCH) * INV(TP, TCH)
  )
)
  =N=
  0;

*============================================================================*
*  Cumulative Security Inidcator of Supply Options                           *
*============================================================================*
EQ_SECURIT .. MMSCALE * (
  SUM(TPSEP(TP, SEP),
    SECUR_TSEP(TP, SEP) * TSEP(TP, SEP)
  )
)
  =N=
  0;

*============================================================================*
*  Annual Security Indicator of Supply Options                               *
*============================================================================*
EQ_TSECURI(TP) .. MMSCALE * (
  SUM(SEP,
    TSECU_TSEP(TP, SEP) * TSEP(TP, SEP)
  )
)
  =N=
  0;

*============================================================================*
*  Scheduled Maintenance for Conversion Technologies                         *
*============================================================================*
*GG* V1.1a add maintenance
EQ_UTLCON(TPCON(TP, CON))$TUTL_CON(TP, CON) .. MMSCALE * (
  SUM(Z,
    1.0 * M(TP, CON, Z)) +
  TUTL_CON(TP, CON) * CAP(TP, CON)
)
  =G=
  0;

*============================================================================*
*  Process Capacity/Activity                                                 *
*============================================================================*
EQ_UTLPRC(TPPRC(TP, PRC)) .. MMSCALE * (
  UTLPRC_ACT(TP, PRC) * ACT(TP, PRC) +
  UTLPRC_CAP(TP, PRC) * CAP(TP, PRC)
)
  =L=
  0;

*============================================================================*
*  Balance Equation for Energy Carrier Tax/Subsidy                           *
*============================================================================*
*GG* V1.4e add tax/subsidy
EQ_TXSUB(TP, TAXSUB) .. MMSCALE * (
  SUM(ENC$TSUB_ENT(TAXSUB,ENC),

* Resource Supply Options
  SUM((SRC, P)$TSUB_SEP(TAXSUB,SRC,ENC,P,TP), TSUB_SEP(TAXSUB,SRC,ENC,P,TP) * (
      -1$(BAL_TSEP(TP,TP,SRC,ENC,P) < 0) *
      BAL_TSEP(TP, TP, SRC, ENC, P) * TSEP(TP, SRC, ENC, P)
    )
  )

* Use of an Energy Carrier for a Resource Supply Options
* + SUM(SEP,
*    BAL_SEPENT(TP, SEP, ENC) * TSEP(TP, SEP)
* )

* Process Activity, not LIMIT
  + SUM(TPPRC(TC, PRC)$TSUB_TCH(TAXSUB,PRC,TP), TSUB_TCH(TAXSUB,PRC,TP) * (
      -1$(BAL_ACT(TP,TC,PRC,ENC) < 0) *
      BAL_ACT(TP, TC, PRC, ENC) *
      (ACT(TC, PRC)$(NOT PRC_LIM(PRC, TP) OR
                    (PRC_INP2(PRC, ENC, TP) AND 1$(NOT ZPR(PRC)))) +
       LOUT(TC, PRC, ENC)$(PRC_LIM(PRC, TP) AND (NOT PRC_INP2(PRC, ENC, TP))))
    )
  )

* Technology Capacity & Investment
  + SUM(TPTCH(TC, TCH)$TSUB_TCH(TAXSUB,TCH,TP), TSUB_TCH(TAXSUB,TCH,TP) * (
      -1$(BAL_CAP(TP,TC,TCH,ENC) < 0) *
      BAL_CAP(TP, TC, TCH, ENC) * CAP(TC, TCH) +
      (-1$(BAL_INV(TP,TC,TCH,ENC) < 0)) *
      BAL_INV(TP, TC, TCH, ENC) * INV(TC, TCH)
    )
  )

* Electricity Generation
  + SUM((ELA, Z, Y)$TSUB_TCH(TAXSUB,ELA,TP), TSUB_TCH(TAXSUB,ELA,TP) * (
      -1$(BAL_TEZY(TP,ELA,ENC,Z,Y) < 0) *
      BAL_TEZY(TP, ELA, ENC, Z, Y) * TEZY(TP, ELA, Z, Y)
    )
  )

* Coupled Production Plants
  + SUM((CPD, Z, Y)$TSUB_TCH(TAXSUB,CPD,TP), TSUB_TCH(TAXSUB,CPD,TP) * (
      -1$(BAL_TCZY(TP,CPD,ENC,Z,Y) < 0) *
      BAL_TCZY(TP, CPD, ENC, Z, Y) * TCZYH(TP, CPD, Z, Y)
    )
  )

* Heat Generation
  + SUM((HPL, Z)$TSUB_TCH(TAXSUB,HPL,TP), TSUB_TCH(TAXSUB,HPL,TP) * (
      -1$(BAL_THZ(TP,HPL,ENC,Z) < 0) *
      BAL_THZ(TP, HPL, ENC, Z) * THZ(TP, HPL, Z)
    )
  )
  ) +

*============================================================================*
*  Electricity Balance Equation, Day                                         *
*============================================================================*
   SUM((ELC,Z)$TSUB_ENT(TAXSUB,ELC),

* import/export of electricity
  + SUM((SRC,P)$TSUB_SEP(TAXSUB,SRC,ELC,P,TP), TSUB_SEP(TAXSUB,SRC,ELC,P,TP) * (
      -1$(BALE_SEP(TP,SRC,ELC,P,Z,'D') < 0) *
      BALE_SEP(TP, SRC, ELC, P, Z, 'D') * TSEP(TP, SRC, ELC, P)
    )
  )

* Use of an Energy Carrier for a Resource Supply Options
*  + SUM(SEP,
*    (QHR(Z, 'D') * BAL_SEPENT(TP, SEP, 'ELC')) * TSEP(TP, SEP)
*  )

* Production/Consumption according to capacity
  + SUM(TPTCH(TC, TCH)$TSUB_TCH(TAXSUB,TCH,TP), TSUB_TCH(TAXSUB,TCH,TP) * (
      -1$(BALE_CAP(TP,TC,TCH,Z,'D') < 0) *
      BALE_CAP(TP, TC, TCH, Z, 'D') * CAP(TC, TCH)
    )
  )

* Demand for Electricity by Processes
  - SUM(TPPRC(TC,PRC)$TSUB_TCH(TAXSUB,PRC,TP), TSUB_TCH(TAXSUB,PRC,TP) * (
      BALE_ACT(TP, TC, PRC, Z, 'D') * ACT(TC, PRC)
    )
  )

* Demand for Electricity by Heating Plants
  - SUM(HPL$TSUB_TCH(TAXSUB,HPL,TP), TSUB_TCH(TAXSUB,HPL,TP) * (
      BALE_HPL(TP, HPL, Z, 'D') * THZ(TP, HPL, Z)
    )
  )

* Generation of Electricity
  + SUM(ELA$TSUB_TCH(TAXSUB,ELA,TP), TSUB_TCH(TAXSUB,ELA,TP) * (
      BALE_TEZY(TP, ELA, Z, 'D') * TEZY(TP, ELA, Z, 'D')
    )
  )

* Coupled Production Generation of Electricity
  + SUM(CPD$TSUB_TCH(TAXSUB,CPD,TP), TSUB_TCH(TAXSUB,CPD,TP) * (
      BALE_TCZY(TP, CPD, Z, 'D') * TCZYH(TP, CPD, Z, 'D')
    )
  )

*============================================================================*
*  Electricity Balance Equation, Night                                       *
*============================================================================*
* import/export of electricity
  + SUM((SRC,P)$TSUB_SEP(TAXSUB,SRC,ELC,P,TP), TSUB_SEP(TAXSUB,SRC,ELC,P,TP) * (
      -1$(BALE_SEP(TP,SRC,ELC,P,Z,'N') < 0) *
      BALE_SEP(TP, SRC, ELC, P, Z, 'N') * TSEP(TP, SRC, ELC, P)
    )
  )

*GG* V1.0i Use of an Energy Carrier for a Resource Supply Options
*  + SUM(SEP,
*    (QHR(Z, 'N') * BAL_SEPENT(TP, SEP, 'ELC')) * TSEP(TP, SEP)
*  )

* Electric Generation/consumption according to capacity, for externally load managed plants
  + SUM(TPTCH(TC, TCH)$TSUB_TCH(TAXSUB,TCH,TP), TSUB_TCH(TAXSUB,TCH,TP) * (
      -1$(BALE_CAP(TP,TC,TCH,Z,'N') < 0) *
      BALE_CAP(TP, TC, TCH, Z, 'N') * CAP(TC, TCH)
    )
  )

* Electric Generation for non-base-load and non-storage plants
  + SUM(ELAXBAS$(1$(NOT STG(ELAXBAS)) + TSUB_TCH(TAXSUB,ELAXBAS,TP)),
      TSUB_TCH(TAXSUB,ELAXBAS,TP) * (
      BALE_TEZY(TP, ELAXBAS, Z, 'N') * TEZY(TP, ELAXBAS, Z, 'N')
    )
  )

* Electric Generation for base-load plants, other than storage
  + SUM(ELABAS$(1$(NOT STG(ELABAS)) + TSUB_TCH(TAXSUB,ELABAS,TP)),
      TSUB_TCH(TAXSUB,ELABAS,TP) * (
      BALE_TEZY(TP, ELABAS, Z, 'N') * TEZY(TP, ELABAS, Z, 'D')
    )
  )

* Electric Demand by Processes
  - SUM(TPPRC(TC, PRC)$TSUB_TCH(TAXSUB,PRC,TP), TSUB_TCH(TAXSUB,PRC,TP) * (
      BALE_ACT(TP, TC, PRC, Z, 'N') * ACT(TC, PRC)
    )
  )

* Demand for Electricity by Heating Plants
  - SUM(HPL$TSUB_TCH(TAXSUB,HPL,TP), TSUB_TCH(TAXSUB,HPL,TP) * (
      BALE_HPL(TP, HPL, Z, 'N') * THZ(TP, HPL, Z)
    )
  )

* Electric Demand for Storage
  - SUM(STG$TSUB_TCH(TAXSUB,STG,TP), TSUB_TCH(TAXSUB,STG,TP) * (
      BALE_TEZY(TP, STG, Z, 'N') * TEZY(TP, STG, Z, 'D')
    )
  )

*GG* Coupled Production Generation of Electricity
  + SUM(CPD$(1$(NOT CPDBAS(CPD)) + TSUB_TCH(TAXSUB,CPD,TP)),
      TSUB_TCH(TAXSUB,CPD,TP) * (
      BALE_TCZY(TP, CPD, Z, 'N') * TCZYH(TP, CPD, Z, 'N')
    )
  )
  + SUM(CPDBAS$TSUB_TCH(TAXSUB,CPDBAS,TP),
      TSUB_TCH(TAXSUB,CPDBAS,TP) * (
      BALE_TCZY(TP, CPDBAS, Z, 'N') * TCZYH(TP, CPDBAS, Z, 'D')
    )
  )
  ) +

*============================================================================*
*  Low-temperature Heat Balance Equation                                     *
*============================================================================*
  SUM((LTH,Z)$TSUB_ENT(TAXSUB,LTH),

* Demand for and Contribution from capacity for externally load managed plants
    SUM(TCH$TSUB_TCH(TAXSUB,TCH,TP), TSUB_TCH(TAXSUB,TCH,TP) * (
      -1$(BALH_CAP(TP,TP,TCH,Z) < 0) *
      BALH_CAP(TP, TP, TCH, Z) * CAP(TP, TCH)
    )
  )

* Heat from Coupled Production Plants
  + SUM((CPD,Y)$TSUB_TCH(TAXSUB,CPD,TP), TSUB_TCH(TAXSUB,CPD,TP) * (
      BALH_TCZY(TP, CPD, Z, Y) *
      (TCZYH(TP, CPD, Z, Y)$CPD_ELM(CPD) + TEZY(TP, CPD, Z, Y)$CPD_REH(CPD))
    )
  )

* Contribution from activity
  + SUM(HPL$(1$(NOT HPLXLM(HPL)) + TSUB_TCH(TAXSUB,HPL,TP)),
      TSUB_TCH(TAXSUB,HPL,TP) * (BALH_THZ(TP, HPL, Z) * THZ(TP, HPL, Z)
    )
  )
  )

* balance variable
  - TXSUB(TP, TAXSUB)

)

  =E=
  0;
