*******************************************************************************
*                                                                             *
*  Interpolate the User MARKAL Input Tables and Initialize Some Defaults      *
*                                                                             *
*******************************************************************************
*GG* re-write using batinclude and FILLTAB2/3/4.GMS
*GG* V1.0g init intepolation set according to actual years
SET FIL(YEAR)
PARAMETER  FIL2(YEAR);
*GG* V1.2a introduce Ken Noble's tempary array to speed filling
PARAMETER  TEMPARRAY(YEAR);
SCALAR F;
$EOLCOM !

******************************************************************************
*  Interpolate the Individual User Input Tables                              *
******************************************************************************

*============================================================================*
*  ADRATIOs - User Defined Constraints                                       *
*   - (TYP) row RHS Values                                                   *
*   - Capacities                                                             *
*   - Process Activities                                                     *
*   - Resource Supply Options                                                *
*   - Electric Conversion Plant Activity                                     *
*   - Heating Conversion Plant Activity                                      *
*GG* V1.1a - Investment in a technology                                      *
*============================================================================*
*GG* V1.1a improve xeq time by setting up preprocess sets
SET ADR_TCHC(ADRATIO, TCH) / EMPTY.EMPTY /;
  ADR_TCHC(ADRATIO, TCH)$(SUM(TP, RAT_CAP(ADRATIO, TCH, TP))) = YES;
SET ADR_TCHI(ADRATIO, TCH) / EMPTY.EMPTY /;
  ADR_TCHI(ADRATIO, TCH)$(SUM(TP, RAT_INV(ADRATIO, TCH, TP))) = YES;
SET ADR_CON(ADRATIO, CON, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY /;
  ADR_CON(ADRATIO, CON, Z, Y)$(SUM(TP, 1$RAT_TEZY(ADRATIO, CON, Z, Y, TP)))=YES;
SET ADR_CPD(ADRATIO, CPD, Z, Y) / EMPTY.EMPTY.EMPTY.EMPTY /;
  ADR_CPD(ADRATIO, CPD, Z, Y)$(SUM(TP, 1$RAT_TCZY(ADRATIO, CPD, Z, Y, TP)))=YES;
SET ADR_HPL(ADRATIO, HPL, Z) / EMPTY.EMPTY.EMPTY /;
  ADR_HPL(ADRATIO, HPL, Z)$(SUM(TP, 1$RAT_HPL(ADRATIO, HPL, Z, TP)))=YES;
SET ADR_PRC(ADRATIO, PRC) / EMPTY.EMPTY /;
  ADR_PRC(ADRATIO, PRC)$(SUM(TP, 1$RAT_ACT(ADRATIO, PRC, TP)))=YES;
SET ADR_SEP(ADRATIO, SRC, ENT, P) / EMPTY.EMPTY.EMPTY.EMPTY /;
  ADR_SEP(ADRATIO, SEP)$(SUM(TP, 1$RAT_TSEP(ADRATIO, SEP, TP)))=YES;
$BATINCLUDE FILLTAB3.GMS RAT_RTY2 ADRATIO RTY
$BATINCLUDE FILLTAB2.GMS RAT_CAP ADR_TCHC
$BATINCLUDE FILLTAB2.GMS RAT_ACT ADR_PRC
$BATINCLUDE FILLTAB2.GMS RAT_TSEP ADR_SEP
$BATINCLUDE FILLTAB2.GMS RAT_TEZY ADR_CON
*GG* V1.0h add ADRATIO heating plants
$BATINCLUDE FILLTAB2.GMS RAT_HPL ADR_HPL
*GG* V1.1 add CPDs
$BATINCLUDE FILLTAB2.GMS RAT_TCZY ADR_CPD
$BATINCLUDE FILLTAB2.GMS RAT_INV ADR_TCHI

*============================================================================*
*  CON - Conversion Technology                                               *
*   - Input of an Energy Carrier                                             *
*   - Output of an Energy Carrier                                            *
*============================================================================*
*GG* V1.1a improve xeq time by setting up preprocess sets
SET CON_ENC(CON, ENC) / EMPTY.EMPTY /;
  CON_ENC(CON, ENC)$(SUM(TP, 1$CON_INP1(CON, ENC, TP) OR
                             1$CON_OUT(CON, ENC, TP)))=YES;
SET CON_ELC(CON, ENT) / EMPTY.EMPTY /;
  CON_ELC(CON, 'ELC')$(SUM(TP, CON_INP1(CON, 'ELC', TP))) = YES;
SET CON_FEQ(CON, ENT) / EMPTY.EMPTY /;
  CON_FEQ(CON, 'FEQ')$(SUM(TP, CON_INP1(CON, 'FEQ', TP))) = YES;
$BATINCLUDE FILLTAB2.GMS CON_INP1 CON_ENC
$BATINCLUDE FILLTAB2.GMS CON_INP1 CON_ELC
$BATINCLUDE FILLTAB2.GMS CON_INP1 CON_FEQ
$BATINCLUDE FILLTAB2.GMS CON_OUT CON_ENC

*============================================================================*
*  DMD - Demand Devices                                                      *
*   - Efficiency                                                             *
*   - Input Energy Carrier                                                   *
*   - Output to another DM
*============================================================================*
$BATINCLUDE FILLTAB2.GMS DMD_EFF DMD
DMD_EFF(DMD, TP)$(NOT DMD_EFF(DMD, TP)) = 1;
*GG* V1.1a improve xeq time by setting up preprocess sets
SET DD_MA(DMD, ENT) / EMPTY.EMPTY /;
  DD_MA(DMD, ENT)$(SUM(TP, DMD_MA(DMD, ENT, TP))) = YES;
SET DD_MO(DMD, ENC) / EMPTY.EMPTY /;
  DD_MO(DMD, ENC)$(SUM(TP, DMD_MO(DMD, ENC, TP))) = YES;
SET DMD_DMS(DMD, DM) / EMPTY.EMPTY /;
  DMD_DMS(DMD, DM)$SUM(TP, DMD_OUT(DMD, DM, TP)) = YES;
$BATINCLUDE FILLTAB2.GMS DMD_MA DD_MA
*GG* v1.0i allow for output to other DMs
$BATINCLUDE FILLTAB2.GMS DMD_OUT DMD_DMS
*GG* V1.1a set default and create the complete list of devices to demand sectors
  DMD_OUT(DMD_DM(DMD, DM), TP)$(NOT DMD_OUT(DMD, DM, TP)) = 1;
  DMD_DMS(DMD, DM) = DMD_DM(DMD, DM) + DMD_DMS(DMD, DM);
*GG* V1.0i add energy carrier from demand devices
$BATINCLUDE FILLTAB2.GMS DMD_MO DD_MO

*GG* V1.3b move to after DMDs so can init UNIFDIST if missing
*============================================================================*
*  DM - Demands                                                              *
*   - Demand Levels                                                          *
*   - Fraction of Demand Entering Peak Equation                              *
*   - Set Fraction of Demand in Each Season                                  *
*============================================================================*
*GG* V1.0i add the demands too!
$BATINCLUDE FILLTAB2.GMS DM_DEMAND DM
$BATINCLUDE FILLTAB2.GMS DM_ELF DM
* fill in table where no user value was provided
DM_ELF(DM, TP)$(NOT DM_ELF(DM, TP)) = 1;
*GG* V1.3b adjust to deal with both missing if some device uses electricity
*DM_UNIFDIS(DM)$((DM_UNIFDIS(DM) EQ 0) AND (SUM(TD,DM_FR(DM,TD)) EQ 0)) = 1.;
DM_UNIFDIS(DM)$(((DM_UNIFDIS(DM) EQ 0) AND (SUM(TD,DM_FR(DM,TD)) EQ 0)) AND
                                           (SUM(DMD$(1$DMD_DMS(DMD,DM) AND
                       (1$DD_MA(DMD,'ELC') OR 1$DD_MA(DMD,'LTH'))),1))) = 1;
DM_FR(DM, Z, Y) = QHR(Z, Y)$DM_UNIFDIS(DM) +
                            DM_FR(DM, Z, Y)$(NOT DM_UNIFDIS(DM));

*============================================================================*
*  ENV - Environmental Indicators                                            *
*   - Resource Supply Options                                                *
*   - Activity of a Technology                                               *
*   - Capacity of a Technology                                               *
*   - Investment in a Technology                                             *
*   - Cost Associated with an Emissions                                      *
*   - EC adjustment for emissions_tax_revenues                               *
*   - Emission Bounds                                                        *
*============================================================================*
*GG* V1.1a improve xeq time by setting up preprocess sets
SET ENV_S(ENV, SRC, ENT, P) / EMPTY.EMPTY.EMPTY.EMPTY /;
  ENV_S(ENV, SEP)$SUM(TP, ENV_TSEP(ENV, SEP, TP)) = YES;
SET ENV_A(ENV, TCH) / EMPTY.EMPTY /;
  ENV_A(ENV, TCH)$SUM(TP, ENV_TACT(ENV, TCH, TP)) = YES;
SET ENV_C(ENV, TCH) / EMPTY.EMPTY /;
  ENV_C(ENV, TCH)$SUM(TP, ENV_CAP(ENV, TCH, TP)) = YES;
SET ENV_I(ENV, TCH) / EMPTY.EMPTY /;
  ENV_I(ENV, TCH)$SUM(TP, ENV_INV(ENV, TCH, TP)) = YES;
$BATINCLUDE FILLTAB2.GMS ENV_TSEP ENV_S
$BATINCLUDE FILLTAB2.GMS ENV_TACT ENV_A
*GG* V1.0g add the rest of the emission tracking options
$BATINCLUDE FILLTAB2.GMS ENV_CAP ENV_C
$BATINCLUDE FILLTAB2.GMS ENV_INV ENV_I
$BATINCLUDE FILLTAB2.GMS ENV_COST ENV
$BATINCLUDE FILLTAB2.GMS ENV_TAX ENV
$BATINCLUDE FILLTAB3.GMS ENV_GWP ENV GWP
*GG* V1.0i add the emissions bounds
$BATINCLUDE FILLTAB2.GMS EM_BOUND ENV

*============================================================================*
*  PEAK - Conversion Technology Peaking Contribution                         *
*============================================================================*
$BATINCLUDE FILLTAB2.GMS PEAK1 CON

*============================================================================*
*  PEAKDA - Peaking Consumption by Process & Supply options using electricity*
*============================================================================*
*GG* V1.1a add the peaking adjustment options
$BATINCLUDE FILLTAB2.GMS PEAKDA_PRC PRC
$BATINCLUDE FILLTAB2.GMS PEAKDA_SEP SEP
*GG* V1.2d add initialization that imports assumed to contribute to peak
PEAKDA_SEP('IMP', 'ELC', P, TP)$(1$IMPEXPELC('IMP', P) AND
                                 1$(NOT PEAKDA_SEP('IMP', 'ELC', P, TP))) = 1;
PEAKDA_SEP('IMP', 'ELC', P, TP)$(1$IMPEXPELC('IMP', P) AND
                               1$(PEAKDA_SEP('IMP', 'ELC', P, TP) EQ EPS)) = 0;
PEAKDA_SEP(SEP('EXP', 'ELC', P), TP)$(NOT PEAKDA_SEP(SEP, TP)) = 1.0;

*============================================================================*
*  PRC - Process Technologies                                                *
*   - Input to a Process                                                     *
*   - Input to a Process, in the Previous Period                             *
*   - Output from a Process                                                  *
*   - Output from a Process, Delayed One Period                              *
*============================================================================*
*GG* V1.1a improve xeq time by setting up preprocess sets
SET PRC_ENC(PRC, ENC) / EMPTY.EMPTY /;
  PRC_ENC(PRC, ENC)$(SUM(TP, 1$PRC_INP2(PRC, ENC, TP) OR 1$PRC_LAG(PRC, ENC, TP)
                   OR 1$PRC_LED(PRC, ENC, TP) OR 1$PRC_OUT(PRC, ENC, TP))) = YES;
SET PRC_ELC(PRC, ENT) / EMPTY.EMPTY /;
  PRC_ELC(PRC, 'ELC')$(SUM(TP, 1$PRC_INP2(PRC, 'ELC', TP) OR
                               1$PRC_LED(PRC, 'ELC', TP))) = YES;
SET PRC_FEQ(PRC, ENT) / EMPTY.EMPTY /;
  PRC_FEQ(PRC, 'FEQ')$(SUM(TP, PRC_INP2(PRC, 'FEQ', TP))) = YES;
$BATINCLUDE FILLTAB2.GMS PRC_INP2 PRC_ENC
$BATINCLUDE FILLTAB2.GMS PRC_INP2 PRC_ELC
$BATINCLUDE FILLTAB2.GMS PRC_INP2 PRC_FEQ
$BATINCLUDE FILLTAB2.GMS PRC_LAG PRC_ENC
$BATINCLUDE FILLTAB2.GMS PRC_LED PRC_ENC
$BATINCLUDE FILLTAB2.GMS PRC_LED PRC_ELC
$BATINCLUDE FILLTAB2.GMS PRC_LIM PRC
$BATINCLUDE FILLTAB2.GMS PRC_OUT PRC_ENC
*GG* V1.1a initialize electric peak contribution table
PEAKDA_PRC(PRC, TP)$(NOT PEAKDA_PRC(PRC, TP) AND PRC_INP2(PRC, 'ELC', TP)) = 1.;

*============================================================================*
*  SRCENCP - Resource Supply Options                                         *
*   - Bounds on Annual Resource Availability                                 *
*   - Cost of Supply                                                         *
*   - Supply Option Security Indicator                                       *
*============================================================================*
*GG* V1.1a improve xeq time by setting up preprocess sets
SET SEP_ENT(SRC, ENT, P, ENT) / EMPTY.EMPTY.EMPTY.EMPTY /;
  SEP_ENT(SEP, ENC)$(SUM(TP, 1$SEP_INP(SEP, ENC, TP) OR
                              1$SEP_DELIV(SEP, ENC, TP))) = YES;
  SEP_ENT(SEP, 'ELC')$(SUM(TP, 1$SEP_INP(SEP, 'ELC', TP) OR
                               1$SEP_DELIV(SEP, 'ELC', TP))) = YES;
$BATINCLUDE FILLTAB3.GMS SEP_BOUND SEP BD
$BATINCLUDE FILLTAB2.GMS SEP_COST1 SEP
*GG* V1.1a resource incremental growth constraint, NOT IN OMNI?
*$BATINCLUDE FILLTAB2.GMS SEP_TGR SEP
$BATINCLUDE FILLTAB2.GMS SEP_SECURI SEP
*GG* V1.0i add input fuels & associated delivery costs
$BATINCLUDE FILLTAB2.GMS SEP_INP SEP_ENT
$BATINCLUDE FILLTAB2.GMS SEP_DELIV SEP_ENT
*GG* V1.1a initialize electric peak contribution table, including EXPorts
$BATINCLUDE FILLTAB2.GMS SEP_DELIV SEP_ENT
PEAKDA_SEP(SEP(SRC, ENT, P), TP)$
  (NOT PEAKDA_SEP(SEP, TP) AND SEP_INP(SEP, 'ELC', TP)) = 1.0;

*============================================================================*
*  TCH - Technology Characterization                                         *
*   - Annual Availability, and Set Defaults                                  *
*   - Seasonal Availability                                                  *
*   - Capacity Bounds                                                        *
*   - Investment Bounds                                                      *
*   - Activity Bounds                                                        *
*   - Capacity Unit Conversion Factor Defaults                               *
*   - Seasonal Capacity Factor, and set Defaults                             *
*   - Annual Capacity Factor, and set Defaults                               *
*   - Delivery Costs                                                         *
*   - Fixed O&M Costs                                                        *
*   - Investment Costs                                                       *
*   - Residual Capacity                                                      *
*   - Variable O&M Costs                                                     *
*============================================================================*
*GG* V1.1a improve xeq time by setting up preprocess sets
SET TCH_BD1(TCH, BD) / EMPTY.EMPTY /;
  TCH_BD1(TCH, BD)$(SUM(TP, TCH_BOUND(TCH, BD, TP))) = YES;
SET TCH_BD2(TCH, BD) / EMPTY.EMPTY /;
  TCH_BD2(TCH, BD)$(SUM(TP, 1$TCH_IBND(TCH, BD, TP) OR
                            1$TCH_BNDO(TCH, BD, TP))) = YES;
SET TCH_TD(TCH, Z, Y) / EMPTY.EMPTY.EMPTY /;
  TCH_TD(TCH, TD)$(SUM(TP, TCH_AF3(TCH, TD, TP))) = YES;
$BATINCLUDE FILLTAB2.GMS TCH_AF1 TCH
*GG* V1.0h try to properly init AF1
*GG*@ add the PEAK TID test too????
*GG* V1.0i move up TCH_AF3 initialization due to TCH_AF1 init
$BATINCLUDE FILLTAB2.GMS TCH_AF3 TCH_TD
TCH_AF1(PON, TP)$((NOT TCH_AF1(PON, TP)) AND
                  (NOT SUM(TD, TCH_AF3(PON, TD, TP)))) = 1.0;
TCH_AF1(XLM, TP) = 0;
*GG* V1.3c assign the AFs to the CFs for XPRs
*GG* V1.4a first interpolate then set from AFs if necessary
$BATINCLUDE FILLTAB2.GMS TCH_CF2 TCH
TCH_CF2(ZPR, TP)$(NOT TCH_CF2(ZPR,TP)) = TCH_AF1(ZPR, TP);
TCH_AF1(ZPR, TP) = 0;

$BATINCLUDE FILLTAB2.GMS TCH_BOUND TCH_BD1
$BATINCLUDE FILLTAB2.GMS TCH_IBND TCH_BD2
$BATINCLUDE FILLTAB2.GMS TCH_BNDO TCH_BD2

TCH_CAPUNI(TCH) = 1$(NOT TCH_CAPUNI(TCH)) + TCH_CAPUNI(TCH)$TCH_CAPUNI(TCH);
*GG* V1.2b move up the TCH_CF2 filling and process all YEARs to correct for
*          initialziation of CF1 = 1.0 in missing entries
*GG* V1.4a interpolate earlier before moving AFs
*$BATINCLUDE FILLTAB2.GMS TCH_CF2 TCH
TCH_CF1(XLM, Z, Y, YEAR) = TCH_CF2(XLM, YEAR)$TCH_CF2(XLM, YEAR) +
                         TCH_CF1(XLM, Z, Y, YEAR)$(NOT TCH_CF2(XLM, YEAR));
*GG* V1.1a adjust to only go over XLM and fix the init
*******************************************************************************
*$BATINCLUDE FILLTAB3.GMS TCH_CF1 TCH TD
*GG* V1.0i adjust the initialization tests a little
*TCH_CF1(TCH, Z, Y, TP)$(NOT TCH_CF1(TCH, Z, Y, TP)) =
*                        1.0$(SUM(TD, TCH_CF1(TCH, TD, TP)) EQ 0);
*TCH_CF1(BAS, Z, 'N', TP) = 0;
*GG*? TCH_CF1(STG, Z, 'N', TP) = 0;
*GG* V1.0i set night to day for externally load managed heating plants
*GG* V1.1a set all BAS/STG/HPL XLM cap-util factors from day
*TCH_CF1(XLM, Z, 'N', TP)$(1$BAS(XLM) OR 1$STG(XLM) OR 1$HPL(XLM)) =
*                          TCH_CF1(XLM, Z, 'D', TP);
*TCH_CF1(HPLXLM, Z, 'N', TP) = TCH_CF1(HPLXLM, Z, 'D', TP);
*******************************************************************************
$BATINCLUDE FILLTAB3.GMS TCH_CF1 XLM TD
*GG* V1.0i adjust the initialization tests a little
SET TCH_CFX(XLM, Z, Y, TP) / EMPTY.EMPTY.EMPTY.EMPTY /;
  TCH_CFX(XLM, Z, Y, TP)$(NOT TCH_CF1(XLM, Z, Y, TP) AND
                          (SUM(TD, TCH_CF1(XLM, TD, TP)) EQ 0)) = YES;
*GG* V1.2b only deal with available years
TCH_CF1(TCH_CFX(XLM, Z, Y, TP))$TPTCH(TP,XLM) = 1.0;
*TCH_CF1(BAS, Z, 'N', TP) = 0;
*GG*? TCH_CF1(STG, Z, 'N', TP) = 0;
*GG* V1.0i set night to day for externally load managed heating plants
*GG* V1.1a set all BAS/STG/HPL XLM cap-util factors from day
TCH_CF1(XLM, Z, 'N', TP)$(1$BAS(XLM) OR 1$STG(XLM) OR 1$HPL(XLM)) =
                          TCH_CF1(XLM, Z, 'D', TP);
*TCH_CF1(HPLXLM, Z, 'N', TP) = TCH_CF1(HPLXLM, Z, 'D', TP);

TCH_CF2(TCH, TP)$(NOT TCH_CF2(TCH, TP)) = 1.0;

SET TCH_ENT(TCH, ENT) / EMPTY.EMPTY /;
  TCH_ENT(TCH, ENT)$(SUM(TP, 1$TCH_DELIV(TCH, ENT, TP))) = YES;
$BATINCLUDE FILLTAB2.GMS TCH_DELIV TCH_ENT
$BATINCLUDE FILLTAB2.GMS TCH_FIXOM TCH
*GG* V1.1a resource incremental growth constraint, NOT IN OMNI?
*$BATINCLUDE FILLTAB2.GMS TCH_TGR TCH
$BATINCLUDE FILLTAB2.GMS TCH_INVCOS TCH
*GG* V1.1a add peak duration factor
$BATINCLUDE FILLTAB3.GMS TCH_PD CON Z
$BATINCLUDE FILLTAB2.GMS TCH_RESID TCH
$BATINCLUDE FILLTAB2.GMS TCH_VAROM TCH

*GG* V1.2b add filling of user differential costing DM table
$BATINCLUDE FILLTAB2.GMS DIFFCOST DM

*GG* V1.4e handle the tax/subsidy parameters
$BATINCLUDE FILLTAB3.GMS TSUB_BND TAXSUB BD
$BATINCLUDE FILLTAB2.GMS TSUB_COST TAXSUB
$BATINCLUDE FILLTAB3.GMS TSUB_TCH TAXSUB TCH
$BATINCLUDE FILLTAB3.GMS TSUB_SEP TAXSUB SEP
$BATINCLUDE FILLTAB2.GMS TSUB_TOT TAXSUB

*GG* V1.4e handle user MARKAL-MICRO parameters
$BATINCLUDE FILLTAB2.GMS SHFTDD DM
